@@ -1,7 +1,7 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: arkapp.h,v 1.16.2.1 2003/01/13 10:32:43 helio Exp $
+ $Id: arkapp.h 287753 2004-02-13 14:39:47Z waba $
 
  ark -- archiver for the KDE project
 
@@ -23,7 +23,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
@@ -90,8 +90,6 @@ class ArkApplication : public KUniqueApplication
 		// given a QString key, you get an ArkWidget * pointer.
 		QDict<ArkTopLevelWindow>m_windowsHash;
 		
-		bool m_isSessionRestored;
-		
 		static ArkApplication *mInstance; 
 };
 
