@@ -1,41 +1,42 @@
 //  -*- mode: c++; c-basic-offset: 4; -*-
 /*
- 
+
   ark -- archiver for the KDE project
- 
+
   Copyright (C)
- 
+
   2003: Georg Robbers <Georg.Robbers@urz.uni-hd.de>
   2002: Helio Chissini de Castro <helio@conectiva.com.br>
   2001: Corel Corporation (author: Michael Jarrett, michaelj@corel.com)
   1999-2000: Corel Corporation (author: Emily Ezust, emilye@corel.com)
   1999: Francois-Xavier Duranceau duranceau@kde.org
   1997-1999: Rob Palmbos palm9744@kettering.edu
- 
+
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.
- 
+
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
- 
+
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- 
+
 */
 
 #ifndef ARKWIDGET_H
 #define ARKWIDGET_H
 
-#define ARK_VERSION "2.1.9"
-
-#include "arkwidgetbase.h"
 #include <kio/job.h>
-#include <qwidget.h>
+#include <ktempdir.h>
+
+#include <qvbox.h>
+
+#include "arch.h"
 
 class QPoint;
 class QString;
@@ -51,21 +52,64 @@ class KURL;
 class KRun;
 class KTempFile;
 class KTempDir;
+class KToolBar;
 
-class Arch;
-class ArkSettings;
+class FileListView;
 class FileLVI;
+class SearchBar;
 
 
-class ArkWidget : public QWidget, public ArkWidgetBase
+class ArkWidget : public QVBox
 {
     Q_OBJECT
 public:
     ArkWidget( QWidget *parent=0, const char *name=0 );
     virtual ~ArkWidget();
 
+    bool isArchiveOpen() const { return m_bIsArchiveOpen; }
+    int getNumFilesInArchive() const { return m_nNumFiles; }
+
+    int getArkInstanceId() const { return m_arkInstanceId; }
+    void setArkInstanceId( int aid ) { m_arkInstanceId = aid; }
+
+    void cleanArkTmpDir();
+    virtual QString getArchName() const { return m_strArchName; }
+
+    const KURL& realURL() const { return m_realURL; }
+    void setRealURL( const KURL& url ) { m_realURL = url; }
+
+    QString tmpDir() const { return m_tmpDir ? m_tmpDir->name() : QString::null; }
+
+    FileListView * fileList() const { return archiveContent; }
+    Arch * archive() const { return arch; }
+    ArchType archiveType() const { return m_archType; }
+    int numSelectedFiles() const { return m_nNumSelectedFiles; }
+
+    /**
+     * Sets up the column headers for the file list. Clears previous entries before adding new ones.
+     * @param _headers A list of headers to add.
+     * @param _rightAlignCols An array of ints representing the columns ro right-align
+     * @param _numColsToAlignRight Size of _rightAlignCols
+     */
+    void setHeaders( QStringList* _headers, int* _rightAlignCols, int _numColsToAlignRight );
+
+    /**
+     * Clears all headers from the file list.
+     */
+    void clearHeaders();
+
+    /**
+     * Brings up a dialog showing the results returned by the last cmdline tool.
+     */
+    void viewShellOutput();
+
+    /**
+     * Miscellaneous tasks involved in closing an archive.
+     */
+    void closeArch();
+
     virtual void setExtractOnly(bool extOnly) { m_extractOnly = extOnly; }
-    virtual ArkSettings *settings() { return m_settings; }
+    virtual void deleteAfterUse( const QString& path );
     bool allowedArchiveName( const KURL & u );
     bool file_save_as( const KURL & u );
     virtual KURL getSaveAsFileName();
@@ -86,8 +130,8 @@ public slots:
     void edit_view_last_shell_output();
     virtual void file_close();
     virtual void file_new();
-    virtual void options_dirs();
-    virtual void options_saveNow();
+    void slotShowSearchBarToggled( bool b );
+    void showSettings();
 
 protected slots:
     void edit_select();
@@ -152,9 +196,10 @@ private: // methods
     void updateStatusSelection();
     void updateStatusTotals();
     void addFile(QStringList *list);
+    void removeDownloadedFiles();
 
     // make sure that str is a local file/dir
-    KURL toLocalFile( QString & str);
+    KURL toLocalFile(const KURL& url);
 
     // ask user whether to create a real archive from a compressed file
     // returns filename if so. Otherwise, empty.
@@ -187,7 +232,7 @@ private slots:
     void startDragSlotExtractDone( bool );
     void editSlotExtractDone();
     void editSlotAddDone( bool success );
-    void viewSlotExtractDone();
+    void viewSlotExtractDone( bool success );
     void openWithSlotExtractDone();
 
     void createRealArchiveSlotCreate( Arch * newArch, bool success,
@@ -249,7 +294,7 @@ private: // data
 
     KRun *m_pKRunPtr;
 
-    QStringList *mpDownloadedList;
+    QStringList mpDownloadedList;
 
     bool m_bArchivePopupEnabled;
 
@@ -266,6 +311,30 @@ private: // data
     KTempDir * m_extractRemoteTmpDir;
 
     bool m_modified;
+
+    KToolBar  * m_searchToolBar;
+    SearchBar * m_searchBar;
+
+    Arch *arch;
+    QString m_strArchName;
+    KURL m_realURL;
+    FileListView *archiveContent;
+    KURL m_url;
+    ArchType m_archType;
+
+    KIO::filesize_t m_nSizeOfFiles;
+    KIO::filesize_t m_nSizeOfSelectedFiles;
+    unsigned int m_nNumFiles;
+    int m_nNumSelectedFiles;
+    int m_arkInstanceId;
+
+    bool m_bIsArchiveOpen;
+    bool m_bIsSimpleCompressedFile;
+    bool m_bDropSourceIsSelf;
+
+    QStringList mDragFiles;
+    QStringList *m_extractList;
+    KTempDir *m_tmpDir;
 };
 
 #endif /* ARKWIDGET_H*/
