@@ -33,6 +33,7 @@
 
 // KDE includes
 #include <kdebug.h>
+#include <klargefile.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kstandarddirs.h>
@@ -45,20 +46,19 @@
 #include <kapplication.h>
 
 // ark includes
-#include "arkwidgetbase.h"
-#include "arksettings.h"
+#include "arkwidget.h"
 #include "compressedfile.h"
 
 // encapsulates the idea of a compressed file
 
-CompressedFile::CompressedFile( ArkSettings *_settings, ArkWidgetBase *_gui,
+CompressedFile::CompressedFile( ArkWidget *_gui,
 		  const QString & _fileName, const QString & _openAsMimeType )
-  : Arch(_settings, _gui, _fileName )
+  : Arch( _gui, _fileName )
 {
   m_tempDirectory = NULL;
   m_openAsMimeType = _openAsMimeType;
   kdDebug(1601) << "CompressedFile constructor" << endl;
-  m_tempDirectory = new KTempDir( _settings->getTmpDir()
+  m_tempDirectory = new KTempDir( _gui->tmpDir()
                           + QString::fromLatin1( "compressed_file_temp" ) );
   m_tempDirectory->setAutoDelete( true );
   m_tmpdir = m_tempDirectory->name();
@@ -172,7 +172,7 @@ void CompressedFile::open()
   KURL src, target;
   src.setPath( m_filename );
   target.setPath( m_tmpfile );
-  KIO::NetAccess::copy( m_filename, m_tmpfile );
+  KIO::NetAccess::copy( m_filename, m_tmpfile, m_gui );
 
   kdDebug(1601) << "Temp file name is " << m_tmpfile << endl;
 
@@ -203,7 +203,7 @@ void CompressedFile::open()
 
   if (kp->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false)
     {
-      KMessageBox::error( 0, i18n("Couldn't start a subprocess.") );
+      KMessageBox::error( 0, i18n("Could not start a subprocess.") );
       emit sigOpen(this, false, QString::null, 0 );
     }
 
@@ -219,14 +219,7 @@ void CompressedFile::slotUncompressDone(KProcess *_kp)
 
   if( _kp->normalExit() && (_kp->exitStatus()==0) )
   {
-    if(stderrIsError())
-    {
-      KMessageBox::error( 0, i18n("You probably don't have sufficient permissions.\n"
-                          "Please check the file owner and the integrity "
-                          "of the archive.") );
-    }
-    else
-      bSuccess = true;
+    bSuccess = true;
   }
 
   delete _kp;
@@ -246,7 +239,7 @@ void CompressedFile::slotUncompressDone(KProcess *_kp)
   url.setPath( m_tmpdir + lst.first() );
   m_tmpfile = url.path();
   KIO::UDSEntry udsInfo;
-  KIO::NetAccess::stat( url, udsInfo );
+  KIO::NetAccess::stat( url, udsInfo, m_gui );
   KFileItem fileItem( udsInfo, url );
   QStringList list;
   list << fileItem.name();
@@ -254,7 +247,7 @@ void CompressedFile::slotUncompressDone(KProcess *_kp)
   list << fileItem.user();
   list << fileItem.group();
   list << KIO::number( fileItem.size() );
-  m_gui->listingAdd(&list); // send to GUI
+  m_gui->fileList()->addItem(list); // send to GUI
 
   emit sigOpen( this, bSuccess, m_filename,
                 Arch::Extract | Arch::Delete | Arch::Add | Arch::View );
@@ -267,7 +260,7 @@ void CompressedFile::create()
 		  | Arch::View);
 }
 
-void CompressedFile::addFile( QStringList *urls )
+void CompressedFile::addFile( const QStringList &urls )
 {
   // only used for adding ONE file to an EMPTY gzip file, i.e., one that
   // has just been created
@@ -275,11 +268,13 @@ void CompressedFile::addFile( QStringList *urls )
   kdDebug(1601) << "+CompressedFile::addFile" << endl;
 
   Q_ASSERT(m_gui->getNumFilesInArchive() == 0);
-  Q_ASSERT(urls->count() == 1);
+  Q_ASSERT(urls.count() == 1);
 
-  QString file = urls->first();
-  if (file.left(5) == "file:")
-    file = file.right(file.length() - 5);
+  KURL url = KURL::fromPathOrURL(urls.first());
+  Q_ASSERT(url.isLocalFile());
+
+  QString file;
+  file = url.path();
 
   KProcess proc;
   proc << "cp" << file << m_tmpdir;
@@ -311,11 +306,15 @@ void CompressedFile::addFile( QStringList *urls )
   connect( kp, SIGNAL(processExited(KProcess*)), this,
 	   SLOT(slotAddDone(KProcess*)));
 
-  fd = fopen( QFile::encodeName(m_filename), "w" );
+  int f_desc = KDE_open(QFile::encodeName(m_filename), O_CREAT | O_TRUNC | O_WRONLY, 0666);
+  if (f_desc != -1)
+      fd = fdopen( f_desc, "w" );
+  else
+      fd = NULL;
 
   if (kp->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false)
     {
-      KMessageBox::error( 0, i18n("Couldn't start a subprocess.") );
+      KMessageBox::error( 0, i18n("Could not start a subprocess.") );
     }
 
   kdDebug(1601) << "-CompressedFile::addFile" << endl;
@@ -370,7 +369,7 @@ void CompressedFile::remove(QStringList *)
   // delete the compressed file but then create it empty in case someone
   // does a reload and finds it no longer exists!
   QFile::remove(m_filename);
-  
+
   ::close(::open(QFile::encodeName(m_filename), O_WRONLY | O_CREAT | O_EXCL));
 
   m_tmpfile = "";
