@@ -1,6 +1,6 @@
 /* -*- c++ -*-
 
-$Id: extractdlg.cpp,v 1.35 2004/07/03 20:55:34 pinto Exp $
+$Id: extractdlg.cpp 416616 2005-05-22 01:42:37Z henrique $
 
 ark -- archiver for the KDE project
 
@@ -50,9 +50,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "arkutils.h"
 #include "extractdlg.h"
 #include "settings.h"
+#include "arch.h"
 #define FIRST_PAGE_WIDTH  390
 
-ExtractDlg::ExtractDlg( QWidget *parent, const char *name, const QString& archiveName, const QString &prefix )
+ExtractDlg::ExtractDlg( QWidget *parent, const char *name, const QString& archiveName )
     : KDialogBase( KDialogBase::Plain, i18n("Extract"), Ok | Cancel, Ok, parent, name )
 {
 	QFrame *mainFrame = plainPage();
@@ -93,22 +94,8 @@ ExtractDlg::ExtractDlg( QWidget *parent, const char *name, const QString& archiv
 	m_extractDirCB->setHistoryItems( list );
 
 	KURL u;
-
-	switch ( Settings::extractDirMode() )
-	{
-		case Settings::EnumExtractDirMode::Common:
-			kdDebug( 1601 ) << "ExtractDlg: Using common folder" << endl;
-			u = Settings::archiveDirectory() + prefix;
-			break;
-		case Settings::EnumExtractDirMode::Custom:
-			kdDebug( 1601 ) << "ExtractDlg: Using custom folder" << endl;
-			u = Settings::extractDir() + prefix;
-			break;
-		case Settings::EnumExtractDirMode::Last:
-		default:
-			kdDebug( 1601 ) << "ExtractDlg: Using last extraction folder" << endl;
-			u = Settings::lastExtractDir() + prefix;
-	}
+	QString tmp;
+	u = KFileDialog::getStartURL( ":ArkExtractDir", tmp );
 
 	kdDebug( 1601 ) << "ExtractDlg: u is " << u.prettyURL() << endl;
 	
@@ -197,6 +184,22 @@ ExtractDlg::~ExtractDlg()
 	config->writeEntry( "OpenDestinationFolder", m_viewFolderAfterExtraction->isChecked() );
 }
 
+void 
+ExtractDlg::setDefaultExtractOp( ExtractOp op ) 
+{
+	switch ( op )
+	{
+		case Current:
+			m_radioCurrent->setChecked(   true );
+			break;
+		case Selected:
+			m_radioSelected->setChecked(  true );
+			break;
+		default:
+			m_radioAll->setChecked(  true );
+	}
+}
+
 void
 ExtractDlg::extractDirChanged(const QString &text )
 {
@@ -246,8 +249,6 @@ ExtractDlg::accept()
 	}
 
 	m_extractDir = p;
-	// you need to change the settings to change the fixed dir.
-	Settings::setLastExtractDir( p.prettyURL() );
 
 	if ( m_radioPattern->isChecked() )
 	{
@@ -263,10 +264,6 @@ ExtractDlg::accept()
 		}
 	}
 
-
-	// Remember the last extraction folder
-	Settings::setLastExtractDir( m_extractDirCB->lineEdit()->text() );
-
 	// I made it! so nothing's wrong.
 	KDialogBase::accept();
 }
@@ -338,5 +335,10 @@ ExtractFailureDlg::ExtractFailureDlg( QStringList *list, QWidget *parent, char *
 	QApplication::restoreOverrideCursor();
 }
 
+void ExtractDlg::setURL( const KURL& u )
+{
+	m_extractDirCB->setEditURL( u );
+}
+
 #include "extractdlg.moc"
 
