@@ -1,6 +1,6 @@
 /*
 
- $Id: shellOutputDlg.h,v 1.8 2003/03/07 22:06:46 waba Exp $
+ $Id: shellOutputDlg.h 314731 2004-05-26 10:38:08Z henrique $
 
  ark -- archiver for the KDE project
 
@@ -28,29 +28,20 @@
 #ifndef SHELL_OUTPUT_DLG_H
 #define SHELL_OUTPUT_DLG_H
 
-#include <qmultilineedit.h>
-#include <qdialog.h>
+#include <kdialogbase.h>
 
 class QWidget;
+class QString;
+class QTextEdit;
 
-class ArkSettings;
-
-class ShellOutputWidget : public QMultiLineEdit {
-public:
-  ShellOutputWidget( QDialog* _d ) : QMultiLineEdit( _d ) 
-    { setWordWrap(FixedColumnWidth);
-      setWrapColumnOrWidth(80);
-     };
-};
-
-
-
-class ShellOutputDlg : public QDialog 
+class ShellOutputDlg : public KDialogBase
 {
-  Q_OBJECT
-public:
-  ShellOutputDlg( ArkSettings *, QWidget *parent=0, const char *name=0 );
-  
+	Q_OBJECT
+	public:
+		ShellOutputDlg( const QString& text, QWidget *parent=0, const char *name=0 );
+		~ShellOutputDlg();
+	private:
+		QTextEdit * m_outputViewer;
 };
 
 #endif /* SHELL_OUTPUT_DLG_H */
