@@ -71,28 +71,6 @@ static void fpe_handler(int fpe_parm)
 
 const CALCAMNT CalcEngine::pi = (ASIN(1L) * 2L);
 
-int precedence[14] = { 0, 1, 2, 3, 4, 4, 5, 5, 6, 6, 6, 7, 7, 6 };
-
-/*
-int adjust_op[14][3] =
-{
-	{FUNC_NULL,     FUNC_NULL,     FUNC_NULL},
-	{FUNC_OR,       FUNC_OR,       FUNC_XOR },
-	{FUNC_XOR,      FUNC_XOR,      FUNC_XOR },
-	{FUNC_AND,      FUNC_AND,      FUNC_AND },
-	{FUNC_LSH,      FUNC_LSH,      FUNC_RSH },
-	{FUNC_RSH,      FUNC_RSH,      FUNC_RSH },
-	{FUNC_ADD,      FUNC_ADD,      FUNC_ADD },
-	{FUNC_SUBTRACT, FUNC_SUBTRACT, FUNC_SUBTRACT},
-	{FUNC_MULTIPLY, FUNC_MULTIPLY, FUNC_MULTIPLY},
-	{FUNC_DIVIDE,   FUNC_DIVIDE,   FUNC_DIVIDE},
-	{FUNC_MOD,      FUNC_MOD,      FUNC_INTDIV },
-	{FUNC_POWER,    FUNC_POWER,    FUNC_PWR_ROOT},
-	{FUNC_PWR_ROOT, FUNC_PWR_ROOT, FUNC_PWR_ROOT},
-	{FUNC_INTDIV,   FUNC_INTDIV,   FUNC_INTDIV},
-};
-*/
-
 static CALCAMNT _error;
 
 static CALCAMNT ExecOr(CALCAMNT left_op, CALCAMNT right_op)
@@ -233,13 +211,49 @@ static CALCAMNT ExecRsh(CALCAMNT left_op, CALCAMNT right_op)
 static CALCAMNT ExecAdd(CALCAMNT left_op, CALCAMNT right_op)
 {
 	// printf("ExecAdd\n");
-	return left_op + right_op;
+	CALCAMNT tmp_result = left_op + right_op;
+
+	if (!tmp_result)
+		return 0;
+
+	// When operating with floating point numbers the following
+	// effect can happen: 1.0000001 + (-1.0) gives 1.0000232e-6
+	// instead of 1e-6. This looks very bad on a calculator (to
+	// the unexperienced eye). Hence we round in this case.
+	CALCAMNT max_precision = (FABS(left_op) + FABS(right_op))
+	  * CALCAMNT_EPSILON;
+	// we want to round to decimal digits, hence we need to find
+	// the number of valid digits
+	CALCAMNT digits = 1;
+	while (digits > max_precision)
+	  digits *= 0.1L;
+	digits *= 100.0L; // this number is experimental
+
+	return  digits * ROUND(tmp_result/digits);
 }
 
 static CALCAMNT ExecSubtract(CALCAMNT left_op, CALCAMNT right_op)
 {
 	// printf("ExecSubtract\n");
-	return left_op - right_op;
+	CALCAMNT tmp_result = left_op - right_op;
+
+	if (!tmp_result)
+		return 0;
+
+	// When operating with floating point numbers the following
+	// effect can happen: 1.0000001 + (-1.0) gives 1.0000232e-6
+	// instead of 1e-6. This looks very bad on a calculator (to
+	// the unexperienced eye). Hence we round in this case.
+	CALCAMNT max_precision = (FABS(left_op) + FABS(right_op))
+	  * CALCAMNT_EPSILON;
+	// we want to round to decimal digits, hence we need to find
+	// the number of valid digits
+	CALCAMNT digits = 1;
+	while (digits > max_precision)
+	  digits *= 0.1L;
+	digits *= 100.0L; // this number is experimental
+
+	return  digits * ROUND(tmp_result/digits);
 }
 
 static CALCAMNT ExecMultiply(CALCAMNT left_op, CALCAMNT right_op)
@@ -379,9 +393,29 @@ static CALCAMNT ExecDivideP(CALCAMNT left_op, CALCAMNT right_op)
 }
 
 
+// build precedence list
+const struct operator_data CalcEngine::Operator[] = {
+  { 0, NULL,     NULL}, // FUNC_EQUAL
+  { 0, NULL,     NULL}, // FUNC_PERCENT
+  { 0, NULL,     NULL}, // FUNC_BRACKET
+  { 1, ExecOr,   NULL}, // FUNC_OR
+  { 2, ExecXor,  NULL}, // FUNC_XOR
+  { 3, ExecAnd,  NULL}, // FUNC_AND
+  { 4, ExecLsh,  NULL}, // FUNC_LSH
+  { 4, ExecRsh,  NULL}, // FUNC_RSH
+  { 5, ExecAdd,  ExecAddP}, // FUNC_ADD
+  { 5, ExecSubtract, ExecSubP}, // FUNC_SUBTRACT
+  { 6, ExecMultiply, ExecMultiplyP}, // FUNC_MULTIPLY
+  { 6, ExecDivide,   ExecDivideP}, // FUNC_DIVIDE
+  { 6, ExecMod,  NULL}, // FUNC_MOD
+  { 6, ExecIntDiv, NULL}, // FUNC_INTDIV
+  { 7, ExecPower,  NULL}, // FUNC_POWER
+  { 7, ExecPwrRoot, NULL} // FUNC_PWR_ROOT
+};
+
 
 CalcEngine::CalcEngine()
-  :   precedence_base(0), percent_mode(false)
+  :   _percent_mode(false)
 {
 	//
 	// Basic initialization involves initializing the calcultion
@@ -399,126 +433,99 @@ CalcEngine::CalcEngine()
 #endif
 	sigaction(SIGFPE, &fpe_trap, NULL);
 
-	//	RefreshEngine();
-
-	Arith_ops[0] = NULL,
-	  Arith_ops[1] = ExecOr,
-	  Arith_ops[2] = ExecXor,
-	  Arith_ops[3] = ExecAnd,
-	  Arith_ops[4] = ExecLsh,
-	  Arith_ops[5] = ExecRsh,
-	  Arith_ops[6] = ExecAdd,
-	  Arith_ops[7] = ExecSubtract,
-	  Arith_ops[8] = ExecMultiply,
-	  Arith_ops[9] = ExecDivide,
-	  Arith_ops[10] = ExecMod,
-	  Arith_ops[11] = ExecPower,
-	  Arith_ops[12] = ExecPwrRoot,
-	  Arith_ops[13] = ExecIntDiv;
-
-	Prcnt_ops[0] = NULL,
-	  Prcnt_ops[1] = NULL,
-	  Prcnt_ops[2] = NULL,
-	  Prcnt_ops[3] = NULL,
-	  Prcnt_ops[4] = NULL,
-	  Prcnt_ops[5] = NULL,
-	  Prcnt_ops[6] = ExecAddP,
-	  Prcnt_ops[7] = ExecSubP,
-	  Prcnt_ops[8] = ExecMultiplyP,
-	  Prcnt_ops[9] = ExecDivideP,
-	  Prcnt_ops[10] = NULL,
-	  Prcnt_ops[11] = NULL,
-	  Prcnt_ops[12] = NULL,
-	  Prcnt_ops[13] = NULL;
-
-	_last_result = 0L;
+	_last_number = 0L;
 	_error = false;
 }
 
-CALCAMNT CalcEngine::last_output(bool &error) const
+CALCAMNT CalcEngine::lastOutput(bool &error) const
 {
 	error = _error;
-	return _last_result;
+	return _last_number;
 }
 
-
-/*
-void CalcEngine::RefreshEngine()
-{
-	display_error = false;
-	DISPLAY_AMOUNT = 0L;
-	decimal_point = 0;
-	input_count = 0;
-	UpdateDisplay();
-	last_input = DIGIT; // must set last to DIGIT after Update Display in order
-						// not to get a display holding e.g. 0.000
-}
-*/
-
-
-void CalcEngine::And(CALCAMNT input)
-{
-	EnterStackFunction(FUNC_AND, input);
-}
-
-void CalcEngine::ArcCos(CALCAMNT input)
+void CalcEngine::ArcCosDeg(CALCAMNT input)
 {
 	CALCAMNT tmp = ACOS(input);
 
-	switch (_angle_mode)
-	{
-	case ANG_DEGREE:
-		_last_result = Rad2Deg(tmp);
-		break;
-	case ANG_GRADIENT:
-		_last_result = Rad2Gra(tmp);
-		break;
-	case ANG_RADIAN:
-		_last_result = tmp;
-		break;
-	}
+	_last_number = Rad2Deg(tmp);
 
 	//if (errno == EDOM || errno == ERANGE)
 	//	_error = true;
 }
 
-void CalcEngine::ArcSin(CALCAMNT input)
+void CalcEngine::ArcCosRad(CALCAMNT input)
+{
+	CALCAMNT tmp = ACOS(input);
+	
+	_last_number = tmp;
+
+	//if (errno == EDOM || errno == ERANGE)
+	//	_error = true;
+}
+
+void CalcEngine::ArcCosGrad(CALCAMNT input)
+{
+	CALCAMNT tmp = ACOS(input);
+
+	_last_number = Rad2Gra(tmp);
+
+	//if (errno == EDOM || errno == ERANGE)
+	//	_error = true;
+}
+
+void CalcEngine::ArcSinDeg(CALCAMNT input)
+{
+	CALCAMNT tmp = ASIN(input);
+	
+	_last_number = Rad2Deg(tmp);
+
+	//if (errno == EDOM || errno == ERANGE)
+	//	_error = true;
+}
+
+void CalcEngine::ArcSinRad(CALCAMNT input)
 {
 	CALCAMNT tmp = ASIN(input);
 
-	switch (_angle_mode)
-	{
-	case ANG_DEGREE:
-		_last_result = Rad2Deg(tmp);
-		break;
-	case ANG_GRADIENT:
-		_last_result = Rad2Gra(tmp);
-		break;
-	case ANG_RADIAN:
-		_last_result = tmp;
-		break;
-	}
+	_last_number = tmp;
 
 	//if (errno == EDOM || errno == ERANGE)
 	//	_error = true;
 }
 
-void CalcEngine::ArcTangens(CALCAMNT input)
+void CalcEngine::ArcSinGrad(CALCAMNT input)
+{
+	CALCAMNT tmp = ASIN(input);
+
+	_last_number = Rad2Gra(tmp);
+
+	//if (errno == EDOM || errno == ERANGE)
+	//	_error = true;
+}
+
+void CalcEngine::ArcTangensDeg(CALCAMNT input)
+{
+	CALCAMNT tmp = ATAN(input);
+	
+	_last_number = Rad2Deg(tmp);
+
+	//if (errno == EDOM || errno == ERANGE)
+	//	_error = true;
+}
+
+void CalcEngine::ArcTangensRad(CALCAMNT input)
+{
+	_last_number = ATAN(input);
+
+	//if (errno == EDOM || errno == ERANGE)
+	//	_error = true;
+}
+
+void CalcEngine::ArcTangensGrad(CALCAMNT input)
 {
 	CALCAMNT tmp = ATAN(input);
 
-	switch (_angle_mode)
-	{
-	case ANG_DEGREE:
-		_last_result = Rad2Deg(tmp);
-		break;
-	case ANG_GRADIENT:
-		_last_result = Rad2Gra(tmp);
-		break;
-	case ANG_RADIAN:
-		_last_result = tmp;
-		break;
-	}
+	_last_number = Rad2Gra(tmp);
 
 	//if (errno == EDOM || errno == ERANGE)
 	//	_error = true;
@@ -526,21 +533,21 @@ void CalcEngine::ArcTangens(CALCAMNT input)
 
 void CalcEngine::AreaCosHyp(CALCAMNT input)
 {
-	_last_result = ACOSH(input);
+	_last_number = ACOSH(input);
 	//if (errno == EDOM || errno == ERANGE)
 	//	_error = true;
 }
 
 void CalcEngine::AreaSinHyp(CALCAMNT input)
 {
-	_last_result = ASINH(input);
+	_last_number = ASINH(input);
 	//if (errno == EDOM || errno == ERANGE)
 	//	_error = true;
 }
 
 void CalcEngine::AreaTangensHyp(CALCAMNT input)
 {
-	_last_result = ATANH(input);
+	_last_number = ATANH(input);
 	//if (errno == EDOM || errno == ERANGE)
 	//	_error = true;
 }
@@ -559,31 +566,50 @@ void CalcEngine::Complement(CALCAMNT input)
 
 	KCALC_LONG boh_work = (KCALC_LONG)boh_work_d;
 
-	_last_result = ~boh_work;
+	_last_number = ~boh_work;
 }
 
-void CalcEngine::Cos(CALCAMNT input)
+void CalcEngine::CosDeg(CALCAMNT input)
+{
+	CALCAMNT tmp = input;
+	
+	tmp = Deg2Rad(input);
+
+	_last_number = COS(tmp);
+
+	// Now a cheat to help the weird case of COS 90 degrees not being 0!!!
+	if (_last_number < POS_ZERO && _last_number > NEG_ZERO)
+		_last_number = 0.0;
+
+	//if (errno == EDOM || errno == ERANGE)
+	//	_error = true;
+}
+
+void CalcEngine::CosRad(CALCAMNT input)
 {
 	CALCAMNT tmp = input;
 
-	switch (_angle_mode)
-	{
-	case ANG_DEGREE:
-		tmp = Deg2Rad(input);
-		break;
-	case ANG_GRADIENT:
-		tmp = Gra2Rad(input);
-		break;
-	case ANG_RADIAN:
-		tmp = input;
-		break;
-	}
-
-	_last_result = COS(tmp);
+	_last_number = COS(tmp);
 
 	// Now a cheat to help the weird case of COS 90 degrees not being 0!!!
-	if (_last_result < POS_ZERO && _last_result > NEG_ZERO)
-		_last_result = 0.0;
+	if (_last_number < POS_ZERO && _last_number > NEG_ZERO)
+		_last_number = 0.0;
+
+	//if (errno == EDOM || errno == ERANGE)
+	//	_error = true;
+}
+
+void CalcEngine::CosGrad(CALCAMNT input)
+{
+	CALCAMNT tmp = input;
+
+	tmp = Gra2Rad(input);
+
+	_last_number = COS(tmp);
+
+	// Now a cheat to help the weird case of COS 90 degrees not being 0!!!
+	if (_last_number < POS_ZERO && _last_number > NEG_ZERO)
+		_last_number = 0.0;
 
 	//if (errno == EDOM || errno == ERANGE)
 	//	_error = true;
@@ -591,22 +617,28 @@ void CalcEngine::Cos(CALCAMNT input)
 
 void CalcEngine::CosHyp(CALCAMNT input)
 {
-	_last_result = COSH(input);
+	_last_number = COSH(input);
 }
 
-void CalcEngine::Divide(CALCAMNT input)
+void CalcEngine::Cube(CALCAMNT input)
 {
-	EnterStackFunction(FUNC_DIVIDE, input);
+	if (ISINF(_last_number = input*input*input))
+		_error = true;
+}
+
+void CalcEngine::CubeRoot(CALCAMNT input)
+{
+	_last_number = CBRT(input);
 }
 
 void CalcEngine::Exp(CALCAMNT input)
 {
-	_last_result = EXP(input);
+	_last_number = EXP(input);
 }
 
 void CalcEngine::Exp10(CALCAMNT input)
 {
-	_last_result = POW(10, input);
+	_last_number = POW(10, input);
 }
 
 static CALCAMNT _factorial(CALCAMNT input)
@@ -646,23 +678,13 @@ void CalcEngine::Factorial(CALCAMNT input)
 
 	MODF(input, &tmp_amount);
 
-	_last_result = _factorial(tmp_amount);
+	_last_number = _factorial(tmp_amount);
 
 }
 
 void CalcEngine::InvertSign(CALCAMNT input)
 {
-	_last_result = -input;
-}
-
-void CalcEngine::InvMod(CALCAMNT input)
-{
-	EnterStackFunction(FUNC_INTDIV, input);
-}
-
-void CalcEngine::InvPower(CALCAMNT input)
-{
-	EnterStackFunction(FUNC_PWR_ROOT, input);
+	_last_number = -input;
 }
 
 void CalcEngine::Ln(CALCAMNT input)
@@ -670,7 +692,7 @@ void CalcEngine::Ln(CALCAMNT input)
 	if (input <= 0.0)
 		_error = true;
 	else
-		_last_result = LN(input);
+		_last_number = LN(input);
 }
 
 void CalcEngine::Log10(CALCAMNT input)
@@ -678,57 +700,27 @@ void CalcEngine::Log10(CALCAMNT input)
 	if (input <= 0.0)
 		_error = true;
 	else
-		_last_result = LOG_TEN(input);
-}
-
-void CalcEngine::Minus(CALCAMNT input)
-{
-	EnterStackFunction(FUNC_SUBTRACT, input);
-}
-
-void CalcEngine::Mod(CALCAMNT input)
-{
-	EnterStackFunction(FUNC_MOD, input);
-}
-
-void CalcEngine::Multiply(CALCAMNT input)
-{
-	EnterStackFunction(FUNC_MULTIPLY, input);
-}
-
-void CalcEngine::Or(CALCAMNT input)
-{
-	EnterStackFunction(FUNC_OR, input);
+		_last_number = LOG_TEN(input);
 }
 
 void CalcEngine::ParenClose(CALCAMNT input)
 {
-	amount_stack.push(input);
-
-	UpdateStack(precedence_base);
-
-	if ((precedence_base -= PRECEDENCE_INCR) < 0)
-		precedence_base = 0;
-
-	// sad, but necessary: pushing once above and once in
-	// UpdateStack
-	amount_stack.pop();
+ 	// evaluate stack until corresponding opening bracket
+	while (!_stack.isEmpty())
+	{
+		_node tmp_node = _stack.pop();
+		if (tmp_node.operation == FUNC_BRACKET)
+			break;
+		input = evalOperation(tmp_node.number, tmp_node.operation,
+				      input);
+	}
+	_last_number = input;
+	return;
 }
 
 void CalcEngine::ParenOpen(CALCAMNT input)
 {
-	UNUSED(input);
-	precedence_base += PRECEDENCE_INCR;
-}
-
-void CalcEngine::Plus(CALCAMNT input)
-{
-	EnterStackFunction(FUNC_ADD, input);
-}
-
-void CalcEngine::Power(CALCAMNT input)
-{
-	EnterStackFunction(FUNC_POWER, input);
+	enterOperation(input, FUNC_BRACKET);
 }
 
 void CalcEngine::Reciprocal(CALCAMNT input)
@@ -736,41 +728,50 @@ void CalcEngine::Reciprocal(CALCAMNT input)
 	if (input == 0.0)
 		_error = true;
 	else
-		_last_result = 1/input;
-}
-		
-void CalcEngine::ShiftLeft(CALCAMNT input)
-{
-	EnterStackFunction(FUNC_LSH, input);
+		_last_number = 1/input;
 }
 
-void CalcEngine::ShiftRight(CALCAMNT input)
-{
-	EnterStackFunction(FUNC_RSH, input);
-}
-
-void CalcEngine::Sin(CALCAMNT input)
+void CalcEngine::SinDeg(CALCAMNT input)
 {
 	CALCAMNT tmp = input;
 
-	switch (_angle_mode)
-	{
-	case ANG_DEGREE:
-		tmp = Deg2Rad(input);
-		break;
-	case ANG_GRADIENT:
-		tmp = Gra2Rad(input);
-		break;
-	case ANG_RADIAN:
-		tmp = input;
-		break;
-	}
+	tmp = Deg2Rad(input);
 
-	_last_result = SIN(tmp);
+	_last_number = SIN(tmp);
 
 	// Now a cheat to help the weird case of COS 90 degrees not being 0!!!
-	if (_last_result < POS_ZERO && _last_result > NEG_ZERO)
-		_last_result = 0.0;
+	if (_last_number < POS_ZERO && _last_number > NEG_ZERO)
+		_last_number = 0.0;
+
+	//if (errno == EDOM || errno == ERANGE)
+	//	_error = true;
+}
+
+void CalcEngine::SinRad(CALCAMNT input)
+{
+	CALCAMNT tmp = input;
+
+	_last_number = SIN(tmp);
+
+	// Now a cheat to help the weird case of COS 90 degrees not being 0!!!
+	if (_last_number < POS_ZERO && _last_number > NEG_ZERO)
+		_last_number = 0.0;
+
+	//if (errno == EDOM || errno == ERANGE)
+	//	_error = true;
+}
+
+void CalcEngine::SinGrad(CALCAMNT input)
+{
+	CALCAMNT tmp = input;
+
+	tmp = Gra2Rad(input);
+
+	_last_number = SIN(tmp);
+
+	// Now a cheat to help the weird case of COS 90 degrees not being 0!!!
+	if (_last_number < POS_ZERO && _last_number > NEG_ZERO)
+		_last_number = 0.0;
 
 	//if (errno == EDOM || errno == ERANGE)
 	//	_error = true;
@@ -778,12 +779,12 @@ void CalcEngine::Sin(CALCAMNT input)
 
 void CalcEngine::SinHyp(CALCAMNT input)
 {
-	_last_result = SINH(input);
+	_last_number = SINH(input);
 }
 
 void CalcEngine::Square(CALCAMNT input)
 {
-	if (ISINF(_last_result = input*input))
+	if (ISINF(_last_number = input*input))
 		_error = true;
 }
 
@@ -792,7 +793,7 @@ void CalcEngine::SquareRoot(CALCAMNT input)
 	if (input < 0.0)
 		_error = true;
 	else
-		_last_result = SQRT(input);
+		_last_number = SQRT(input);
 }
 
 void CalcEngine::StatClearAll(CALCAMNT input)
@@ -804,26 +805,26 @@ void CalcEngine::StatClearAll(CALCAMNT input)
 void CalcEngine::StatCount(CALCAMNT input)
 {
 	UNUSED(input);
-	_last_result = stats.count();
+	_last_number = stats.count();
 }
 
 void CalcEngine::StatDataNew(CALCAMNT input)
 {
 	stats.enterData(input);
-	_last_result = stats.count();
+	_last_number = stats.count();
 }
 
 void CalcEngine::StatDataDel(CALCAMNT input)
 {
 	UNUSED(input);
 	stats.clearLast();
-	_last_result = 0L;
+	_last_number = 0L;
 }
 
 void CalcEngine::StatMean(CALCAMNT input)
 {
 	UNUSED(input);
-	_last_result = stats.mean();
+	_last_number = stats.mean();
 
 	_error = stats.error();
 }
@@ -831,7 +832,7 @@ void CalcEngine::StatMean(CALCAMNT input)
 void CalcEngine::StatMedian(CALCAMNT input)
 {
 	UNUSED(input);
-	_last_result = stats.median();
+	_last_number = stats.median();
 
 	_error = stats.error();
 }
@@ -839,7 +840,7 @@ void CalcEngine::StatMedian(CALCAMNT input)
 void CalcEngine::StatStdDeviation(CALCAMNT input)
 {
 	UNUSED(input);
-	_last_result = stats.std();
+	_last_number = stats.std();
 
 	_error = stats.error();
 }
@@ -847,7 +848,7 @@ void CalcEngine::StatStdDeviation(CALCAMNT input)
 void CalcEngine::StatStdSample(CALCAMNT input)
 {
 	UNUSED(input);
-	_last_result = stats.sample_std();
+	_last_number = stats.sample_std();
 
 	_error = stats.error();
 }
@@ -855,33 +856,20 @@ void CalcEngine::StatStdSample(CALCAMNT input)
 void CalcEngine::StatSum(CALCAMNT input)
 {
 	UNUSED(input);
-	_last_result = stats.sum();
+	_last_number = stats.sum();
 }
 
 void CalcEngine::StatSumSquares(CALCAMNT input)
 {
 	UNUSED(input);
-	_last_result = stats.sum_of_squares();
+	_last_number = stats.sum_of_squares();
 
 	_error = stats.error();
 }
 
-void CalcEngine::Tangens(CALCAMNT input)
+void CalcEngine::TangensDeg(CALCAMNT input)
 {
-	CALCAMNT aux, tmp = input;
-
-	switch (_angle_mode)
-	{
-	case ANG_DEGREE:
-		tmp = Deg2Rad(input);
-		break;
-	case ANG_GRADIENT:
-		tmp = Gra2Rad(input);
-		break;
-	case ANG_RADIAN:
-		tmp = input;
-		break;
-	}
+	CALCAMNT aux, tmp = Deg2Rad(input);
 	
 	aux = tmp;
 	// make aux positive
@@ -890,15 +878,65 @@ void CalcEngine::Tangens(CALCAMNT input)
 	while (aux > pi) aux -= pi;
 	// if were are really close to pi/2 throw an error
 	// tan(pi/2) => inf
-	// using the 10 factor because without it 270 tan still gave a result
+	// using the 10 factor because without it 270Âº tan still gave a result
 	if ( (aux - pi/2 < POS_ZERO * 10) && (aux - pi/2 > NEG_ZERO * 10) )
 		_error = true;
 	else
-		_last_result = TAN(tmp);
+		_last_number = TAN(tmp);
 
 	// Now a cheat to help the weird case of TAN 0 degrees not being 0!!!
-	if (_last_result < POS_ZERO && _last_result > NEG_ZERO)
-		_last_result = 0.0;
+	if (_last_number < POS_ZERO && _last_number > NEG_ZERO)
+		_last_number = 0.0;
+
+	//if (errno == EDOM || errno == ERANGE)
+	//	_error = true;
+}
+
+void CalcEngine::TangensRad(CALCAMNT input)
+{
+	CALCAMNT aux, tmp = input;
+	
+	aux = tmp;
+	// make aux positive
+	if (aux < 0) aux = -aux;
+	// put aux between 0 and pi
+	while (aux > pi) aux -= pi;
+	// if were are really close to pi/2 throw an error
+	// tan(pi/2) => inf
+	// using the 10 factor because without it 270Âº tan still gave a result
+	if ( (aux - pi/2 < POS_ZERO * 10) && (aux - pi/2 > NEG_ZERO * 10) )
+		_error = true;
+	else
+		_last_number = TAN(tmp);
+
+	// Now a cheat to help the weird case of TAN 0 degrees not being 0!!!
+	if (_last_number < POS_ZERO && _last_number > NEG_ZERO)
+		_last_number = 0.0;
+
+	//if (errno == EDOM || errno == ERANGE)
+	//	_error = true;
+}
+
+void CalcEngine::TangensGrad(CALCAMNT input)
+{
+	CALCAMNT aux, tmp = Gra2Rad(input);
+	
+	aux = tmp;
+	// make aux positive
+	if (aux < 0) aux = -aux;
+	// put aux between 0 and pi
+	while (aux > pi) aux -= pi;
+	// if were are really close to pi/2 throw an error
+	// tan(pi/2) => inf
+	// using the 10 factor because without it 270Âº tan still gave a result
+	if ( (aux - pi/2 < POS_ZERO * 10) && (aux - pi/2 > NEG_ZERO * 10) )
+		_error = true;
+	else
+		_last_number = TAN(tmp);
+
+	// Now a cheat to help the weird case of TAN 0 degrees not being 0!!!
+	if (_last_number < POS_ZERO && _last_number > NEG_ZERO)
+		_last_number = 0.0;
 
 	//if (errno == EDOM || errno == ERANGE)
 	//	_error = true;
@@ -906,110 +944,88 @@ void CalcEngine::Tangens(CALCAMNT input)
 
 void CalcEngine::TangensHyp(CALCAMNT input)
 {
-	_last_result = TANH(input);
+	_last_number = TANH(input);
 }
 
-
-void CalcEngine::Equal(CALCAMNT input)
+CALCAMNT CalcEngine::evalOperation(CALCAMNT arg1, Operation operation,
+				   CALCAMNT arg2)
 {
-	amount_stack.push(input);
-	_last_result = input;
-
-	UpdateStack(0);
-
-	precedence_base = 0;
+	if (!_percent_mode || Operator[operation].prcnt_ptr == NULL)
+	{
+		return (Operator[operation].arith_ptr)(arg1, arg2);
+	} else {
+		_percent_mode = false;
+		return (Operator[operation].prcnt_ptr)(arg1, arg2);
+	}
 }
 
-void CalcEngine::Percent(CALCAMNT input)
+void CalcEngine::enterOperation(CALCAMNT number, Operation func)
 {
-	percent_mode = true;
+	_node tmp_node;
+
+	if (func == FUNC_BRACKET)
+	{
+		tmp_node.number = 0;
+		tmp_node.operation = FUNC_BRACKET;
 	
-	Equal(input);
-}
+		_stack.push(tmp_node);
 
-void CalcEngine::EnterStackFunction(int func, CALCAMNT number)
-{
-	func_data new_item;
-	int new_precedence;
-
-	_last_result = number;
-
-	amount_stack.push(number);
+		return;
+	}
 	
-	new_item.item_function = func;
-	new_item.item_precedence = new_precedence = 
-		(precedence[func] + precedence_base);
-
-	//	refresh_display = true;
-	if (UpdateStack(new_precedence)) {
-	  ;//	UpdateDisplay();
+	if (func == FUNC_PERCENT)
+	{
+		_percent_mode = true;
 	}
 
-	func_stack.push(new_item);
+	tmp_node.number = number;
+	tmp_node.operation = func;
+	
+	_stack.push(tmp_node);
+
+	evalStack();
 }
 
-void CalcEngine::Xor(CALCAMNT input)
+bool CalcEngine::evalStack(void)
 {
-	EnterStackFunction(FUNC_XOR, input);
+	// this should never happen
+	if (_stack.isEmpty()) KMessageBox::error(0L, i18n("Stack processing error - empty stack"));
+
+	_node tmp_node = _stack.pop();
+
+	while (! _stack.isEmpty())
+	{
+		_node tmp_node2 = _stack.pop();
+		if (Operator[tmp_node.operation].precedence <=
+		    Operator[tmp_node2.operation].precedence)
+		{
+			if (tmp_node2.operation == FUNC_BRACKET) continue;
+			CALCAMNT tmp_result =
+			  evalOperation(tmp_node2.number, tmp_node2.operation,
+					tmp_node.number);
+			tmp_node.number = tmp_result;
+		}
+		else
+		{
+			_stack.push(tmp_node2);
+			break;
+		}  
+		  
+	}
+
+	if(tmp_node.operation != FUNC_EQUAL  &&  tmp_node.operation != FUNC_PERCENT)
+		_stack.push(tmp_node);
+
+	_last_number = tmp_node.number;
+	return true;
 }
 
 void CalcEngine::Reset()
 {
 	_error = false;
-	_last_result = 0L;
-	//decimal_point = 0;
-	//input_count = 0;
+	_last_number = 0L;
 
-	amount_stack.clear();
-	func_stack.clear();
+	_stack.clear();
 }
 
-int CalcEngine::UpdateStack(int run_precedence)
-{
-	CALCAMNT left_op	= 0.0;
-	CALCAMNT right_op 	= 0.0;
-	CALCAMNT new_value	= 0.0;
-	int op_function		= 0;
-	int return_value	= 0;
-
-
-	while ((func_stack.size() != 0) && 
-		(func_stack.top().item_precedence >= run_precedence))
-	{
-		return_value = 1;
-
-		if (amount_stack.isEmpty()) {
-			KMessageBox::error(0L, i18n("Stack processing error - right_op"));
-		}
-
-		right_op = amount_stack.pop();
-
-		if (func_stack.isEmpty()) {
-			KMessageBox::error(0L, i18n("Stack processing error - function"));
-		}
-
-		op_function = func_stack.pop().item_function;
-
-		if (amount_stack.isEmpty()) {
-			KMessageBox::error(0L, i18n("Stack processing error - left_op"));
-		}
-
-		left_op = amount_stack.pop();
-
-		if (!percent_mode || Prcnt_ops[op_function] == NULL) {
-			new_value = (Arith_ops[op_function])(left_op, right_op);
-		} else {
-			new_value = (Prcnt_ops[op_function])(left_op, right_op);
-			percent_mode = false;
-		}
-
-		amount_stack.push(new_value);
-	}
-
-	if (return_value)
-		_last_result = new_value;
-
-	//decimal_point = 1;
-	return return_value;
-}
 
