@@ -1,5 +1,5 @@
 /*
-    $Id: kcalcdisplay.cpp,v 1.6.2.5 2004/04/19 10:34:13 lukas Exp $
+    $Id: kcalcdisplay.cpp 381208 2005-01-22 13:42:57Z wheeler $
 
     KCalc, a scientific calculator for the X window system using the
     Qt widget libraries, available at no cost at http://www.troll.no
@@ -27,7 +27,9 @@
 #include <ctype.h>
 
 #include <qclipboard.h>
+#include <qregexp.h>
 
+#include <kglobal.h>
 #include <klocale.h>
 #include <knotifyclient.h>
 #include "kcalcdisplay.h"
@@ -51,22 +53,23 @@ static CALCAMNT toDouble(const QString &s, bool &ok)
 }
 
 KCalcDisplay::KCalcDisplay(QWidget *parent, const char *name)
-  :QLabel(parent,name), _button(0), _lit(false),
+  :QLabel(parent,name), _beep(false), _groupdigits(false), _button(0), _lit(false),
    _num_base(NB_DECIMAL), _input_limit(0),
    _display_size(DEC_SIZE), _precision(9),
-   _fixed_precision(-1), selection_timer(new QTimer)
+   _fixed_precision(-1), _error(false), selection_timer(new QTimer)
 {
 	setFrameStyle(QFrame::WinPanel | QFrame::Sunken);
 	setAlignment(AlignRight | AlignVCenter);
 	setFocus();
 	setFocusPolicy(QWidget::StrongFocus);
+	setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed, false);
 
 	connect(this, SIGNAL(clicked()), this, SLOT(slotDisplaySelected()));
 
 	connect(selection_timer, SIGNAL(timeout()),
 		this, SLOT(slotSelectionTimedOut()));
 
-	Reset();
+	sendEvent(EventReset);
 }
 
 KCalcDisplay::~KCalcDisplay()
@@ -74,6 +77,39 @@ KCalcDisplay::~KCalcDisplay()
 	delete selection_timer;
 }
 
+bool KCalcDisplay::sendEvent(Event const event)
+{
+	switch(event)
+	{
+	case EventReset:
+		_error = false;
+		_display_amount = 0.0;
+		_str_int = "0";
+		_str_int_exp = (char *)0;
+
+		_eestate = false;
+		_period = false;
+		_neg_sign = false;
+
+		updateDisplay();
+
+		return true;
+	case EventClear:
+		if (! _error) return sendEvent(EventReset);
+		return false;
+	case EventChangeSign:
+		return changeSign();
+	case EventError:
+		_error = true;
+		updateDisplay();
+
+		return true;
+	default:
+		return false;
+	}
+}
+
+
 void KCalcDisplay::slotCut(void)
 {
 	if(_error  &&  _beep)
@@ -83,7 +119,7 @@ void KCalcDisplay::slotCut(void)
 	}
 
 	slotCopy();
-	Reset();
+	sendEvent(EventReset);
 }
 
 void KCalcDisplay::slotCopy(void)
@@ -111,19 +147,29 @@ void KCalcDisplay::slotPaste(bool bClipboard)
 		return;
 	}
 
-	if (_num_base == NB_HEX)
-		tmp_str.prepend( "0x" );
+	if (_num_base == NB_HEX  &&  ! tmp_str.startsWith("0x", false))
+	  tmp_str.prepend( "0x" );
 
 	bool was_ok;
-	CALCAMNT tmp_result = toDouble(tmp_str, was_ok);
+	CALCAMNT tmp_result;
 
-	if (!was_ok)
+	if ( (_num_base == NB_OCTAL || _num_base == NB_BINARY) &&
+	     !  tmp_str.startsWith("0x",false))
 	{
-		tmp_result = (CALCAMNT) (0);
-		if(_beep) KNotifyClient::beep();		
+		tmp_result = CALCAMNT(tmp_str.toLongLong(& was_ok, _num_base));
+		if (!was_ok)
+		{
+			tmp_result = (CALCAMNT) (0);
+			if(_beep) KNotifyClient::beep();
+			return ;
+		}
+	  
+		setAmount(tmp_result);
+	} 
+	else
+	{
+		setAmount(tmp_str);
 	}
-
-	setAmount(tmp_result);
 }
 
 void KCalcDisplay::slotDisplaySelected(void)
@@ -188,17 +234,40 @@ void KCalcDisplay::setBeep(bool flag)
 	_beep = flag;
 }
 
+void KCalcDisplay::setGroupDigits(bool flag)
+{
+	_groupdigits = flag;
+}
+
 CALCAMNT KCalcDisplay::getAmount(void) const
 {
 	return _display_amount;
 }
 
+bool KCalcDisplay::setAmount(const QString &string)
+{
+	bool was_ok;
+	CALCAMNT tmp_result;
+
+	tmp_result = toDouble(string, was_ok);
+	
+	if (!was_ok)
+	{
+		tmp_result = (CALCAMNT) (0);
+		if(_beep) KNotifyClient::beep();
+		return false;
+	}
+	
+	setAmount(tmp_result);
+
+	return true;
+}
+
 bool KCalcDisplay::setAmount(CALCAMNT new_amount)
 {
-	if(_error)
-		return false;
+	if(_error) return false;
 
-	char display_str[DSP_SIZE+1];
+	QString display_str;
 
 	_str_int = "0";
 	_str_int_exp = (char *)0;
@@ -212,12 +281,14 @@ bool KCalcDisplay::setAmount(CALCAMNT new_amount)
 	{
 		CALCAMNT	tmp_round;
 		KCALC_LONG	rounded_num = 0;
-		int str_size;
 
 		MODF(_display_amount, &tmp_round);
 
 		if (tmp_round < KCALC_LONG_MIN || tmp_round > KCALC_ULONG_MAX)
-			_error = true;
+		{
+			sendEvent(EventError);
+			return false;
+		}
 
 		//
 		// We may be in that never-never land where boh numbers
@@ -236,71 +307,81 @@ bool KCalcDisplay::setAmount(CALCAMNT new_amount)
 			rounded_num = (KCALC_LONG)_display_amount;
 		}
 
-		switch(_num_base)
+		display_str = QString::number(rounded_num, _num_base).upper();
+		if (display_str.length() > DSP_SIZE)
 		{
-		case NB_BINARY:
-			str_size = cvb(display_str, rounded_num, DSP_SIZE);
-			break;
-
-		case NB_OCTAL:
-			str_size = snprintf(display_str, DSP_SIZE, PRINT_OCTAL, rounded_num);
-			break;
-
-		case NB_HEX:
-			str_size = snprintf(display_str, DSP_SIZE, PRINT_HEX, rounded_num);
-			break;
-		default:
-			_error = true;
-			str_size = -1;
-			break;
+			sendEvent(EventError);
+			return false;
 		}
-
-		if (str_size == -1) _error = true;
 	}
 	else // _num_base == NB_DECIMAL
 	{
-		int str_size;
+		// We need to use QCString here since it uses the systems native ::sprintf()
+		// implementation which is more flexible than QString's.
 
-		if (_fixed_precision != -1 && _display_amount <= 1.0e+16) {
-			str_size = snprintf(display_str, DSP_SIZE,
-					    PRINT_FLOAT,
-					    _fixed_precision,
-					    _display_amount);
-		} else if(_display_amount > 1.0e+16) {
-			// guard against _display_amount too large
-			// to prevent segfault. Such as from typing
-			// from 5*5*******
-			str_size = snprintf(display_str, DSP_SIZE,
-					    PRINT_LONG_BIG,
-					    _precision + 1,
-					    _display_amount);
-		} else {
-			str_size = snprintf(display_str, DSP_SIZE,
-					    PRINT_LONG_BIG, _precision,
-					    _display_amount);
+		if (_fixed_precision != -1 && _display_amount <= 1.0e+16)
+			display_str = QCString().sprintf(PRINT_FLOAT, _fixed_precision, _display_amount);
+		else if (_display_amount > 1.0e+16)
+			display_str = QCString().sprintf(PRINT_LONG_BIG, _precision + 1, _display_amount);
+		else
+			display_str = QCString().sprintf(PRINT_LONG_BIG, _precision, _display_amount);
+
+		if (display_str.length() > DSP_SIZE)
+		{
+			sendEvent(EventError);
+			return false;
 		}
-
-		if (str_size == -1) _error = true;
 	}
 
-	if(_error)
-	{
-		if(_beep) KNotifyClient::beep();
-		setText(i18n("Error"));
-		return false;
-	}
-	else
-	{
-		setText(display_str);
-		return true;
-	}
+	Q_ASSERT(_error == false);
+	setText(display_str);
+	return true;
 	
 }
 
 void KCalcDisplay::setText(QString const &string)
 {
-	QLabel::setText(string);
-	emit changedText(string);
+	QString localizedString = string;
+
+	// Only treat digits (skip the sign)
+	int first_digit = localizedString.find(QRegExp("\\d"));
+	
+	// If we aren't in decimal mode, we don't need to modify the string
+	if (_num_base == NB_DECIMAL  &&  !_error
+	    &&  _groupdigits  &&  first_digit != -1)
+	{
+		// Obtain decimal symbol and thousands separator
+		QString decimalSymbol = KGlobal::locale()->decimalSymbol();
+		QString thousandsSeparator = KGlobal::locale()->thousandsSeparator();
+		// Replace dot with locale decimal separator
+		localizedString.replace(QChar('.'),decimalSymbol);
+	
+		// Insert the thousand separators
+                int decimalSymbolPos = localizedString.find(decimalSymbol);
+                int eSymbolPos = localizedString.find('e');
+
+                if (-1 == decimalSymbolPos)
+                    decimalSymbolPos = localizedString.length();
+                if (-1 == eSymbolPos)
+                    eSymbolPos = localizedString.length();
+
+                int pos = QMIN((decimalSymbolPos - 1), (eSymbolPos-1));
+                
+		for(int index=1;pos>first_digit;pos--,index++)
+			if (index%3 == 0)
+				localizedString.insert(pos,thousandsSeparator);
+	}
+
+	QLabel::setText(localizedString);
+	emit changedText(localizedString);
+}
+
+QString KCalcDisplay::text() const
+{
+	if (_num_base != NB_DECIMAL || _error)
+		return QLabel::text();
+
+	return QCString().sprintf(PRINT_LONG_BIG, 40, _display_amount);
 }
 
 /* change representation of display to new base (i.e. binary, decimal,
@@ -585,8 +666,14 @@ void KCalcDisplay::deleteLastDigit(void)
 	updateDisplay();
 }
 
-void KCalcDisplay::changeSign(void)
+// change Sign of display. Problem: Only possible here, when in input
+// mode. Otherwise return 'false' so that the kcalc_core can handle
+// things.
+bool KCalcDisplay::changeSign(void)
 {
+	//stupid way, to see if in input_mode or display_mode
+	if (_str_int == "0") return false;
+
 	if(_eestate)
 	{
 		if(!_str_int_exp.isNull())
@@ -603,96 +690,11 @@ void KCalcDisplay::changeSign(void)
 	}
 	
 	updateDisplay();
-}
 
-bool KCalcDisplay::clearLastInput(void)
-{
-	if (_error)
-	{
-		return updateDisplay();
-	}
-	else
-	{
-		_period	= false;
-		_eestate = false;
-		_neg_sign = false;
-		_str_int = "0";
-		_str_int_exp = (char *)0;
-		return updateDisplay();
-	}
-}
-
-void KCalcDisplay::setError(bool error)
-{
-	_error = error;
-	updateDisplay();
+	return true;
 }
 
 bool KCalcDisplay::getError(void) const
 {
 	return _error;
 }
-
-int KCalcDisplay::cvb(char *out_str, KCALC_LONG amount, int max_digits)
-{
-	/*
-	* A routine that converts a long int to
-	* binary display format
-	*/
-
-	bool hitOne		= false;
-	unsigned KCALC_LONG bit_mask =
-		((unsigned KCALC_LONG) 1 << (BIN_SIZE - 1));
-	unsigned KCALC_LONG bit_mask_mask = bit_mask - 1;
-	unsigned int count = 0 ;
-
-	while(bit_mask != 0 && max_digits > 0)
-	{
-		char tmp = (bit_mask & amount) ? '1' : '0';
-
-		// put a space every 4th digit
-		if (hitOne && ((count & 3) == 0))
-			*out_str++ = ' ';
-			
-		count++;
-
-		if(!hitOne && tmp == '1')
-			hitOne = true;
-
-		if(hitOne)
-			*out_str++ = tmp;
-
-		bit_mask >>= 1;
-
-		// this will fix a prob with some processors using an
-		// arithmetic right shift (which would maintain sign on
-		// negative numbers and cause a loop that's too long)
-		bit_mask &= bit_mask_mask; //Sven: Uwe's Alpha adition
-
-		max_digits--;
-	}
-
-	if(amount == 0)
-		*out_str++ = '0';
-
-	*out_str = '\0';
-
-	return count;
-}
-
-
-void KCalcDisplay::Reset(void)
-{
-	// This updates display through setError.
-	// Should one explicitly call UpdateDisplay to be nicer?
-
-	_display_amount = 0.0;
-	_str_int = "0";
-	_str_int_exp = (char *)0;
-
-	_eestate = false;
-	_period = false;
-	_neg_sign = false;
-
-	setError(false);
-}
