@@ -1,5 +1,5 @@
 /*
-    $Id: stats.h,v 1.8 2001/12/16 00:53:32 mueller Exp $
+    $Id: stats.h 212185 2003-03-07 22:11:39Z waba $
 
     KCalc, a scientific calculator for the X window system using the
     Qt widget libraries, available at no cost at http://www.troll.no
@@ -19,58 +19,42 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
 #ifndef KSTATS_H
 #define KSTATS_H
 
-#include <qptrlist.h>
-#include <math.h>
+#include <qvaluevector.h>
 #include "kcalctype.h"
 
-class KStats
-{
+class KStats {
 
 public:
-
-    KStats();
-    ~KStats();
+	KStats();
+	~KStats();
 
 public:
-
-    void clearAll();
-    void enterData(CALCAMNT data);
-    void clearLast();
-    CALCAMNT sum();
-    CALCAMNT sum_of_squares();
-    CALCAMNT mean();
-    CALCAMNT median();
-    CALCAMNT std_kernel();
-    CALCAMNT std();
-    CALCAMNT sample_std();
-    int	     count();
-    bool     error();
+	void clearAll();
+	void enterData(CALCAMNT data);
+	void clearLast();
+	CALCAMNT sum();
+	CALCAMNT sum_of_squares();
+	CALCAMNT mean();
+	CALCAMNT median();
+	CALCAMNT std_kernel();
+	CALCAMNT std();
+	CALCAMNT sample_std();
+	int	     count();
+	bool     error();
 
 private:
-
-    QPtrList<CALCAMNT> data;
+    QValueVector<CALCAMNT> mData;
     bool error_flag;
 
 };
 
-class MyList : public  QPtrList<CALCAMNT> 
-{
-
-public:
-
-  MyList() : QPtrList<CALCAMNT>() {};
-  
-protected:
-  int compareItems(Item item1,Item item2);
-};
-
 
 #endif /*KSTATS_H*/
 
