@@ -1,8 +1,6 @@
 /*
  * kdfwidget.cpp
  *
- * $Id: kdfwidget.cpp,v 1.40 2003/10/03 16:25:15 aacid Exp $
- *
  * Copyright (c) 1998-2001 Michael Kropfberger <michael.kropfberger@gmx.net>
  *
  * Requires the Qt widget libraries, available at no cost at
@@ -62,37 +60,26 @@ CListViewItem::CListViewItem( CListView * parent, QListViewItem * after )
   :QListViewItem( parent, after )
 {}
 
-// 2001-03-10 Walter F.J. Mueller <W.F.J.Mueller@gsi.de>
-// This method returns for all numeric columns the converted number.
-// The conversion is done with
-//    1. fixed position of the colon
-//    2. a sufficient number of leading blanks
-// This ensures that the lexical string comparison gives numerical order.
-
-QString CListViewItem::key ( int column, bool ) const
+int CListViewItem::compare ( QListViewItem *i, int column, bool ) const
 {
   QString tmp;
 
+  CListViewItem *c = static_cast<CListViewItem*>(i);
+
   switch (column) {
   case KDFWidget::sizeCol:
-    tmp.sprintf("%10d",size);
-    break;
+    return (size==c->size) ? 0 : (size<c->size) ? -1 : 1;
 
   case KDFWidget::freeCol:
-    tmp.sprintf("%10d",avail);
-    break;
+    return (avail==c->avail) ? 0 : (avail<c->avail) ? -1 : 1;
 
   case KDFWidget::fullCol:
   case KDFWidget::usageCol:
-    tmp.sprintf("%7.2f",full);
-    break;
+    return (full==c->full) ? 0 : (full<c->full) ? -1 : 1;
 
   default:
-    tmp = text(column);
-    break;
+    return key(column,true).compare(i->key(column,true));
   }
-
-  return tmp;
 }
 
 void CListViewItem::setKeys (int kb_size, int kb_avail, float percent_full)
@@ -135,10 +122,10 @@ KDFWidget::KDFWidget( QWidget *parent, const char *name, bool init )
     mList->setFrameStyle( QFrame::WinPanel + QFrame::Sunken );
     mList->setShowSortIndicator(true);
     connect( mList,
-      SIGNAL( pressed( QListViewItem *, const QPoint &, int )),
+      SIGNAL( rightButtonPressed( QListViewItem *, const QPoint &, int )),
       this, SLOT( rightButtonPressed( QListViewItem *, const QPoint &, int )));
     connect( mList,
-      SIGNAL( clicked( QListViewItem *, const QPoint &, int )),
+      SIGNAL( rightButtonClicked( QListViewItem *, const QPoint &, int )),
       this, SLOT( rightButtonClicked( QListViewItem *, const QPoint &, int )));
     connect( mList->header(), SIGNAL(sizeChange(int, int, int)),
       this, SLOT(columnSizeChanged(int, int, int)) );
@@ -218,11 +205,6 @@ void KDFWidget::applySettings( void )
   KConfig &config = *kapp->config();
 
   config.setGroup("KDiskFree");
-  if( mIsTopLevel == true )
-  {
-    config.writeEntry( "Width", width() );
-    config.writeEntry( "Height", height() );
-  }
   if( GUI )
   {
     for( uint i=0; i<mTabProp.size(); i++ )
@@ -251,13 +233,6 @@ void KDFWidget::loadSettings( void )
   {
     KConfig &config = *kapp->config();
     config.setGroup("KDiskFree");
-    if( mIsTopLevel == true )  // only "kdf" can be resized
-    {
-      int w  = config.readNumEntry("Width",width());
-      int h = config.readNumEntry("Height",height());
-      resize( w, h );
-    }
-
     for( uint i=0; i<mTabProp.size(); i++ )
     {
       CTabEntry &e = *mTabProp[i];
