@@ -1,8 +1,8 @@
 /*
     KFloppy
-    Copyright (C) 1997 Bernd Johannes Wuebben
-                       wuebben@math.cornell.edu
-
+    
+    Copyright (C) 1997 Bernd Johannes Wuebben <wuebben@math.cornell.edu>
+    Copyright (C) 2004 Nicolas GOUTTE <goutte@kde.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,12 +23,10 @@
 
 #include <qlayout.h>
 #include <qcheckbox.h>
-#include <qlineedit.h>
 #include <qlabel.h>
 #include <qcursor.h>
 #include <qradiobutton.h>
 #include <qbuttongroup.h>
-#include <qcombobox.h>
 
 #include <kconfig.h>
 
@@ -40,8 +38,10 @@
 #include <kapplication.h>
 #include <kprogress.h>
 #include <klocale.h>
+#include <kcombobox.h>
+#include <klineedit.h>
 
-#include "floppy.moc"
+#include "floppy.h"
 #include "format.h"
 
 FloppyData::FloppyData(QWidget * parent, const char * name)
@@ -50,10 +50,7 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
 {
 
 	formating = false;
-	quickerase = false;
-	abort = false;
-	counter = 0;
-	tracks = 0;
+	//abort = false;
 	blocks = 0;
 
         QVBoxLayout* ml = new QVBoxLayout( this, 10 );
@@ -70,8 +67,8 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
         g1->addWidget( label1, 0, 0, AlignLeft );
 
 
-	deviceComboBox = new QComboBox( false, this, "ComboBox_1" );
-	g1->addWidget( deviceComboBox, 0, 1, AlignLeft );
+	deviceComboBox = new KComboBox( false, this, "ComboBox_1" );
+	g1->addWidget( deviceComboBox, 0, 1 );
 
 	deviceComboBox->insertItem(i18n("Primary"));
 	deviceComboBox->insertItem(i18n("Secondary"));
@@ -80,9 +77,12 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
 	label2->setText(i18n("Size:"));
         g1->addWidget( label2, 1, 0, AlignLeft );
 
-	densityComboBox = new QComboBox( false, this, "ComboBox_1" );
-	g1->addWidget( densityComboBox, 1, 1, AlignLeft );
+	densityComboBox = new KComboBox( false, this, "ComboBox_1" );
+	g1->addWidget( densityComboBox, 1, 1 );
 
+#if defined(ANY_LINUX)
+	densityComboBox->insertItem( i18n( "Auto-Detect" ) );
+#endif
 	densityComboBox->insertItem(i18n("3.5\" 1.44MB"));
 	densityComboBox->insertItem(i18n("3.5\" 720KB"));
 	densityComboBox->insertItem(i18n("5.25\" 1.2MB"));
@@ -93,24 +93,59 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
 	label3->setText(i18n("File system:"));
         g1->addWidget( label3, 2, 0, AlignLeft );
 
-	filesystemComboBox = new QComboBox( false, this, "ComboBox_2" );
-	g1->addWidget( filesystemComboBox, 2, 1, AlignLeft );
+	filesystemComboBox = new KComboBox( false, this, "ComboBox_2" );
+	g1->addWidget( filesystemComboBox, 2, 1 );
+	g1->setColStretch(1, 1);
 
+        // If you modify the user visible string, change them also (far) below
+
+        QString userFeedBack;
         uint numFileSystems = 0;
 
+#if defined(ANY_LINUX)
         if (FATFilesystem::runtimeCheck()) {
             filesystemComboBox->insertItem(i18n("DOS"));
             ++numFileSystems;
+            userFeedBack += i18n( "Linux", "Program mkdosfs found." );
         }
-#if defined(ANY_LINUX)
+        else {
+            userFeedBack += i18n( "Linux", "Program mkdosfs <b>not found</b>. MSDOS formatting <b>not available</b>." );
+        }
+        userFeedBack += "<br>";
         if (Ext2Filesystem::runtimeCheck()) {
             filesystemComboBox->insertItem(i18n("ext2"));
             ++numFileSystems;
+            userFeedBack += i18n( "Linux", "Program mke2fs found." );
+        }
+        else {
+            userFeedBack += i18n( "Linux", "Program mke2fs <b>not found</b>. Ext2 formatting <b>not available</b>" );
+        }
+        userFeedBack += "<br>";
+        if (MinixFilesystem::runtimeCheck()) {
+            filesystemComboBox->insertItem(i18n("Minix"));
+            ++numFileSystems;
+            userFeedBack += i18n( "Linux", "Program mkfs.minix found." );
+        }
+        else {
+            userFeedBack += i18n( "Linux", "Program mkfs.minix <b>not found</b>. Minix formatting <b>not available</b>" );
         }
 #elif defined(ANY_BSD)
+        if (FATFilesystem::runtimeCheck()) {
+            filesystemComboBox->insertItem(i18n("DOS"));
+            ++numFileSystems;
+            userFeedBack += i18n( "BSD", "Program newfs_msdos found." );
+        }
+        else {
+            userFeedBack += i18n( "BSD", "Program newfs_msdos <b>not found</b>. MSDOS formatting <b>not available</b>." );
+        }
+        userFeedBack += "<br>";
         if (UFSFilesystem::runtimeCheck()) {
             filesystemComboBox->insertItem(i18n("UFS"));
             ++numFileSystems;
+            userFeedBack += i18n( "BSD", "Program newfs found." );
+        }
+        else {
+            userFeedBack += i18n( "BSD", "Program newfs <b>not found</b>. UFS formatting <b>not available</b>." );
         }
 #endif
 
@@ -129,14 +164,18 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
 	fullformat = new QRadioButton( buttongroup, "RadioButton_3" );
 	fullformat->setText(i18n( "Fu&ll format") );
         v2->addWidget( fullformat, AlignLeft );
-        
+
+        // ### TODO: we need some user feedback telling why full formatting is disabled.
+        userFeedBack += "<br>";
         m_canLowLevel = FDFormat::runtimeCheck();
         if (m_canLowLevel){
             fullformat->setChecked(true);
+            userFeedBack += i18n( "Program fdformat found." );
         }
         else {
             fullformat->setDisabled(true);
             quick->setChecked(true);
+            userFeedBack += i18n( "Program fdformat <b>not found</b>. Full formatting <b>disabled</b>." );
         }
         
 	verifylabel = new QCheckBox( buttongroup, "RadioButton_4" );
@@ -152,10 +191,9 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
         QHBoxLayout* h2 = new QHBoxLayout( v2 );
         h2->addSpacing( 20 );
 
-	lineedit = new QLineEdit( buttongroup, "Lineedit" );
-	lineedit->setText(i18n( "KDE Floppy") );
-	lineedit->setMaxLength(11); // ### TODO: translators need to need this limit!!!
-        lineedit->setMinimumWidth( lineedit->sizeHint().width() );
+	lineedit = new KLineEdit( buttongroup, "Lineedit" );
+	lineedit->setText(i18n( "Volume label, maximal 11 characters", "KDE Floppy" ) );
+	lineedit->setMaxLength(11);
         h2->addWidget( lineedit, AlignRight );
 
 	connect(labellabel,SIGNAL(toggled(bool)),lineedit,SLOT(setEnabled(bool)));
@@ -188,33 +226,32 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
         ml->addSpacing( 10 );
 
 	frame = new QLabel( this, "NewsWindow" );
-	frame->setMinimumHeight( 50 );
 	frame->setFrameStyle(QFrame::Panel | QFrame::Sunken);
-	frame->setAlignment(AlignCenter|WordBreak|ExpandTabs);
+	frame->setAlignment(WordBreak|ExpandTabs);
+
+        QString frameText( userFeedBack );
+        frameText.prepend( "<qt>" );
+        frameText.append( "</qt>" );
+        frame->setText( frameText );
+        
         ml->addWidget( frame );
 
 	progress = new KProgress( this, "Progress" );
-        progress->setMinimumHeight( 30 );
+        progress->setDisabled( true );
         ml->addWidget( progress );
 
 	readSettings();
 	setWidgets();
 
     if (!numFileSystems) {
-        // ### TODO: better error message
-        KMessageBox::error(this,
-            i18n("KFloppy cannot find the support programs needed "
-                    "for sensible operation."));
+        QString errorMessage;
+        errorMessage += "<qt>";
+        errorMessage += i18n("KFloppy cannot find any of the needed programs for creating file systems; please check your installation.<br><br>Log:");
+        errorMessage += "<br>";
+        errorMessage += userFeedBack;
+        errorMessage += "</qt>";
+        KMessageBox::error( this, errorMessage );
     }
-
-    int maxW = QMAX( deviceComboBox->sizeHint().width(),
-                     densityComboBox->sizeHint().width() );
-    maxW = QMAX( maxW, filesystemComboBox->sizeHint().width() );
-    deviceComboBox->setMinimumWidth( maxW );
-    densityComboBox->setMinimumWidth( maxW );
-    filesystemComboBox->setMinimumWidth( maxW );
-
-    setMinimumSize(minimumSizeHint());
 }
 
 
@@ -274,7 +311,11 @@ bool FloppyData::findDevice()
     if( densityComboBox->currentText() == i18n("5.25\" 360KB")){
       blocks = 360;
       }
-
+#if defined(ANY_LINUX)
+    else { // For Linux, anything else is Auto
+        blocks = 0;
+    }
+#endif
 
   return true;
 }
@@ -317,10 +358,11 @@ void FloppyData::setEnabled(bool b)
   fullformat->setEnabled(b && m_canLowLevel);
   verifylabel->setEnabled(b);
   labellabel->setEnabled(b);
-  lineedit->setEnabled(b);
+  lineedit->setEnabled(b && labellabel->isChecked() );
   helpbutton->setEnabled(b);
   quitbutton->setEnabled(b);
   formatbutton->setEnabled(b);
+  progress->setDisabled( b ); // The other way round!
 }
 
 void FloppyData::reset()
@@ -328,7 +370,6 @@ void FloppyData::reset()
   DEBUGSETUP;
 
   formating = false;
-  quickerase = false;
 
   if (formatActions)
   {
@@ -344,12 +385,8 @@ void FloppyData::reset()
 
 void FloppyData::format(){
 
-  errstring = "";
-  formatstring ="";
-  //mdev = "";
-
   if(formating){
-    abort = true;
+    //abort = true;
     reset();
     return;
   }
@@ -383,7 +420,6 @@ void FloppyData::format(){
 
 	if (quick->isChecked())
 	{
-		quickerase=true;
 		formating=false;
 		// No fdformat to push
 	}
@@ -395,7 +431,7 @@ void FloppyData::format(){
 		formatActions->queue(f);
 	}
 
-	if (filesystemComboBox->currentItem() == 0)
+	if ( filesystemComboBox->currentText() == i18n("DOS") )
 	{
 		FATFilesystem *f = new FATFilesystem(this);
 		connect(f,SIGNAL(status(const QString &,int)),
@@ -408,20 +444,29 @@ void FloppyData::format(){
 		f->configureDevice(drive,blocks);
 		formatActions->queue(f);
 	}
-	else if (filesystemComboBox->currentItem() == 1)
-	{
-		FloppyAction *f = 0L;
 #ifdef ANY_LINUX
-		Ext2Filesystem *e2f = new Ext2Filesystem(this);
-		e2f->configure(verifylabel->isChecked(),
+	else if ( filesystemComboBox->currentText() == i18n("ext2") )
+	{
+		Ext2Filesystem *f = new Ext2Filesystem(this);
+		f->configure(verifylabel->isChecked(),
 			labellabel->isChecked(),
 			lineedit->text());
-		f=e2f;
-#else
+		if (f)
+		{
+			connect(f,SIGNAL(status(const QString &,int)),
+				this,SLOT(formatStatus(const QString &,int)));
+			connect(f,SIGNAL(done(KFAction *,bool)),
+				this,SLOT(reset()));
+			f->configureDevice(drive,blocks);
+			formatActions->queue(f);
+		}
+	}
+#endif
+
 #ifdef ANY_BSD
-		f = new UFSFilesystem(this);
-#endif
-#endif
+	else if ( filesystemComboBox->currentText() == i18n("UFS") )
+	{
+		FloppyAction *f = new UFSFilesystem(this);
 
 		if (f)
 		{
@@ -433,6 +478,26 @@ void FloppyData::format(){
 			formatActions->queue(f);
 		}
 	}
+#endif
+
+#ifdef ANY_LINUX
+	else if ( filesystemComboBox->currentText() == i18n("Minix") )
+	{
+		MinixFilesystem *f = new MinixFilesystem(this);
+		f->configure(verifylabel->isChecked(),
+			labellabel->isChecked(),
+			lineedit->text());
+		if (f)
+		{
+			connect(f,SIGNAL(status(const QString &,int)),
+				this,SLOT(formatStatus(const QString &,int)));
+			connect(f,SIGNAL(done(KFAction *,bool)),
+				this,SLOT(reset()));
+			f->configureDevice(drive,blocks);
+			formatActions->queue(f);
+		}
+	}
+#endif
 
 
 
@@ -441,6 +506,7 @@ void FloppyData::format(){
 
 void FloppyData::formatStatus(const QString &s,int p)
 {
+    kdDebug(2002) << "FloppyData::formatStatus: " << s << " : "  << p << endl;
 	if (!s.isEmpty())
 		frame->setText(s);
 
@@ -448,270 +514,6 @@ void FloppyData::formatStatus(const QString &s,int p)
 		progress->setValue(p);
 }
 
-#if 0
-void FloppyData::readStdout(KProcess *, char *buffer, int buflen)
-{
-  bool increment = true;
-
-  formatstring = QString::fromLocal8Bit(buffer, buflen);
-
-  if (formatstring.contains("track"))
-  {
-    int pos = formatstring.find('\n');
-    QString newstring;
-
-    if(pos != -1)
-      newstring = formatstring.left(pos);
-    else
-      newstring = formatstring;
-
-    frame->setText(newstring);
-    increment =false;
-  }
-
-
-  if (increment)
-  {
-    counter ++;
-    progress->setValue(counter);
-  }
-
-  kdDebug(2002) << "STDOUT: " << formatstring << endl;
-}
-
-void FloppyData::readStderr(KProcess *, char *buffer, int buflen){
-
-  char mybuffer[1001];
-  int amount;
-
-
-  if(buflen > 1000)
-    amount = 1000;
-  else
-    amount = buflen;
-
-  memcpy(mybuffer,buffer,amount);
-  mybuffer[amount] = '\0';
-
-  abort = true;
-  errstring  +=mybuffer;
-
-
-  errtimer->start(300,true);
-
-  kdDebug(2002) << "STDERR: " << mybuffer << endl;
-}
-
-void FloppyData::errslot(){
-
-  abort = true;
-
-  if(errstring.contains("ioctl(FDFMTBEG)")){
-
-    QString str = i 18n(
-		"Cannot access floppy or floppy drive.\n"
-		"Please insert a floppy and make sure that you "
-		"have selected a valid floppy drive.");
-
-    KMessageBox::error(this, str);
-
-    reset();
-    return;
-
-  }
-
-  QString str = i 18n("Cannot format: %1\n%2").arg(drive).arg(errstring);
-
-  KMessageBox::error(this, str);
-
-  reset();
-}
-
-void FloppyData::readfsStdout(KProcess *, char *buffer, int buflen){
-  char mybuffer[1001];
-  int amount;
-
-  if(buflen > 1000)
-    amount = 1000;
-  else
-    amount = buflen;
-
-  memcpy(mybuffer,buffer,amount);
-  mybuffer[amount] = '\0';
-
-  fsstring += mybuffer;
-  if( fsstring.find('\n') == -1)
-    return;
-
-  QString string ;
-  QString newstring = fsstring;
-
-
-  int i;
-
-  while( (i =newstring.find('\n')) != -1){
-
-    QString mystring;
-    mystring = newstring.left(i);
-
-    kdDebug(2002) << "NEWLINE: " << mystring.data() << endl;
-
-    if(findKeyWord(mystring,"BBF ")){
-      int bblock = mystring.left(8).toInt();
-      QString mstr;
-      mstr = i 18n("Block %1 is bad. Continuing...").arg(bblock);
-      frame->setText(mstr);
-    }
-
-    if(findKeyWord(mystring,"TNBB ")){
-      badblocks = mystring.left(8).toInt();
-    }
-    newstring = newstring.mid(i+1,newstring.length());
-  }
-
-  counter += findKeyWord(fsstring,"BLOCK");
-
-  kdDebug(2002) << "Block Counter: " << counter << endl;
-
-  if(quickerase){
-
-    if(findKeyWord(fsstring,"START"))
-      counter ++;
-
-    if(findKeyWord(fsstring,"EXIT"))
-      counter ++;
-
-
-  }
-
-  fsstring = newstring;
-
-  progress->setValue(counter);
-
-  kdDebug(2002) << "STDOUT: " << mybuffer << endl;
-}
-
-
-void FloppyData::readfsStderr(KProcess *, char *buffer, int buflen){
-
-  char mybuffer[1001];
-  int amount;
-
-
-  if(buflen > 1000)
-    amount = 1000;
-  else
-    amount = buflen;
-
-  memcpy(mybuffer,buffer,amount);
-  mybuffer[amount] = '\0';
-
-  // skip version message
-  int pos=0;
-  if (fserrstring.isEmpty() && strncmp(mybuffer, "mke2fs", 6) == 0)
-    {
-      pos = QString(mybuffer).find('\n');
-      if (pos+1 == amount)
-	return;
-      pos++;
-    }
-  if (fserrstring.isEmpty() && strncmp(mybuffer, "/sbin/mkdosfs", 13) == 0)
-    {
-      pos = QString(mybuffer).find('\n');
-      if (pos+1 == amount)
-	return;
-      pos++;
-    }
-
-  abort = true;
-  fserrstring += mybuffer+pos;
-
-  // the timers are put in so that I get all of the error message.
-  fserrtimer->start(300,true);
-
-  kdDebug(2002) << "STDOUT: " << mybuffer << endl;
-}
-
-void FloppyData::fserrslot(){
-
-
-  if(fserrstring.contains("No such device")){
-
-    QString str = i 18n(
-		"Cannot access floppy or floppy drive.\n"
-		"Please insert a floppy and make sure that you "
- 		"have selected a valid floppy drive.");
-
-    KMessageBox::sorry(this, str);
-
-    reset();
-    return;
-  }
-
-  reset();
-
-  QString str = i 18n("Cannot create a filesystem on: %1\n%2")
-	      .arg(drive).arg(fserrstring);
-
-  KMessageBox::error(this, str);
-}
-
-
-void FloppyData::cfdone(KProcess*){
-
-    mytimer->start(10,true);
-
-}
-
-void FloppyData::cf2done(){
-
-
-  bool lcquick;
-  lcquick = quickerase;
-
-  mytimer->stop();
-
-  reset();
-
-  if(abort)
-    return;
-
-  if(!lcquick){
-    QString str = i 18n(
-		"The floppy was successfully formatted.\n"
-		"Blocks marked bad: %1\n"
-		"Raw Capacity: %2\n")
-		.arg(badblocks)
-		.arg((blocks - badblocks)*1024);
-
-    KMessageBox::information(this, str);
-  }
-  else{
-    QString str = i 18n("All files were successfully erased.");
-
-    KMessageBox::information(this, str);
-  }
-}
-
-int FloppyData::findKeyWord(QString & string,const QString & word){
-
-  int count = 0;
-  int index = 0;
-  int len = 0;
-
-  QString wordstring = word;
-  len = wordstring.length();
-
-  while( (index = string.find(word)) >= 0)
-  {
-    count++;
-    string = string.mid(index + len,string.length());
-  }
-
-  return count;
-}
-#endif
-
 void FloppyData::writeSettings(){
 
         config = kapp->config();
@@ -753,12 +555,11 @@ void FloppyData::readSettings(){
 
 	verifyconfig = config->readNumEntry("Verify", 1);
 	labelconfig = config->readNumEntry("CreateLabel",1);
-	labelnameconfig = config->readEntry("Label",i18n("KDE Floppy"));
+	labelnameconfig = config->readEntry( "Label", i18n("Volume label, maximal 11 characters", "KDE Floppy") );
 	quickformatconfig = config->readNumEntry("QuickFormat",0);
-	driveconfig = config->readEntry("FloppyDrive","A: 3.5");
-	densityconfig = config->readEntry("Density",i18n("HD"));
-	filesystemconfig = config->readEntry("Filesystem",i18n("Dos"));
-
+	driveconfig = config->readEntry( "FloppyDrive", i18n("Primary") );
+	densityconfig = config->readEntry( "Density", i18n("3.5\" 1.44MB") );
+	filesystemconfig = config->readEntry( "Filesystem", i18n("DOS") );
 }
 
 void FloppyData::setWidgets(){
@@ -771,22 +572,22 @@ void FloppyData::setWidgets(){
   lineedit->setText(labelnameconfig);
 
   for(int i = 0 ; i < deviceComboBox->count(); i++){
-    if ( (QString) deviceComboBox->text(i) == driveconfig){
+    if ( deviceComboBox->text(i) == driveconfig){
       deviceComboBox->setCurrentItem(i);
     }
   }
 
   for(int i = 0 ; i < filesystemComboBox->count(); i++){
-    if ( (QString) filesystemComboBox->text(i) == filesystemconfig){
+    if ( filesystemComboBox->text(i) == filesystemconfig){
       filesystemComboBox->setCurrentItem(i);
     }
   }
 
   for(int i = 0 ; i < densityComboBox->count(); i++){
-    if ( (QString) densityComboBox->text(i) == densityconfig){
+    if ( densityComboBox->text(i) == densityconfig){
       densityComboBox->setCurrentItem(i);
     }
   }
 }
 
-
+#include "floppy.moc"
