@@ -1,9 +1,9 @@
 /*
 
     KFloppy
-    Copyright (C) 2002 Adriaan de Groot
-                       groot@kde.org
-
+    
+    Copyright (C) 2002 Adriaan de Groot <groot@kde.org>
+    Copyright (C) 2004, 2005 Nicolas GOUTTE <goutte@kde.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@
 #include <kdebug.h>
 #include <kstandarddirs.h>
 
-#include "format.moc"
+#include "format.h"
 
 static QString extPath = QString::null;
 
@@ -133,6 +133,7 @@ void KFActionQueue::queue(KFAction *p)
 
 	if (!success)
 	{
+            // ### TODO: the user must be told that the action has failed.
 		DEBUGS("Action failed.");
 		emit done(this,false);
 		return;
@@ -145,7 +146,7 @@ void KFActionQueue::queue(KFAction *p)
 	}
 	else
 	{
-		DEBUGS("  Running action " << next->name());
+		kdDebug(KFAREA) << "Running action " << next->name() << endl;
 		QObject::connect(next,SIGNAL(done(KFAction *,bool)),
 			this,SLOT(actionDone(KFAction *,bool)));
 		// Propagate signals
@@ -164,16 +165,23 @@ void KFActionQueue::queue(KFAction *p)
 //
 //
 #ifdef ANY_LINUX
-const char *fd0H1440[] = { "/dev/fd0h1440", "/dev/fd0H1440", "/dev/fd0u1440", 0L } ;
-const char *fd0D720[]={ "/dev/fd0u720", "/dev/fd0D720", 0L };
-const char *fd0h1200[]={ "/dev/fd0h1200", 0L };
-const char *fd0h360[]={ "/dev/fd0h360", 0L };
-const char *fd1H1440[] = { "/dev/fd1h1440", "/dev/fd1H1440", "/dev/fd0u1440", 0L } ;
-const char *fd1D720[]={ "/dev/fd0u720", "/dev/fd1D720", 0L };
-const char *fd1h1200[]={ "/dev/fd1h1200", 0L };
-const char *fd1h360[]={ "/dev/fd1h360", 0L };
+
+const char *fd0H1440[] = { "/dev/fd0u1440", "/dev/floppy/0u1440", "/dev/fd0h1440", "/dev/fd0H1440", 0L } ;
+const char *fd0D720[] = { "/dev/fd0u720", "/dev/floppy/0u720", "/dev/fd0D720", "/dev/fd0h720", 0L };
+const char *fd0h1200[] = { "/dev/fd0h1200", "/dev/floppy/0h1200", 0L };
+const char *fd0h360[] = { "/dev/fd0u360", "/dev/floppy/0u360", "/dev/fd0h360", "/dev/fd0d360", 0L };
+
+const char *fd1H1440[] = { "/dev/fd1u1440", "/dev/floppy/1u1440","/dev/fd1h1440", "/dev/fd1H1440", 0L } ;
+const char *fd1D720[] = { "/dev/fd1u720", "/dev/floppy/1u720", "/dev/fd1D720", "/dev/fd1h720", 0L };
+const char *fd1h1200[] = { "/dev/fd1h1200", "/dev/floppy/1h1200", 0L };
+const char *fd1h360[] = { "/dev/fd1u360", "/dev/floppy/1u360","/dev/fd1h360", "/dev/fd1d360", 0L };
+
+const char *fd0auto[] = { "/dev/fd0", 0L };
+const char *fd1auto[] = { "/dev/fd1", 0L };
+
 #endif
 
+
 #ifdef ANY_BSD
 const char *fd0[] = { "/dev/fd0", 0L } ;
 const char *fd1[] = { "/dev/fd1", 0L } ;
@@ -204,6 +212,8 @@ fdinfo fdtable[] =
 	{ fd1h1200, 1, 1200, 80, 0 },
 	{ fd0h360,  0,  360, 40, 0 },
 	{ fd1h360,  1,  360, 40, 0 },
+	{ fd0auto,  0,    0, 80, 0 },
+	{ fd1auto,  1,    0, 80, 0 },
 #endif
 
 #ifdef ANY_BSD
@@ -282,7 +292,7 @@ bool FloppyAction::configureDevice(int drive,int density)
 	{
 		if (access(*devices,W_OK)>=0)
 		{
-			DEBUGS(QString("  Found device %1").arg(*devices).latin1());
+			kdDebug(KFAREA) << "Found device " << *devices << endl;
 			devicename=*devices;
 			break;
 		}
@@ -290,7 +300,7 @@ bool FloppyAction::configureDevice(int drive,int density)
 
 	if (!devicename)
 	{
-		QString str = i18n(
+		const QString str = i18n(
 			"Cannot access %1\nMake sure that the device exists and that "
 			"you have write permission to it.").arg(deviceinfo->devices[0]);
 		emit status(str,-1);
@@ -329,7 +339,7 @@ void FloppyAction::processStdOut(KProcess *, char *b, int l)
 {
 	Q_UNUSED(b);
 	Q_UNUSED(l);
-	DEBUGS("stdout:" << QString::fromLatin1(b,l));
+	kdDebug(KFAREA) << "stdout:" << QString::fromLatin1(b,l) << endl;
 }
 
 void FloppyAction::processStdErr(KProcess *p, char *b, int l)
@@ -455,44 +465,63 @@ void FDFormat::processStdOut(KProcess *, char *b, int l)
 		s = QString::fromLatin1(b,l);
 		if (s.contains("ioctl(FD_FORM)"))
 		{
-			goto ioError;
+                    emit status (i18n(
+                            "Cannot access floppy or floppy drive.\n"
+                            "Please insert a floppy and make sure that you "
+                            "have selected a valid floppy drive."),-1);
+                    return;
 		}
 		if (s.find("/dev/")>=0)
 		{
 			emit status(s,-1);
 			return;
 		}
-		DEBUGS(s.latin1());
+		DEBUGS(s);
 	}
 #elif defined(ANY_LINUX)
 	s = QString::fromLatin1(b,l);
+	DEBUGS(s);
         QRegExp regexp( "([0-9]+)" );
-        if ( regexp.search(s) > -1 )
+        if ( s.startsWith( "bad data at cyl" ) || ( s.find( "Problem reading cylinder" ) != -1 ) )
         {
+            if ( regexp.search( s ) > -1 )
+            {
+                const int track = regexp.cap(1).toInt();
+                emit status(i18n("Low-level formatting error at track %1!").arg(track), -1);
+            }
+            else
+            {
+                // This error should not happen
+                emit status(i18n("Low-level formatting error: %1").arg(s), -1);
+            }
+            return;
+        }
+	else if (s.find("ioctl(FDFMTBEG)")!=-1)
+	{
+            emit status (i18n(
+                    "Cannot access floppy or floppy drive.\n"
+                    "Please insert a floppy and make sure that you "
+                    "have selected a valid floppy drive."),-1);
+            return;
+	}
+        else if ( ( s.find( "ioctl" ) != -1 )
+            || ( s.find( "busy" ) != -1 ) ) // "Device or resource busy"
+        {
+            emit status(i18n("Low-level format error: %1").arg(s),-1);
+            return;
+        }
+        else if ( regexp.search(s) > -1 )
+        {
+            // Normal track number (formatting or verifying)
             const int p = regexp.cap(1).toInt();
-            if ((p>0) && (p<deviceInfo->tracks))
+            if ((p>=0) && (p<deviceInfo->tracks))
             {
                     emit status(QString::null,
                             p * 100 / deviceInfo->tracks);
             }
         }
-	else if (s.contains("ioctl(FDFMTBEG)"))
-	{
-		goto ioError;
-	}
-	DEBUGS(s.latin1());
 #endif
 	return;
-
-// Now a bunch of (goto) labels for all the possible error messages.
-//
-//
-ioError:
-	emit status (i18n(
-		"Cannot access floppy or floppy drive.\n"
-		"Please insert a floppy and make sure that you "
-		"have selected a valid floppy drive."),-1);
-	return;
 }
 
 
@@ -705,6 +734,7 @@ void Ext2Filesystem::exec()
 	*p << "-q";
 	if (doVerify) *p << "-c" ;
 	if (doLabel) *p << "-L" << label ;
+
 	*p << deviceName ;
 
 	if (!startProcess())
@@ -717,3 +747,78 @@ void Ext2Filesystem::exec()
 
 
 #endif
+
+#ifdef ANY_LINUX
+/* static */ QString MinixFilesystem::newfs = QString::null ;
+
+MinixFilesystem::MinixFilesystem(QObject *parent) :
+	FloppyAction(parent)
+{
+	DEBUGSETUP;
+	runtimeCheck();
+	theProcessName="mkfs.minix";
+	setName("Minix2Filesystem");
+}
+
+/* static */ bool MinixFilesystem::runtimeCheck()
+{
+	DEBUGSETUP;
+
+	newfs = findExecutable("mkfs.minix");
+
+	return !newfs.isEmpty();
+}
+
+bool MinixFilesystem::configure(bool v,bool l,const QString &lbl)
+{
+	doVerify=v;
+	doLabel=l;
+	if (l)
+	{
+		label=lbl.stripWhiteSpace();
+	}
+	else
+	{
+		label=QString::null;
+	}
+
+	return true;
+}
+
+void MinixFilesystem::exec()
+{
+	DEBUGSETUP;
+
+	if (!deviceInfo || !deviceName)
+	{
+		emit done(this,false);
+		return;
+	}
+
+	if (newfs.isEmpty())
+	{
+		emit status(i18n("Cannot find a program to create Minix filesystems."),-1);
+		emit done(this,false);
+		return;
+	}
+
+	if (theProcess) delete theProcess;
+	KProcess *p = theProcess = new KProcess;
+
+	*p << newfs;
+
+        // Labeling is not possible
+	if (doVerify) *p << "-c" ;
+
+	*p << deviceName ;
+
+	if (!startProcess())
+	{
+		emit status(i18n("Cannot start Minix format program."),-1);
+		emit done(this,false);
+	}
+}
+
+#endif
+
+#include "format.moc"
