@@ -15,21 +15,37 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <stdlib.h>
 
 #include <qlabel.h>
-#include <qpixmap.h>
 #include <qclipboard.h>
 #include <qfile.h>
 #include <qpopupmenu.h>
 #include <qwidget.h>
-
+#include <qcheckbox.h>
+#include <qmovie.h>
+#include <qcstring.h>
+#include <qhbuttongroup.h> 
 #include <kglobal.h>
+#include <kactivelabel.h>
 #include <kdeversion.h>
 #include <klocale.h>
 #include <kconfig.h>
 #include <kapplication.h>
 #include <kmessagebox.h>
 #include <kcombobox.h>
+#include <qregexp.h>
+#include <kcmdlineargs.h>
+#include <qtooltip.h>
+#include <kdebug.h>
+#include <kurlrequesterdlg.h> 
+#include <klineedit.h>
+#include <kio/renamedlg.h>
+#include <kpassivepopup.h>
+#include <qlayout.h>
+#include <qbuttongroup.h>
+#include <kiconloader.h>
+#include <ktempfile.h>
 #include <kwin.h>
 #include <kprocess.h>
 #include <kprocio.h>
@@ -38,18 +54,32 @@
 #include <kurlrequester.h>
 #include <ktip.h>
 #include <kurldrag.h>
-#include <kdebug.h>
 #include <ktar.h>
 #include <kzip.h>
+#include <dcopclient.h>
+#include <kstandarddirs.h>
+#include <kfiledialog.h>
+#include <kpopupmenu.h>
+#include <qcursor.h>
+#include <kdesktopfile.h>
 
+#include "kgpgeditor.h"
+                       
 #include "kgpg.h"
 #include "kgpgsettings.h"
-
+#include "listkeys.h"
+#include "keyserver.h"
+#include "keyservers.h"
+#include "popuppublic.h"
+#include "kgpgview.h"
+#include "kgpglibrary.h"
+#include "kgpgwizard.h"
 
 MyView::MyView( QWidget *parent, const char *name )
                 : QLabel( parent, name )
 {
-        setBackgroundMode(  X11ParentRelative );
+        setBackgroundMode( X11ParentRelative );
+	openTasks=0;
 
 	KAction *saveDecrypt=new KAction(i18n("&Decrypt && Save File"),"decrypted",0,this, SLOT(decryptDroppedFile()),this,"decrypt_file");
         KAction *showDecrypt=new KAction(i18n("&Show Decrypted File"),"edit",0,this, SLOT(showDroppedFile()),this,"show_file");
@@ -58,9 +88,8 @@ MyView::MyView( QWidget *parent, const char *name )
         //QToolTip::add(this,i18n("KGpg drag & drop encryption applet"));
 
         readOptions();
-
-        setPixmap( KSystemTray::loadIcon("kgpg"));
-        resize(24,24);
+	resize(24,24);
+	setPixmap( KSystemTray::loadIcon("kgpg_docked"));
         setAcceptDrops(true);
 
         droppopup=new QPopupMenu();
@@ -70,6 +99,7 @@ MyView::MyView( QWidget *parent, const char *name )
         udroppopup=new QPopupMenu();
         encrypt->plug(udroppopup);
         sign->plug(udroppopup);
+	QToolTip::add(this, i18n("KGpg - encryption tool"));
 }
 
 MyView::~MyView()
@@ -84,7 +114,7 @@ MyView::~MyView()
 
 void  MyView::clipEncrypt()
 {
-        popupPublic *dialoguec=new popupPublic(0, "public_keys", 0,false);
+        popupPublic *dialoguec=new popupPublic(0, "public_keys", 0,false,goDefaultKey);
         connect(dialoguec,SIGNAL(selectedKey(QStringList,QStringList,bool,bool)),this,SLOT(encryptClipboard(QStringList,QStringList,bool,bool)));
         dialoguec->exec();
         delete dialoguec;
@@ -93,13 +123,24 @@ void  MyView::clipEncrypt()
 void  MyView::clipDecrypt()
 {
         QString clippie=kapp->clipboard()->text(clipboardMode).stripWhiteSpace();
-        if (clippie.startsWith("-----BEGIN PGP MESSAGE")) {
-                KgpgApp *kgpgtxtedit = new KgpgApp(0, "editor",WDestructiveClose);
+	droppedtext(clippie,false);
+}
+
+void  MyView::clipSign(bool openEditor)
+{
+        QString clippie=kapp->clipboard()->text(clipboardMode).stripWhiteSpace();
+        if (!clippie.isEmpty()) {
+                KgpgApp *kgpgtxtedit = new KgpgApp(0, "editor",WDestructiveClose,goDefaultKey);
+		connect(this,SIGNAL(setFont(QFont)),kgpgtxtedit,SLOT(slotSetFont(QFont)));
+		connect(kgpgtxtedit,SIGNAL(encryptFiles(KURL::List)),this,SLOT(encryptFiles(KURL::List)));
+		if (!openEditor)
+		connect(kgpgtxtedit->view,SIGNAL(verifyFinished()),kgpgtxtedit,SLOT(closeWindow()));
                 kgpgtxtedit->view->editor->setText(clippie);
-                kgpgtxtedit->view->slotdecode();
-                kgpgtxtedit->show();
+                kgpgtxtedit->view->clearSign();
+		kgpgtxtedit->show();
+		
         } else
-                KMessageBox::sorry(this,i18n("No encrypted text found."));
+                KMessageBox::sorry(this,i18n("Clipboard is empty."));
 }
 
 void MyView::encryptDroppedFolder()
@@ -110,7 +151,7 @@ void MyView::encryptDroppedFolder()
         if (KMessageBox::warningContinueCancel(0,i18n("<qt>KGpg will now create a temporary archive file:<br><b>%1</b> to process the encryption. The file will be deleted after the encryption is finished.</qt>").arg(kgpgfoldertmp->name()),i18n("Temporary File Creation"),KStdGuiItem::cont(),"FolderTmpFile")==KMessageBox::Cancel)
                 return;
 
-	dialogue=new popupPublic(0,"Public keys",droppedUrls.first().filename(),true);
+	dialogue=new popupPublic(0,"Public keys",droppedUrls.first().fileName(),true,goDefaultKey);
 
 	QHButtonGroup *bGroup = new QHButtonGroup(dialogue->plainPage());
                 (void) new QLabel(i18n("Compression method for archive:"),bGroup);
@@ -185,7 +226,7 @@ pop = new KPassivePopup();
                 KMessageBox::sorry(0,i18n("Unable to create temporary file"));
                 return;
         	}
-        arch->addLocalDirectory (droppedUrls.first().path(),droppedUrls.first().filename());
+        arch->addLocalDirectory (droppedUrls.first().path(),droppedUrls.first().fileName());
         arch->close();
 
         KgpgInterface *folderprocess=new KgpgInterface();
@@ -207,11 +248,34 @@ void  MyView::slotFolderFinishedError(QString errmsge)
         KMessageBox::sorry(0,errmsge);
 }
 
+void MyView::busyMessage(QString mssge,bool reset)
+{
+if (reset) openTasks=0;
+if (!mssge.isEmpty())
+{
+openTasks++;
+QToolTip::remove(this);
+QToolTip::add(this, mssge);
+setMovie(QMovie(locate("appdata","pics/kgpg_docked.gif")));
+}
+else openTasks--;
+
+//kdDebug(2100) << "Emit message: "<<openTasks<<endl;
+
+if (openTasks<=0)
+{
+setPixmap( KSystemTray::loadIcon("kgpg_docked"));
+QToolTip::remove(this);
+QToolTip::add(this, i18n("KGpg - encryption tool"));
+openTasks=0;
+}
+}
 
 void  MyView::encryptDroppedFile()
 {
         QStringList opts;
-        KgpgLibrary *lib=new KgpgLibrary(KGpgSettings::pgpExtension());
+        KgpgLibrary *lib=new KgpgLibrary(this,KGpgSettings::pgpExtension());
+	connect(lib,SIGNAL(systemMessage(QString,bool)),this,SLOT(busyMessage(QString,bool)));
         if (KGpgSettings::encryptFilesTo()) {
                 if (KGpgSettings::allowUntrustedKeys())
                         opts<<"--always-trust";
@@ -221,22 +285,35 @@ void  MyView::encryptDroppedFile()
                         opts<<"--throw-keyid";
                 if (KGpgSettings::pgpCompatibility())
                         opts<<"--pgp6";
-                lib->slotFileEnc(droppedUrls,opts,KGpgSettings::fileEncryptionKey().left(8));
+                lib->slotFileEnc(droppedUrls,opts,KGpgSettings::fileEncryptionKey().left(8),goDefaultKey);
         } else
-                lib->slotFileEnc(droppedUrls);
+                lib->slotFileEnc(droppedUrls,QString::null,QString::null,goDefaultKey);
 }
 
+void  MyView::encryptFiles(KURL::List urls)
+{
+droppedUrls=urls;
+encryptDroppedFile();
+}
 
 void  MyView::shredDroppedFile()
 {
-        if (KMessageBox::warningContinueCancelList(0,i18n("Do you really want to shred these files?"),droppedUrls.toStringList())!=KMessageBox::Continue)
-                return;
-        KURL::List::iterator it;
-        for ( it = droppedUrls.begin(); it != droppedUrls.end(); ++it ) {
+KDialogBase *shredConfirm=new KDialogBase( this, "confirm_shred", true,i18n("Shred Files"),KDialogBase::Ok | KDialogBase::Cancel);
+QWidget *page = new QWidget(shredConfirm);
+shredConfirm->setMainWidget(page);
+QBoxLayout *layout=new QBoxLayout(page,QBoxLayout::TopToBottom,0);
+layout->setAutoAdd(true);
 
-	KgpgLibrary *lib=new KgpgLibrary();
-        lib->shredprocessenc(KURL(*it));
-        }
+(void) new KActiveLabel( i18n("Do you really want to <a href=\"whatsthis:%1\">shred</a> these files?").arg(i18n( "<qt><p>You must be aware that <b>shredding is not secure</b> on all file systems, and that parts of the file may have been saved in a temporary file or in the spooler of your printer if you previously opened it in an editor or tried to print it. Only works on files (not on folders).</p></qt>")),page);
+KListBox *lb=new KListBox(page);
+lb->insertStringList(droppedUrls.toStringList());
+if (shredConfirm->exec()==QDialog::Accepted)
+	{
+	KgpgLibrary *lib=new KgpgLibrary(this);
+	connect(lib,SIGNAL(systemMessage(QString,bool)),this,SLOT(busyMessage(QString,bool)));
+	lib->shredprocessenc(droppedUrls);
+	}
+delete shredConfirm;
 }
 
 
@@ -248,7 +325,7 @@ void  MyView::slotVerifyFile()
 
         QString sigfile=QString::null;
         //////////////////////////////////////       try to find detached signature.
-        if (!droppedUrl.filename().endsWith(".sig")) {
+        if (!droppedUrl.fileName().endsWith(".sig")) {
                 sigfile=droppedUrl.path()+".sig";
                 QFile fsig(sigfile);
                 if (!fsig.exists()) {
@@ -303,14 +380,15 @@ void  MyView::signDroppedFile()
 
 void  MyView::decryptDroppedFile()
 {
-        //bool isFolder=false;
+        //bool isFolder=false;  // droppedUrls
         KURL swapname;
 
-        if (!droppedUrl.isLocalFile()) {
+        if (!droppedUrls.first().isLocalFile()) {
                 showDroppedFile();
-                return;
+                decryptNextFile();
         }
-        QString oldname=droppedUrl.filename();
+
+        QString oldname=droppedUrls.first().fileName();
         if (oldname.endsWith(".gpg") || oldname.endsWith(".asc") || oldname.endsWith(".pgp"))
                 oldname.truncate(oldname.length()-4);
         else
@@ -324,27 +402,37 @@ void  MyView::decryptDroppedFile()
                 if (KMessageBox::warningContinueCancel(0,i18n("<qt>The file to decrypt is an archive. KGpg will create a temporary unencrypted archive file:<br><b>%1</b> before processing the archive extraction. This temporary file will be deleted after the decryption is finished.</qt>").arg(kgpgFolderExtract->name()),i18n("Temporary File Creation"),KStdGuiItem::cont(),"FolderTmpDecFile")==KMessageBox::Cancel)
                         return;
         } else*/ {
-                swapname=KURL(droppedUrl.directory(0,0)+oldname);
+                swapname=KURL(droppedUrls.first().directory(0,0)+oldname);
                 QFile fgpg(swapname.path());
                 if (fgpg.exists()) {
 	    KIO::RenameDlg *over=new KIO::RenameDlg(0,i18n("File Already Exists"),QString::null,swapname.path(),KIO::M_OVERWRITE);
 	    if (over->exec()==QDialog::Rejected)
 	    {
                 delete over;
-                return;
+                decryptNextFile();
+		return;
             }
 	    swapname=over->newDestURL();
 	    delete over;
                 }
         }
-        KgpgLibrary *lib=new KgpgLibrary();
-        lib->slotFileDec(droppedUrl,swapname,KGpgSettings::customDecrypt());
-//        if (isFolder)
-  //              connect(lib,SIGNAL(decryptionOver()),this,SLOT(unArchive()));
+        KgpgLibrary *lib=new KgpgLibrary(this);
+        lib->slotFileDec(droppedUrls.first(),swapname,KGpgSettings::customDecrypt());
 	connect(lib,SIGNAL(importOver(QStringList)),this,SIGNAL(importedKeys(QStringList)));
+	connect(lib,SIGNAL(systemMessage(QString,bool)),this,SLOT(busyMessage(QString,bool)));
+//        if (isFolder)
+        connect(lib,SIGNAL(decryptionOver()),this,SLOT(decryptNextFile()));
+	
 }
 
-
+void  MyView::decryptNextFile()
+{
+if (droppedUrls.count()>1)
+{
+droppedUrls.pop_front();
+decryptDroppedFile();
+}
+}
 
 void  MyView::unArchive()
 {
@@ -370,9 +458,11 @@ void  MyView::unArchive()
 
 void  MyView::showDroppedFile()
 {
-kdDebug()<<"------Show dropped file"<<endl;
-        KgpgApp *kgpgtxtedit = new KgpgApp(0, "editor",WDestructiveClose);
-        kgpgtxtedit->view->editor->slotDroppedFile(droppedUrl);
+kdDebug(2100)<<"------Show dropped file"<<endl;
+        KgpgApp *kgpgtxtedit = new KgpgApp(0, "editor",WDestructiveClose,goDefaultKey);
+        kgpgtxtedit->view->editor->slotDroppedFile(droppedUrls.first());
+	connect(kgpgtxtedit,SIGNAL(encryptFiles(KURL::List)),this,SLOT(encryptFiles(KURL::List)));
+	connect(this,SIGNAL(setFont(QFont)),kgpgtxtedit,SLOT(slotSetFont(QFont)));
 	connect(kgpgtxtedit,SIGNAL(refreshImported(QStringList)),this,SIGNAL(importedKeys(QStringList)));
 	connect(kgpgtxtedit->view->editor,SIGNAL(refreshImported(QStringList)),this,SIGNAL(importedKeys(QStringList)));
         kgpgtxtedit->show();
@@ -384,7 +474,8 @@ void  MyView::droppedfile (KURL::List url)
         droppedUrls=url;
         droppedUrl=url.first();
         if (KMimeType::findByURL(droppedUrl)->name()=="inode/directory") {
-                KMessageBox::sorry(0,i18n("Sorry, only file operations are currently supported."));
+		encryptDroppedFolder();
+                //KMessageBox::sorry(0,i18n("Sorry, only file operations are currently supported."));
                 return;
         }
         if (!droppedUrl.isLocalFile()) {
@@ -402,7 +493,7 @@ void  MyView::droppedfile (KURL::List url)
                         break;
                 case KGpgSettings::EnumEncryptedDropEvent::Ask:
                         droppopup->exec(QCursor::pos ());
-			kdDebug()<<"Drop menu--------"<<endl;
+			kdDebug(2100)<<"Drop menu--------"<<endl;
                         break;
                 }
         } else if (droppedUrl.path().endsWith(".sig")) {
@@ -422,12 +513,16 @@ void  MyView::droppedfile (KURL::List url)
 }
 
 
-void  MyView::droppedtext (QString inputText)
+void  MyView::droppedtext (QString inputText,bool allowEncrypt)
 {
 
-        QApplication::clipboard()->setText(inputText,clipboardMode);
         if (inputText.startsWith("-----BEGIN PGP MESSAGE")) {
-                clipDecrypt();
+                KgpgApp *kgpgtxtedit = new KgpgApp(0, "editor",WDestructiveClose,goDefaultKey);
+		connect(kgpgtxtedit,SIGNAL(encryptFiles(KURL::List)),this,SLOT(encryptFiles(KURL::List)));
+		connect(this,SIGNAL(setFont(QFont)),kgpgtxtedit,SLOT(slotSetFont(QFont)));
+                kgpgtxtedit->view->editor->setText(inputText);
+                kgpgtxtedit->view->slotdecode();
+                kgpgtxtedit->show();
                 return;
         }
         if (inputText.startsWith("-----BEGIN PGP PUBLIC KEY")) {
@@ -441,7 +536,12 @@ void  MyView::droppedtext (QString inputText)
                         return;
                 }
         }
-        clipEncrypt();
+	        if (inputText.startsWith("-----BEGIN PGP SIGNED MESSAGE")) {
+                clipSign(false);
+                return;
+        }
+        if (allowEncrypt) clipEncrypt();
+	else KMessageBox::sorry(this,i18n("No encrypted text found."));
 }
 
 
@@ -458,7 +558,10 @@ void  MyView::dropEvent (QDropEvent *o)
         if ( KURLDrag::decode( o, list ) )
                 droppedfile(list);
         else if ( QTextDrag::decode(o, text) )
+		{
+	        QApplication::clipboard()->setText(text,clipboardMode);
                 droppedtext(text);
+		}
 }
 
 
@@ -493,16 +596,32 @@ void  MyView::firstRun()
 }
 
 
+static QString getGpgHome()
+{
+    char    *env=getenv("GNUPGHOME");
+    QString gpgHome(env ? env : QDir::homeDirPath()+"/.gnupg/");
+
+    gpgHome.replace("//", "/");
+
+    if(!gpgHome.endsWith("/"))
+        gpgHome.append('/');
+
+    KStandardDirs::makeDir(gpgHome, 0700);
+    return gpgHome;
+}
+
+
 void  MyView::startWizard()
 {
-        kdDebug()<<"Starting Wizard"<<endl;
+        kdDebug(2100)<<"Starting Wizard"<<endl;
         wiz=new KgpgWizard(0,"wizard");
-        QString confPath=QDir::homeDirPath()+"/.gnupg/options";
+        QString gpgHome(getGpgHome());
+        QString confPath=gpgHome+"options";
         if (!QFile(confPath).exists()) {
-                confPath=QDir::homeDirPath()+"/.gnupg/gpg.conf";
+                confPath=gpgHome+"gpg.conf";
                 if (!QFile(confPath).exists()) {
                         if (KMessageBox::questionYesNo(this,i18n("<qt><b>The GnuPG configuration file was not found</b>. Please make sure you have GnuPG installed. Should KGpg try to create a config file ?</qt>"))==KMessageBox::Yes) {
-                                confPath=QDir::homeDirPath()+"/.gnupg/options";
+                                confPath=gpgHome+"options";
                                 QFile file(confPath);
                                 if ( file.open( IO_WriteOnly ) ) {
                                         QTextStream stream( &file );
@@ -521,15 +640,16 @@ void  MyView::startWizard()
 	else wiz->txtGpgVersion->setText(QString::null);
 
         wiz->kURLRequester1->setURL(confPath);
-        wiz->kURLRequester2->setURL(QString(QDir::homeDirPath()+"/Desktop"));
-        wiz->kURLRequester2->setMode(2);
+        /*
+	wiz->kURLRequester2->setURL(KGlobalSettings::desktopPath());
+        wiz->kURLRequester2->setMode(2);*/
 
         FILE *fp,*fp2;
         QString tst,tst2,name,trustedvals="idre-";
         QString firstKey=QString::null;
         char line[300];
-        int counter=0;
-
+        bool counter=false;
+	
         fp = popen("gpg --no-tty --with-colon --list-secret-keys", "r");
         while ( fgets( line, sizeof(line), fp)) {
                 tst=line;
@@ -540,7 +660,7 @@ void  MyView::startWizard()
                                 while ( fgets( line, sizeof(line), fp2)) {
                                         tst2=line;
                                         if (tst2.startsWith("pub") && (trustedvals.find(tst2.section(':',1,1))==-1)) {
-                                                counter++;
+                                                counter=true;
                                                 wiz->CBdefault->insertItem(tst.section(':',4,4).right(8)+": "+name);
                                                 if (firstKey.isEmpty())
                                                         firstKey=tst.section(':',4,4).right(8)+": "+name;
@@ -554,10 +674,11 @@ void  MyView::startWizard()
         pclose(fp);
 	wiz->CBdefault->setCurrentItem(firstKey);
         //connect(wiz->pushButton4,SIGNAL(clicked()),this,SLOT(slotGenKey()));
-        if (counter==0)
+        if (!counter)
                 connect(wiz->finishButton(),SIGNAL(clicked()),this,SLOT(slotGenKey()));
         else {
                 wiz->textGenerate->hide();
+		wiz->setTitle(wiz->page_4,i18n("Step Three: Select your Default Private Key"));
                 connect(wiz->finishButton(),SIGNAL(clicked()),this,SLOT(slotSaveOptionsPath()));
         }
         connect(wiz->nextButton(),SIGNAL(clicked()),this,SLOT(slotWizardChange()));
@@ -590,24 +711,25 @@ void  MyView::slotWizardChange()
         }
 }
 
-
-void  MyView::slotSaveOptionsPath()
+void  MyView::installShred()
 {
-qWarning("Save wizard settings...");
-        if (wiz->checkBox1->isChecked()) {
                 KURL path;
-                path.addPath(wiz->kURLRequester2->url());
-                path.adjustPath(1);
-                path.setFileName("shredder.desktop");
+		path.setPath(KGlobalSettings::desktopPath());
+		path.addPath("shredder.desktop");
                 KDesktopFile configl2(path.path(), false);
                 if (configl2.isImmutable() ==false) {
                         configl2.setGroup("Desktop Entry");
                         configl2.writeEntry("Type", "Application");
                         configl2.writeEntry("Name",i18n("Shredder"));
-                        configl2.writeEntry("Icon","shredder");
+                        configl2.writeEntry("Icon","editshred");
                         configl2.writeEntry("Exec","kgpg -X %U");
                 }
-        }
+}
+
+void  MyView::slotSaveOptionsPath()
+{
+qWarning("Save wizard settings...");
+        if (wiz->checkBox1->isChecked()) installShred();
 
         KGpgSettings::setAutoStart( wiz->checkBox2->isChecked() );
 
@@ -648,25 +770,6 @@ void  MyView::help()
         kapp->invokeHelp(0,"kgpg");
 }
 
-
-void  MyView::preferences()
-{
-        KConfigDialog *optsDialog=KConfigDialog::exists("settings");
-        if (!optsDialog)
-                optsDialog=new kgpgOptions(this,"settings");
-        disconnect(optsDialog,SIGNAL(settingsUpdated()),this,SLOT(readAgain1()));
-        connect(optsDialog,SIGNAL(settingsUpdated()),this,SLOT(readAgain1()));
-        optsDialog->show();
-}
-
-void MyView::readAgain1()
-{
-        readOptions();
-        emit readAgain2();
-}
-
-
-
 kgpgapplet::kgpgapplet(QWidget *parent, const char *name)
                 : KSystemTray(parent,name)
 {
@@ -675,11 +778,18 @@ kgpgapplet::kgpgapplet(QWidget *parent, const char *name)
         KPopupMenu *conf_menu=contextMenu();
         KAction *KgpgEncryptClipboard = new KAction(i18n("&Encrypt Clipboard"), 0, 0,w, SLOT(clipEncrypt()),actionCollection(),"clip_encrypt");
         KAction *KgpgDecryptClipboard = new KAction(i18n("&Decrypt Clipboard"), 0, 0,w, SLOT(clipDecrypt()),actionCollection(),"clip_decrypt");
-        KAction *KgpgOpenEditor = new KAction(i18n("&Open Editor"), "edit", 0,parent, SLOT(slotOpenEditor()),actionCollection(),"kgpg_editor");
-	KAction *KgpgOpenServer = new KAction(i18n("&Key Server Dialog"), "network", 0,parent, SLOT(keyserver()),actionCollection(),"kgpg_server");
-        KAction *KgpgPreferences=KStdAction::preferences(w, SLOT(preferences()), actionCollection());
+	KAction *KgpgSignClipboard = new KAction(i18n("&Sign/Verify Clipboard"), 0, 0,w, SLOT(clipSign()),actionCollection(),"clip_sign");
+        KAction *KgpgOpenEditor;
+	if (KGpgSettings::leftClick()==KGpgSettings::EnumLeftClick::KeyManager)
+	KgpgOpenEditor = new KAction(i18n("&Open Editor"), "edit", 0,parent, SLOT(slotOpenEditor()),actionCollection(),"kgpg_editor");
+	else
+	KgpgOpenEditor = new KAction(i18n("&Open Key Manager"), "kgpg", 0,this, SLOT(slotOpenKeyManager()),actionCollection(),"kgpg_editor");
+	
+	KAction *KgpgOpenServer = new KAction(i18n("&Key Server Dialog"), "network", 0,this, SLOT(slotOpenServerDialog()),actionCollection(),"kgpg_server");
+        KAction *KgpgPreferences=KStdAction::preferences(this, SLOT(showOptions()), actionCollection());
         KgpgEncryptClipboard->plug(conf_menu);
         KgpgDecryptClipboard->plug(conf_menu);
+	KgpgSignClipboard->plug(conf_menu);
         KgpgOpenEditor->plug(conf_menu);
 	KgpgOpenServer->plug(conf_menu);
         conf_menu->insertSeparator();
@@ -687,6 +797,28 @@ kgpgapplet::kgpgapplet(QWidget *parent, const char *name)
 }
 
 
+void kgpgapplet::showOptions()
+{
+QByteArray data;
+if (!kapp->dcopClient()->send("kgpg", "KeyInterface", "showOptions()",data))
+kdDebug(2100) <<"there was some error using DCOP."<<endl;
+}
+
+void kgpgapplet::slotOpenKeyManager()
+{
+QByteArray data;
+if (!kapp->dcopClient()->send("kgpg", "KeyInterface", "showKeyManager()",data))
+kdDebug(2100) <<"there was some error using DCOP."<<endl;
+}
+
+void kgpgapplet::slotOpenServerDialog()
+{
+QByteArray data;
+if (!kapp->dcopClient()->send("kgpg", "KeyInterface", "showKeyServer()",data))
+kdDebug(2100) <<"there was some error using DCOP."<<endl;
+}
+
+
 
 kgpgapplet::~kgpgapplet()
 {
@@ -713,13 +845,13 @@ KgpgAppletApp::~KgpgAppletApp()
 void KgpgAppletApp::slotHandleQuit()
 {
 s_keyManager->keysList2->saveLayout(KGlobal::config(),"KeyView");
-        KGpgSettings::setShowToolbar(!s_keyManager->toolBar()->isHidden());
         KGpgSettings::setPhotoProperties(s_keyManager->photoProps->currentItem());
 	KGpgSettings::setShowTrust(s_keyManager->sTrust->isChecked());
 	KGpgSettings::setShowExpi(s_keyManager->sExpi->isChecked());
 	KGpgSettings::setShowCreat(s_keyManager->sCreat->isChecked());
 	KGpgSettings::setShowSize(s_keyManager->sSize->isChecked());
         KGpgSettings::writeConfig();
+	KSimpleConfig ("kgpgrc").sync();
         quit();
 }
 
@@ -733,34 +865,52 @@ void KgpgAppletApp::wizardOver(QString defaultKeyId)
 
 int KgpgAppletApp::newInstance()
 {
-        kdDebug()<<"New instance"<<endl;
+        kdDebug(2100)<<"New instance"<<endl;
         args = KCmdLineArgs::parsedArgs();
         if (running) {
-                kdDebug()<<"Already running"<<endl;
+                kdDebug(2100)<<"Already running"<<endl;
                 kgpg_applet->show();
         } else {
-                kdDebug() << "Starting KGpg"<<endl;
+                kdDebug(2100) << "Starting KGpg"<<endl;
                 running=true;
+		
                 s_keyManager=new listKeys(0, "key_manager");
+		
+		QString gpgPath= KGpgSettings::gpgConfigPath();
+		if (!gpgPath.isEmpty() && KURL(gpgPath).directory(false)!=QDir::homeDirPath()+"/.gnupg/")
+		setenv("GNUPGHOME",KURL(gpgPath).directory(false).ascii(),1);
+		
                 s_keyManager->refreshkey();
+		
+		if (KGpgSettings::leftClick()==KGpgSettings::EnumLeftClick::KeyManager)
                 kgpg_applet=new kgpgapplet(s_keyManager,"kgpg_systrayapplet");
+		else
+		{
+		kgpg_applet=new kgpgapplet(s_keyManager->s_kgpgEditor,"kgpg_systrayapplet");
+		}
+		connect(s_keyManager,SIGNAL(encryptFiles(KURL::List)),kgpg_applet->w,SLOT(encryptFiles(KURL::List)));
+		connect(s_keyManager,SIGNAL(installShredder()),kgpg_applet->w,SLOT(installShred()));
+		connect(s_keyManager->s_kgpgEditor,SIGNAL(encryptFiles(KURL::List)),kgpg_applet->w,SLOT(encryptFiles(KURL::List)));
+		
                 connect( kgpg_applet, SIGNAL(quitSelected()), this, SLOT(slotHandleQuit()));
-                connect(kgpg_applet->w,SIGNAL(readAgain2()),s_keyManager,SLOT(readOptions()));
                 connect(s_keyManager,SIGNAL(readAgainOptions()),kgpg_applet->w,SLOT(readOptions()));
                 connect(kgpg_applet->w,SIGNAL(updateDefault(QString)),this,SLOT(wizardOver(QString)));
                 connect(kgpg_applet->w,SIGNAL(createNewKey()),s_keyManager,SLOT(slotgenkey()));
+		connect(s_keyManager,SIGNAL(fontChanged(QFont)),kgpg_applet->w,SIGNAL(setFont(QFont)));
 		connect(kgpg_applet->w,SIGNAL(importedKeys(QStringList)),s_keyManager->keysList2,SLOT(slotReloadKeys(QStringList)));
                 kgpg_applet->show();
-                QString gpgPath= KGpgSettings::gpgConfigPath();
+                
 
                 if (!gpgPath.isEmpty()) {
                         if ((KgpgInterface::getGpgBoolSetting("use-agent",gpgPath)) && (!getenv("GPG_AGENT_INFO")))
                                 KMessageBox::sorry(0,i18n("<qt>The use of <b>GnuPG Agent</b> is enabled in GnuPG's configuration file (%1).<br>"
-                                                          "However, the agent doesn't seem to run. This could result in problems with signing/decryption.<br>"
+                                                          "However, the agent does not seem to be running. This could result in problems with signing/decryption.<br>"
                                                           "Please disable GnuPG Agent from KGpg settings, or fix the agent.</qt>").arg(gpgPath));
                 }
 
         }
+	goHome=s_keyManager->actionCollection()->action("go_default_key")->shortcut();
+	kgpg_applet->w->goDefaultKey=goHome;
 
         ////////////////////////   parsing of command line args
         if (args->isSet("k")!=0) {
@@ -770,7 +920,7 @@ int KgpgAppletApp::newInstance()
                 s_keyManager->raise();  // set on top
         } else
                 if (args->count()>0) {
-                        kdDebug() << "KGpg: found files"<<endl;
+                        kdDebug(2100) << "KGpg: found files"<<endl;
 
                         urlList.clear();
 
@@ -785,12 +935,12 @@ int KgpgAppletApp::newInstance()
                         bool directoryInside=false;
                         QStringList lst=urlList.toStringList();
                         for ( QStringList::Iterator it = lst.begin(); it != lst.end(); ++it ) {
-                                if (KMimeType::findByURL(*it)->name()=="inode/directory")
+                                if (KMimeType::findByURL(KURL( *it ))->name()=="inode/directory")
                                         directoryInside=true;
                         }
 
                         if ((directoryInside) && (lst.count()>1)) {
-                                KMessageBox::sorry(0,i18n("Sorry, cannot perform requested operation.\nPlease select only one folder, or several files, but don't mix files and folders."));
+                                KMessageBox::sorry(0,i18n("Unable to perform requested operation.\nPlease select only one folder, or several files, but do not mix files and folders."));
                                 return 0;
                         }
 
@@ -810,7 +960,7 @@ int KgpgAppletApp::newInstance()
                                 if (!directoryInside)
                                         kgpg_applet->w->showDroppedFile();
                                 else
-                                        KMessageBox::sorry(0,i18n("Cannot decrypt & show folder."));
+                                        KMessageBox::sorry(0,i18n("Cannot decrypt and show folder."));
                         } else if (args->isSet("S")!=0) {
                                 if (!directoryInside)
                                         kgpg_applet->w->signDroppedFile();
@@ -821,7 +971,7 @@ int KgpgAppletApp::newInstance()
                                         kgpg_applet->w->slotVerifyFile();
                                 else
                                         KMessageBox::sorry(0,i18n("Cannot verify folder."));
-                        } else if (kgpg_applet->w->droppedUrl.filename().endsWith(".sig"))
+                        } else if (kgpg_applet->w->droppedUrl.fileName().endsWith(".sig"))
                                 kgpg_applet->w->slotVerifyFile();
                         else
                                 kgpg_applet->w->decryptDroppedFile();
