@@ -15,34 +15,94 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <stdlib.h>
+
 #include <kaction.h>
 #include <kfiledialog.h>
 #include <klocale.h>
+#include <dcopclient.h>
+#include <qpaintdevicemetrics.h>
+#include <qcstring.h>
+
+#include <kencodingfiledialog.h>
+
+#include <qradiobutton.h>
+#include <qclipboard.h>
+#include <qtextcodec.h>
+#include <qpainter.h>
+#include <kprinter.h>
+#include <kmessagebox.h>
+#include <kdebug.h>
+#include <klineedit.h>
+#include <qcheckbox.h>
+#include <kurlrequester.h>
+#include <ktempfile.h>
+#include <kio/netaccess.h>
+#include <kio/renamedlg.h>
+#include <kedittoolbar.h>
+
 
 #include "kgpgsettings.h"
 #include "kgpgeditor.h"
 #include "sourceselect.h"
 #include "keyexport.h"
+#include "keyserver.h"
+#include "keyservers.h"
+#include "kgpg.h"
+#include "kgpgview.h"
+#include "listkeys.h"
+#include "kgpglibrary.h"
 
-KgpgApp::KgpgApp(QWidget *parent, const char *name, WFlags f):KMainWindow(parent, name,f)
+KgpgApp::KgpgApp(QWidget *parent, const char *name, WFlags f,KShortcut goHome,bool mainWindow):KMainWindow(parent, name,f)
 {
+	isMainWindow=mainWindow;
+	textEncoding=QString::null;
         readOptions();
-
+	goDefaultKey=goHome;
         // call inits to invoke all other construction parts
-	setAutoSaveSettings("Editor",true);
+	
         initActions();
         initView();
-        createGUI("kgpg.rc");
+
+	slotSetFont(KGpgSettings::font());
+        setupGUI(( ToolBar | Keys | StatusBar | Save | Create ), "kgpg.rc");
+	setAutoSaveSettings("Editor",true);
+
 }
 
-
 KgpgApp::~KgpgApp()
-{}
+{
+delete view;
+}
+
+void KgpgApp::slotOptions()
+{
+QByteArray data;
+if (!kapp->dcopClient()->send("kgpg", "KeyInterface", "showOptions()",data))
+kdDebug(2100) <<"there was some error using DCOP."<<endl;
+}
+
+void KgpgApp::slotKeyManager()
+{
+QByteArray data;
+if (!kapp->dcopClient()->send("kgpg", "KeyInterface", "showKeyManager()",data))
+kdDebug(2100) <<"there was some error using DCOP."<<endl;
+}
 
 void KgpgApp::closeEvent ( QCloseEvent * e )
 {
-        kapp->ref(); // prevent KMainWindow from closing the app
-        KMainWindow::closeEvent( e );
+        if (!isMainWindow) 
+	{
+	 kapp->ref();	
+	KMainWindow::closeEvent( e );
+	}
+  else e->accept();
+}
+
+void KgpgApp::closeWindow()
+{
+if (view->windowAutoClose) close();
+kdDebug(2100) << "Close requested"<<endl;
 }
 
 void KgpgApp::saveOptions()
@@ -74,11 +134,15 @@ void KgpgApp::initActions()
         KStdAction::copy(this, SLOT(slotEditCopy()), actionCollection());
         KStdAction::paste(this, SLOT(slotEditPaste()), actionCollection());
 	KStdAction::selectAll(this, SLOT(slotSelectAll()), actionCollection());
-        //KStdAction::preferences(this, SLOT(slotOptions()), actionCollection());
+	KStdAction::preferences(this, SLOT(slotOptions()), actionCollection(),"kgpg_config");
+
+        //KStdAction::keyBindings(guiFactory(), SLOT(configureShortcuts()), actionCollection());
+        //KStdAction::configureToolbars(this, SLOT(slotConfigureToolbars()), actionCollection());
 
         fileSave = KStdAction::save(this, SLOT(slotFileSave()), actionCollection());
-        (void) new KAction(i18n("&Encrypt File..."), "kgpg", 0,this, SLOT(slotFilePreEnc()), actionCollection(),"file_encrypt");
-        (void) new KAction(i18n("&Decrypt File..."), "kgpg2", 0,this, SLOT(slotFilePreDec()), actionCollection(),"file_decrypt");
+        (void) new KAction(i18n("&Encrypt File..."), "encrypted", 0,this, SLOT(slotFilePreEnc()), actionCollection(),"file_encrypt");
+        (void) new KAction(i18n("&Decrypt File..."), "decrypted", 0,this, SLOT(slotFilePreDec()), actionCollection(),"file_decrypt");
+	(void) new KAction(i18n("&Open Key Manager"), "kgpg", 0,this, SLOT(slotKeyManager()), actionCollection(),"key_manage");
         editUndo = KStdAction::undo(this, SLOT(slotundo()), actionCollection());
         editRedo = KStdAction::redo(this, SLOT(slotredo()), actionCollection());
         //(void) new KAction(i18n("&Manage Keys"), "kgpg_manage", CTRL+Key_K,this, SLOT(slotManageKey()), actionCollection(),"keys_manage");
@@ -86,22 +150,28 @@ void KgpgApp::initActions()
         (void) new KAction(i18n("&Verify Signature..."),0, this, SLOT(slotPreVerifyFile()), actionCollection(), "sign_verify");
         (void) new KAction(i18n("&Check MD5 Sum..."), 0,this, SLOT(slotCheckMd5()), actionCollection(), "sign_check");
 	KStdAction::print(this, SLOT(slotFilePrint()), actionCollection());
-	
-	encodingAction=new KToggleAction(i18n("&Unicode (utf-8) encoding"), 0, 0,this, SLOT(slotSetCharset()),actionCollection(),"charsets");
+
+	encodingAction=new KToggleAction(i18n("&Unicode (utf-8) Encoding"), 0, 0,this, SLOT(slotSetCharset()),actionCollection(),"charsets");
 }
 
+void KgpgApp::slotSetFont(QFont myFont)
+{
+view->editor->setFont (myFont);
+}
+
+
 void KgpgApp::slotSetCharset()
 {
 ////////  work in progress
 if (encodingAction->isChecked())
-{
-if (!checkEncoding()) return;
 view->editor->setText(QString::fromUtf8(view->editor->text().ascii()));
-}
-else 
+else
+{
+if (checkEncoding(QTextCodec::codecForLocale ())) return;
 view->editor->setText(view->editor->text().utf8());
 }
-    
+}
+
 void KgpgApp::initView()
 {
         ////////////////////////////////////////////////////////////////////
@@ -124,7 +194,7 @@ void KgpgApp::slotFileQuit()
 
 void KgpgApp::slotResetEncoding(bool enc)
 {
-//kdDebug()<<"Resetting encoding--------------------"<<endl;
+//kdDebug(2100)<<"Resetting encoding--------------------"<<endl;
 encodingAction->setChecked(enc);
 //if (enc) slotSetCharset();
 }
@@ -145,24 +215,11 @@ void KgpgApp::slotFileNew()
 void KgpgApp::slotFilePreEnc()
 {
         QStringList opts;
-
-        KURL url=KFileDialog::getOpenURL(QString::null,
+	KURL::List urls=KFileDialog::getOpenURLs(QString::null,
                                          i18n("*|All Files"), this, i18n("Open File to Encode"));
-        if (url.isEmpty())
+        if (urls.isEmpty())
                 return;
-        KgpgLibrary *lib=new KgpgLibrary( KGpgSettings::pgpExtension() );
-        if ( KGpgSettings::encryptFilesTo() ) {
-                if (KGpgSettings::allowUntrustedKeys())
-                        opts<<"--always-trust";
-                if (KGpgSettings::asciiArmor())
-                        opts<<"--armor";
-                if (KGpgSettings::hideUserID())
-                        opts<<"--throw-keyid";
-                if (KGpgSettings::pgpCompatibility())
-                        opts<<"--pgp6";
-                lib->slotFileEnc(KURL::List::List(url),opts, KGpgSettings::fileEncryptionKey().left(8));
-        } else
-                lib->slotFileEnc(KURL::List::List(url));
+	emit encryptFiles(urls);
 }
 
 void KgpgApp::slotFilePreDec()
@@ -173,7 +230,7 @@ void KgpgApp::slotFilePreDec()
 
         if (url.isEmpty())
                 return;
-        QString oldname=url.filename();
+        QString oldname=url.fileName();
 
         QString newname;
 
@@ -183,8 +240,8 @@ void KgpgApp::slotFilePreDec()
                 oldname.append(".clear");
         oldname.prepend(url.directory(0,0));
 
-	KDialogBase *popn=new KDialogBase( KDialogBase::Swallow, i18n("Decrypt File to"), KDialogBase::Ok | KDialogBase::Cancel, KDialogBase::Ok, this, "file_decrypt",true);
-	
+	KDialogBase *popn=new KDialogBase( KDialogBase::Swallow, i18n("Decrypt File To"), KDialogBase::Ok | KDialogBase::Cancel, KDialogBase::Ok, this, "file_decrypt",true);
+
 	SrcSelect *page=new SrcSelect();
 	popn->setMainWidget(page);
 	page->newFilename->setURL(oldname);
@@ -216,7 +273,7 @@ void KgpgApp::slotFilePreDec()
 	    		newname=over->newDestURL().path();
 	    		delete over;
                 }
-                KgpgLibrary *lib=new KgpgLibrary();
+                KgpgLibrary *lib=new KgpgLibrary(this);
                 lib->slotFileDec(url,KURL(newname), customDecrypt);
 		connect(lib,SIGNAL(importOver(QStringList)),this,SIGNAL(refreshImported(QStringList)));
         } else
@@ -225,11 +282,13 @@ void KgpgApp::slotFilePreDec()
 
 void KgpgApp::slotFileOpen()
 {
-
-        KURL url=KFileDialog::getOpenURL(QString::null,
-                                         i18n("*|All Files"), this, i18n("Open File"));
+	KEncodingFileDialog::Result loadResult;
+	loadResult=KEncodingFileDialog::getOpenURLAndEncoding(QString::null,QString::null,QString::null,this);
+	KURL url=loadResult.URLs.first();
+	textEncoding=loadResult.encoding;
+	
         if(!url.isEmpty()) {
-                openDocumentFile(url);
+                openDocumentFile(url,textEncoding);
                 Docname=url;
                 fileSave->setEnabled(false);
                 //fileSaveAs->setEnabled(true);
@@ -238,98 +297,113 @@ void KgpgApp::slotFileOpen()
 
 }
 
-bool KgpgApp::checkEncoding()
+bool KgpgApp::checkEncoding(QTextCodec *codec)
 {
-//KGlobal::charsets()->codecForName(encodingAction->currentText());                    ///     encoding selected
  /////////////          KGlobal::locale()->encoding()->name()
-//QTextCodec *codec = KGlobal::charsets()->codecForName(KGlobal::locale()->encoding());  // "Latin1"
-QTextCodec *codec =QTextCodec::codecForLocale ();
 return codec->canEncode(view->editor->text());
 }
 
 void KgpgApp::slotFileSave()
 {
+    QString filn=Docname.path();
+    if (filn.isEmpty()) {
+    	slotFileSaveAs();
+    	return;
+    }
+    QTextCodec*cod=QTextCodec::codecForName (textEncoding.ascii());
         // slotStatusMsg(i18n("Saving file..."));
-if (!checkEncoding()) 
-{
-KMessageBox::sorry(this,i18n("The document could not been saved, as the selected encoding cannot encode every unicode character in it!"));
-return;
-}
-        QString filn=Docname.path();
-        if (filn.isEmpty()) {
-                slotFileSaveAs();
-                return;
-        }
+    if (!checkEncoding(cod)) {
+	KMessageBox::sorry(this,i18n("The document could not been saved, as the selected encoding cannot encode every unicode character in it."));
+	return;
+    }
 
-	KTempFile tmpfile;
-	if (Docname.isLocalFile())
-	{
-	QFile f(filn);
-        if ( !f.open( IO_WriteOnly ) ) {
-		KMessageBox::sorry(this,i18n("The document could not be saved, please check your permissions and disk space."));
-                return;
-        }
-        QTextStream t( &f );
-        t << view->editor->text().utf8();
-        f.close();
-	}
-	else 
-	{
+    KTempFile tmpfile;
+    if (Docname.isLocalFile()) {
+    QFile f(filn);
+    if ( !f.open( IO_WriteOnly ) ) {
+	KMessageBox::sorry(this,i18n("The document could not be saved, please check your permissions and disk space."));
+        return;
+    }
+    QTextStream t( &f );
+    t.setCodec(cod);
+    //t.setEncoding( QTextStream::Latin1 );
+    t << view->editor->text();//.utf8();
+    f.close();
+    }
+    else {
+	/*FIXME  use following code:
+	 QFile f( fName );
+00983         if ( !f.open( IO_ReadOnly ) )
+00984             return;
+00985         QFileInfo info ( f );
+00986         smModificationTime = new QTime( info.lastModified().time() );
+00987         QTextStream t(&f);
+00988         t.setEncoding( QTextStream::Latin1 );
+00989         QString s = t.readLine();
+00990         f.close();
+
+*/
 	QTextStream *stream = tmpfile.textStream();
-    	*stream << view->editor->text().utf8();
+	stream->setCodec(cod);
+    	*stream << view->editor->text();//.utf8();
    	tmpfile.close();
-	if(!KIO::NetAccess::upload(tmpfile.name(), Docname))
-	{
-		KMessageBox::sorry(this,i18n("The document could not be saved, please check your permissions and disk space."));
-		tmpfile.unlink();
-                return;
+	if(!KIO::NetAccess::upload(tmpfile.name(), Docname,this)) {
+	    KMessageBox::sorry(this,i18n("The document could not be saved, please check your permissions and disk space."));
+	    tmpfile.unlink();
+            return;
 	}
 	tmpfile.unlink();
-	}
-	
-        fileSave->setEnabled(false);
-        setCaption(Docname.fileName(),false);
+    }
+
+    fileSave->setEnabled(false);
+    setCaption(Docname.fileName(),false);
 }
 
 
 void KgpgApp::slotFileSaveAs()
 {
 
-        KURL url=KFileDialog::getSaveURL(QDir::currentDirPath(),
-                                         i18n("*|All Files"), this, i18n("Save As"));
+        //KURL url=KFileDialog::getSaveURL(QDir::currentDirPath(),i18n("*|All Files"), this, i18n("Save As"));
+	KEncodingFileDialog::Result saveResult;
+	saveResult=KEncodingFileDialog::getSaveURLAndEncoding (QString::null,QString::null,QString::null,this);
+	KURL url=saveResult.URLs.first();
+	QString selectedEncoding=saveResult.encoding;
+
 	if(!url.isEmpty()) {
 		if (url.isLocalFile())
 		{
                 QString filn=url.path();
                 QFile f(filn);
                 if (f.exists()) {
-                        QString message=i18n("Overwrite existing file %1?").arg(url.filename());
+                        QString message=i18n("Overwrite existing file %1?").arg(url.fileName());
                         int result=KMessageBox::warningContinueCancel(this,QString(message),i18n("Warning"),i18n("Overwrite"));
                         if (result==KMessageBox::Cancel)
                                 return;
                 }
                 f.close();
 		}
-		else if (KIO::NetAccess::exists(url))
+		else if (KIO::NetAccess::exists(url,false,this))
 		{
-		QString message=i18n("Overwrite existing file %1?").arg(url.filename());
+		QString message=i18n("Overwrite existing file %1?").arg(url.fileName());
                         int result=KMessageBox::warningContinueCancel(this,QString(message),i18n("Warning"),i18n("Overwrite"));
                         if (result==KMessageBox::Cancel)
                                 return;
 		}
 	Docname=url;
+	textEncoding=selectedEncoding;
 	slotFileSave();
 	}
 }
 
-void KgpgApp::openDocumentFile(const KURL& url)
+void KgpgApp::openDocumentFile(const KURL& url,QString encoding)
 {
 QString tempOpenFile;
         /////////////////////////////////////////////////
-if( KIO::NetAccess::download( url, tempOpenFile ) ) {
+if( KIO::NetAccess::download( url, tempOpenFile,this ) ) {
         QFile qfile(tempOpenFile);
         if (qfile.open(IO_ReadOnly)) {
                 QTextStream t( &qfile );
+		t.setCodec(QTextCodec::codecForName (encoding.ascii()));
                 view->editor->setText(t.read());
                 qfile.close();
                 fileSave->setEnabled(false);
@@ -342,7 +416,7 @@ if( KIO::NetAccess::download( url, tempOpenFile ) ) {
 void KgpgApp::slotFilePrint()
 {
         KPrinter prt;
-        //kdDebug()<<"Printing..."<<endl;
+        //kdDebug(2100)<<"Printing..."<<endl;
         if (prt.setup(this)) {
                 QPainter painter(&prt);
                 QPaintDeviceMetrics metrics(painter.device());
@@ -370,16 +444,6 @@ void KgpgApp::slotSelectAll()
         view->editor->selectAll();
 }
 
-/*void KgpgApp::slotOptions()
-{
-  /////////////////////// open option dialog box --> kgpgoptions.cpp
-  kgpgOptions *opts=new kgpgOptions(this);
-  opts->exec();
-  delete opts;
-  readOptions(false);
-}
-*/
-
 void KgpgApp::slotundo()
 {
         view->editor->undo();
@@ -405,7 +469,7 @@ void KgpgApp::slotCheckMd5()
                 Md5Widget *mdwidget=new Md5Widget(this,0,url);
                 mdwidget->exec();
                 delete mdwidget;
-                //      KMessageBox::information(this,QString("MD5 sum for "+url.filename()+" is:\n"+checkfile.hexDigest().data()));
+                //      KMessageBox::information(this,QString("MD5 sum for "+url.fileName()+" is:\n"+checkfile.hexDigest().data()));
         }
 }
 
@@ -455,7 +519,7 @@ void KgpgApp::slotVerifyFile(KURL url)
         QString sigfile=QString::null;
         if (!url.isEmpty()) {
                 //////////////////////////////////////       try to find detached signature.
-                if (!url.filename().endsWith(".sig")) {
+                if (!url.fileName().endsWith(".sig")) {
                         sigfile=url.path()+".sig";
                         QFile fsig(sigfile);
                         if (!fsig.exists()) {
