@@ -175,7 +175,7 @@ void KgpgInterface::KgpgDecryptFile(KURL srcUrl,KURL destUrl,QStringList Options
 		for ( QStringList::Iterator it = Options.begin(); it != Options.end(); ++it )
        		if (!QFile::encodeName(*it).isEmpty()) *proc<< QFile::encodeName(*it);
 
-		if (!destUrl.filename().isEmpty()) // a filename was entered
+		if (!destUrl.fileName().isEmpty()) // a filename was entered
 				*proc<<"-o"<<QFile::encodeName(destUrl.path());
         
                 *proc<<"-d"<<QFile::encodeName(srcUrl.path());
@@ -190,9 +190,10 @@ void KgpgInterface::decryptfin(KProcess *)
         if ((message.find("DECRYPTION_OKAY")!=-1) && (message.find("END_DECRYPTION")!=-1)) //&& (message.find("GOODMDC")!=-1)
                 emit decryptionfinished();
         else
-                emit errormessage(message);
+	emit errormessage(message);
 }
 
+
 void KgpgInterface::readdecprocess(KProcIO *p)
 {
         QString required;
@@ -246,14 +247,13 @@ void KgpgInterface::readdecprocess(KProcIO *p)
 void KgpgInterface::KgpgEncryptText(QString text,QStringList userIDs, QStringList Options)
 {
         message=QString::null;
-	QString txtprocess;
 	//QTextCodec *codec = KGlobal::charsets()->codecForName(KGlobal::locale()->encoding());
 	QTextCodec *codec =QTextCodec::codecForLocale ();
-	if (codec->canEncode(text)) txtprocess=text;
-	else txtprocess=text.utf8();
+	if (codec->canEncode(text)) txtToEncrypt=text;
+	else txtToEncrypt=text.utf8();
 	
         KProcIO *proc=new KProcIO();
-        *proc<<"gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--command-fd=0"<<"--status-fd=2";
+        *proc<<"gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--command-fd=0"<<"--status-fd=1";
         
 	for ( QStringList::Iterator it = Options.begin(); it != Options.end(); ++it )
        		if (!QFile::encodeName(*it).isEmpty()) *proc<< QFile::encodeName(*it);
@@ -264,16 +264,15 @@ void KgpgInterface::KgpgEncryptText(QString text,QStringList userIDs, QStringLis
 	for ( QStringList::Iterator it = userIDs.begin(); it != userIDs.end(); ++it )
        		*proc<<"--recipient"<< *it;
 	}
-	else *proc<<"-c";
-
+	else 
+	  *proc<<"-c";
+	
         /////////  when process ends, update dialog infos
 
         QObject::connect(proc, SIGNAL(processExited(KProcess *)),this,SLOT(txtencryptfin(KProcess *)));
         QObject::connect(proc,SIGNAL(readReady(KProcIO *)),this,SLOT(txtreadencprocess(KProcIO *)));
         proc->start(KProcess::NotifyOnExit,false);
 	emit txtencryptionstarted();
-	proc->writeStdin(txtprocess,false);
-	proc->closeWhenDone();
 }
 
 
@@ -289,6 +288,13 @@ void KgpgInterface::txtreadencprocess(KProcIO *p)
 {
         QString required;
         while (p->readln(required,true)!=-1) {
+	  if (required.find("BEGIN_ENCRYPTION",0,false)!=-1)
+	  {
+	    p->writeStdin(txtToEncrypt,false);
+	    txtToEncrypt=QString::null;
+	    p->closeWhenDone();
+	  }
+	  else
 	if ((required.find("passphrase.enter")!=-1))
             {
               QCString passphrase;
@@ -311,103 +317,115 @@ void KgpgInterface::txtreadencprocess(KProcIO *p)
 
 void KgpgInterface::KgpgDecryptText(QString text,QStringList Options)
 {
- QString txtprocess;
+  gpgOutput=QString::null;
+  log=QString::null;	
+  
   message=QString::null;
   userIDs=QString::null;
   step=3;
   anonymous=false;
-txtprocess=text;
-decfinished=false;
-decok=false;
-badmdc=false;
- KProcIO *proc=new KProcIO();
-	  *proc<<"gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--command-fd=0"<<"--status-fd=1"<<"--no-batch";
-      	for ( QStringList::Iterator it = Options.begin(); it != Options.end(); ++it )
-       		if (!QFile::encodeName(*it).isEmpty()) *proc<< QFile::encodeName(*it);
-
-      *proc<<"-d";
+  decfinished=false;
+  decok=false;
+  badmdc=false;
+  KProcess *proc=new KProcess();
+  *proc<<"gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--command-fd=0"<<"--status-fd=2"<<"--no-batch";
+  for ( QStringList::Iterator it = Options.begin(); it != Options.end(); ++it )
+	  if (!QFile::encodeName(*it).isEmpty()) *proc<< QFile::encodeName(*it);
+  *proc<<"-d";
 
   /////////  when process ends, update dialog infos
 
   QObject::connect(proc, SIGNAL(processExited(KProcess *)),this,SLOT(txtdecryptfin(KProcess *)));
-  QObject::connect(proc,SIGNAL(readReady(KProcIO *)),this,SLOT(txtreaddecprocess(KProcIO *)));
-  proc->start(KProcess::NotifyOnExit,false);
-  proc->writeStdin(txtprocess,false);
+  connect(proc, SIGNAL(receivedStdout(KProcess *, char *, int)),this, SLOT(getOutput(KProcess *, char *, int)));
+  connect(proc, SIGNAL(receivedStderr(KProcess *, char *, int)),this, SLOT(getCmdOutput(KProcess *, char *, int)));
+  proc->start(KProcess::NotifyOnExit,KProcess::All);
+  proc->writeStdin(text.ascii(),text.length());
 }
 
 void KgpgInterface::txtdecryptfin(KProcess *)
 {
 if ((decok) && (!badmdc)) 
-{
-message.remove(0,message.find("BEGIN_DECRYPTION")+17);
-if (message.find("[GNUPG:] DECRYPTION_OKAY")!=-1) message=message.left(message.findRev("[GNUPG:] DECRYPTION_OKAY",-1,false)); 
 emit txtdecryptionfinished(message);
-}
+
 else if (badmdc) 
 {
 KMessageBox::sorry(0,i18n("Bad MDC detected. The encrypted text has been manipulated."));
-emit txtdecryptionfailed(message);
+emit txtdecryptionfailed(log);
 }
 else
-emit txtdecryptionfailed(message);
+emit txtdecryptionfailed(log);
 }
 
-void KgpgInterface::txtreaddecprocess(KProcIO *p)
-{
-  QString required;
-  while (p->readln(required,true)!=-1)
-    {
-	{
-	if (required.find("USERID_HINT",0,false)!=-1)
-        updateIDs(required);
-	
-      if (required.find("ENC_TO")!=-1)
-        {
-          if (required.find("0000000000000000")!=-1)
-            anonymous=true;
-        }
-      if (required.find("GET_")!=-1)
-        {
-         if ((required.find("passphrase.enter")!=-1))
-            {
-              if (userIDs.isEmpty())
-                userIDs=i18n("[No user id found]");
-              QCString passphrase;
-              QString passdlgmessage;
-              if (anonymous)
-                passdlgmessage=i18n("<b>No user id found</b>. Trying all secret keys.<br>");
-              if ((step<3) && (!anonymous))
-                passdlgmessage=i18n("<b>Bad passphrase</b>. You have %1 tries left.<br>").arg(step);
-              passdlgmessage+=i18n("Enter passphrase for <b>%1</b>").arg(checkForUtf8bis(userIDs));
-              int code=KPasswordDialog::getPassword(passphrase,passdlgmessage);
-              if (code!=QDialog::Accepted)
-                {
-                  delete p;
-                  emit processaborted(true);
-                  return;
-                }
-              p->writeStdin(passphrase,true);
-              userIDs=QString::null;
-              //p->writeStdin("\n");
-              step--;
-            }
-		  else
-           p->writeStdin("quit");
-        }
-		message+=required+"\n";
-		if (required.find("BEGIN_DECRYPTION")!=-1)
-      		{
-			p->closeStdin();
-			required=QString::null;
-			}
 
-	  if (required.find("END_DECRYPTION")!=-1) decfinished=true;
-	  if (required.find("DECRYPTION_OKAY")!=-1) decok=true;
-	  if (required.find("BADMDC")!=-1) badmdc=true;
-    }
+void KgpgInterface::getOutput(KProcess *, char *data, int )
+{
+	message.append(data);
+}
+
+
+void KgpgInterface::getCmdOutput(KProcess *p, char *data, int )
+{
+  gpgOutput.append(data);
+  log.append(data);
+
+  int pos;
+  while ((pos=gpgOutput.find("\n"))!=-1)
+  {	
+	QString required=gpgOutput.left(pos);
+	gpgOutput.remove(0,pos+2);
+			
+	if (required.find("USERID_HINT",0,false)!=-1)
+		updateIDs(required);
+	
+	if (required.find("ENC_TO")!=-1)
+	{
+		if (required.find("0000000000000000")!=-1)
+			anonymous=true;
+	}
+		
+	if (required.find("GET_")!=-1)
+	{
+		if ((required.find("passphrase.enter")!=-1))
+		{
+			if (userIDs.isEmpty())
+			userIDs=i18n("[No user id found]");
+			QCString passphrase;
+			QString passdlgmessage;
+			if (anonymous)
+				passdlgmessage=i18n("<b>No user id found</b>. Trying all secret keys.<br>");
+			if ((step<3) && (!anonymous))
+				passdlgmessage=i18n("<b>Bad passphrase</b>. You have %1 tries left.<br>").arg(step);
+			passdlgmessage+=i18n("Enter passphrase for <b>%1</b>").arg(checkForUtf8bis(userIDs));
+			int code=KPasswordDialog::getPassword(passphrase,passdlgmessage);
+			if (code!=QDialog::Accepted)
+			{
+				delete p;
+				emit processaborted(true);
+				return;
+			}
+			passphrase.append("\n");
+			p->writeStdin(passphrase,passphrase.length());
+			userIDs=QString::null;
+			step--;
+		}
+		else
+		{
+			p->writeStdin("quit",4);
+			p->closeStdin();
+		}
+	}
+	
+	if (required.find("BEGIN_DECRYPTION")!=-1)
+	{
+		p->closeStdin();
+		required=QString::null;
+	}
+
+	if (required.find("END_DECRYPTION")!=-1) decfinished=true;
+	if (required.find("DECRYPTION_OKAY")!=-1) decok=true;
+	if (required.find("BADMDC")!=-1) badmdc=true;
 	}
 }
-
 //////////////////////////////////////////////////////////////////////////////////////////////////////////    Text signing
 
 
@@ -562,7 +580,9 @@ QString required;
     required=required.section("]",1,-1).stripWhiteSpace();
      if (required.startsWith("GOODSIG"))
      {
-     signID=i18n("<qt>Good signature from:<br><b>%1</b><br>Key ID: %2</qt>").arg(required.section(" ",2,-1).replace(QRegExp("<"),"&lt;")).arg("0x"+required.section(" ",1,1).right(8));
+	     QString userName=required.section(" ",2,-1).replace(QRegExp("<"),"&lt;");
+	     userName=checkForUtf8(userName);
+     signID=i18n("<qt>Good signature from:<br><b>%1</b><br>Key ID: %2</qt>").arg(userName).arg("0x"+required.section(" ",1,1).right(8));
      }
      if (required.startsWith("BADSIG")) 
      {
@@ -602,7 +622,7 @@ Md5Widget::Md5Widget(QWidget *parent, const char *name,KURL url):KDialogBase( pa
         QGridLayout *MyDialogLayout = new QGridLayout( page, 1, 1, 5, 6, "MyDialogLayout");
 
         QLabel *TextLabel1 = new QLabel( page, "TextLabel1" );
-        TextLabel1->setText(i18n("MD5 sum for <b>%1</b> is:").arg(url.filename()));
+        TextLabel1->setText(i18n("MD5 sum for <b>%1</b> is:").arg(url.fileName()));
         MyDialogLayout->addWidget( TextLabel1, 0, 0 );
 
         KLineEdit *KRestrictedLine1 = new KLineEdit(mdSum,page);
@@ -689,7 +709,7 @@ void KgpgInterface::KgpgSignFile(QString keyID,KURL srcUrl,QStringList Options)
 void KgpgInterface::signfin(KProcess *)
 {
         if (message.find("SIG_CREATED")!=-1)
-                KMessageBox::information(0,i18n("The signature file %1 was successfully created.").arg(file.filename()));
+                KMessageBox::information(0,i18n("The signature file %1 was successfully created.").arg(file.fileName()));
         else if (message.find("BAD_PASSPHRASE")!=-1)
                 KMessageBox::sorry(0,i18n("Bad passphrase, signature was not created."));
         else
@@ -800,7 +820,7 @@ void KgpgInterface::verifyfin(KProcess *)
     }
     else {
     	if (KMessageBox::questionYesNo(0,i18n("<qt><b>Missing signature:</b><br>Key id: %1<br><br>"
-                                                      "Do you want to import this key from a keyserver?</qt>").arg(signID),file.filename())==KMessageBox::Yes)
+                                                      "Do you want to import this key from a keyserver?</qt>").arg(signID),file.fileName())==KMessageBox::Yes)
     	emit verifyquerykey(signID);
     }
     emit verifyfinished();
@@ -1141,36 +1161,26 @@ void KgpgInterface::expover(KProcess *)
 ///////////////////////////////////////////////////////////////    change key trust
 
 
-void KgpgInterface::KgpgTrustExpire(QString keyID,QString keyTrust)
+void KgpgInterface::KgpgTrustExpire(QString keyID,int keyTrust)
 {
-        if (keyTrust==i18n("Don't know"))
-                trustValue=1;
-        if (keyTrust==i18n("Do NOT trust"))
-                trustValue=2;
-        if (keyTrust==i18n("Marginally"))
-                trustValue=3;
-        if (keyTrust==i18n("Fully"))
-                trustValue=4;
-        if (keyTrust==i18n("Ultimately"))
-                trustValue=5;
-
+	trustValue=keyTrust+1;
+/*	Don't know=1; Do NOT trust=2; Marginally=3; Fully=4; Ultimately=5;   */
+	
         output=QString::null;
         KProcIO *conprocess=new KProcIO();
         *conprocess<<"gpg"<<"--no-secmem-warning"<<"--no-tty"<<"--command-fd=0"<<"--status-fd=2";
         *conprocess<<"--edit-key"<<keyID<<"trust";
         QObject::connect(conprocess,SIGNAL(readReady(KProcIO *)),this,SLOT(trustprocess(KProcIO *)));
         QObject::connect(conprocess, SIGNAL(processExited(KProcess *)),this, SLOT(trustover(KProcess *)));
-        conprocess->start(KProcess::NotifyOnExit,KProcess::AllOutput);
+        conprocess->start(KProcess::NotifyOnExit,true);
 
 }
 
 void KgpgInterface::trustprocess(KProcIO *p)
 {
         QString required=QString::null;
-
         while (p->readln(required,true)!=-1) {
                 output+=required+"\n";
-
                 if (required.find("edit_ownertrust.set_ultimate.okay")!=-1) {
                         p->writeStdin("YES");
                         required=QString::null;
@@ -1183,6 +1193,7 @@ void KgpgInterface::trustprocess(KProcIO *p)
 
                 if (required.find("keyedit.prompt")!=-1) {
                         p->writeStdin("save");
+			p->closeWhenDone();
                         required=QString::null;
                 }
 
@@ -1385,34 +1396,34 @@ kdDebug(2100)<<"Importing is over"<<endl;
                 parsedOutput=message.section("IMPORT_RES",-1,-1).stripWhiteSpace();
 		messageList=QStringList::split(" ",parsedOutput,true);
                 	
-                resultMessage=i18n("<qt>%1 key(s) processed.<br></qt>").arg(messageList[0]);
+                resultMessage=i18n("<qt>%n key processed.<br></qt>","<qt>%n keys processed.<br></qt>",messageList[0].toULong());
                 if (messageList[4]!="0")
-                        resultMessage+=i18n("<qt>%1 key(s) unchanged.<br></qt>").arg(messageList[4]);
+                        resultMessage+=i18n("<qt>One key unchanged.<br></qt>","<qt>%n keys unchanged.<br></qt>",messageList[4].toULong());
                 if (messageList[7]!="0")
-                        resultMessage+=i18n("<qt>%1 signature(s) imported.<br></qt>").arg(messageList[7]);
+                        resultMessage+=i18n("<qt>One signature imported.<br></qt>","<qt>%n signatures imported.<br></qt>",messageList[7].toULong());
                 if (messageList[1]!="0")
-                        resultMessage+=i18n("<qt>%1 key(s) without ID.<br></qt>").arg(messageList[1]);
+                        resultMessage+=i18n("<qt>One key without ID.<br></qt>","<qt>%n keys without ID.<br></qt>",messageList[1].toULong());
                 if (messageList[3]!="0")
-                        resultMessage+=i18n("<qt>%1 RSA key(s) imported.<br></qt>").arg(messageList[3]);
+                        resultMessage+=i18n("<qt>One RSA key imported.<br></qt>","<qt>%n RSA keys imported.<br></qt>",messageList[3].toULong());
                 if (messageList[5]!="0")
-                        resultMessage+=i18n("<qt>%1 user ID(s) imported.<br></qt>").arg(messageList[5]);
+                        resultMessage+=i18n("<qt>One user ID imported.<br></qt>","<qt>%n user IDs imported.<br></qt>",messageList[5].toULong());
                 if (messageList[6]!="0")
-                        resultMessage+=i18n("<qt>%1 subkey(s) imported.<br></qt>").arg(messageList[6]);
+                        resultMessage+=i18n("<qt>One subkey imported.<br></qt>","<qt>%n subkeys imported.<br></qt>",messageList[6].toULong());
                 if (messageList[8]!="0")
-                        resultMessage+=i18n("<qt>%1 revocation certificate(s) imported.<br></qt>").arg(messageList[8]);
+                        resultMessage+=i18n("<qt>One revocation certificate imported.<br></qt>","<qt>%n revocation certificates imported.<br></qt>",messageList[8].toULong());
                 if (messageList[9]!="0")
 			{
-                        resultMessage+=i18n("<qt>%1 secret key(s) processed.<br></qt>").arg(messageList[9]);
+                        resultMessage+=i18n("<qt>One secret key processed.<br></qt>","<qt>%n secret keys processed.<br></qt>",messageList[9].toULong());
 			secretImport=true;
 			}
                 if (messageList[10]!="0")
-                        resultMessage+=i18n("<qt><b>%1 secret key(s) imported.</b><br></qt>").arg(messageList[10]);
+                        resultMessage+=i18n("<qt><b>One secret key imported.</b><br></qt>","<qt><b>%n secret keys imported.</b><br></qt>",messageList[10].toULong());
                 if (messageList[11]!="0")
-                        resultMessage+=i18n("<qt>%1 secret key(s) unchanged.<br></qt>").arg(messageList[11]);
+                        resultMessage+=i18n("<qt>One secret key unchanged.<br></qt>","<qt>%n secret keys unchanged.<br></qt>",messageList[11].toULong());
                 if (messageList[12]!="0")
-                        resultMessage+=i18n("<qt>%1 secret key(s) not imported.<br></qt>").arg(messageList[12]);
+                        resultMessage+=i18n("<qt>One secret key not imported.<br></qt>","<qt>%n secret keys not imported.<br></qt>",messageList[12].toULong());
                 if (messageList[2]!="0")
-                        resultMessage+=i18n("<qt><b>%1 key(s) imported:</b><br></qt>").arg(messageList[2]);
+                        resultMessage+=i18n("<qt><b>One key imported:</b><br></qt>","<qt><b>%n keys imported:</b><br></qt>",messageList[2].toULong());
 			
 		if (secretImport) resultMessage+=i18n("<qt><br><b>You have imported a secret key.</b> <br>"
 									"Please note that imported secret keys are not trusted by default.<br>"
@@ -2074,10 +2085,10 @@ QString KgpgInterface::checkForUtf8(QString txt)
                 str[0] = (char) QString( txt.mid( idx + 2, 2 ) ).toShort( 0, 16 );
                 txt.replace( idx, 4, str );
         }
-	if (!strchr (txt.ascii(), 0xc3))
+//	if (!strchr (txt.ascii(), 0xc3))
                 return QString::fromUtf8(txt.ascii());
-        else
-                return QString::fromUtf8(QString::fromUtf8(txt.ascii()).ascii());  // perform Utf8 twice, or some keys display badly
+//        else
+//                return QString::fromUtf8(QString::fromUtf8(txt.ascii()).ascii());  // perform Utf8 twice, or some keys display badly
 }
 
 
