@@ -51,7 +51,7 @@ void KgpgLibrary::slotFileEnc(KURL::List urls,QStringList opts,QString defaultKe
         if (!urls.empty()) {
                 urlselecteds=urls;
                 if (defaultKey.isEmpty()) {
-			QString fileNames=urls.first().filename();
+			QString fileNames=urls.first().fileName();
 			if (urls.count()>1) fileNames+=",...";
                         popupPublic *dialogue=new popupPublic(0,"Public keys",fileNames,true,goDefaultKey);
                         connect(dialogue,SIGNAL(selectedKey(QStringList,QStringList,bool,bool)),this,SLOT(startencode(QStringList,QStringList,bool,bool)));
@@ -140,7 +140,7 @@ void KgpgLibrary::shredpreprocessenc(KURL fileToShred)
 
 void KgpgLibrary::shredprocessenc(KURL::List filesToShred)
 {
-emit systemMessage(i18n("Shredding %1 file(s)").arg(filesToShred.count()));
+emit systemMessage(i18n("Shredding %n file","Shredding %n files",filesToShred.count()));
 
 KIO::Job *job;
 job = KIO::del( filesToShred, true );
