@@ -2,7 +2,7 @@
                           popuppublic.cpp  -  description
                              -------------------
     begin                : Sat Jun 29 2002
-    copyright          : (C) 2002 by Jean-Baptiste Mardelle
+    copyright            : (C) 2002 by Jean-Baptiste Mardelle
     email                : bj@altern.org
  ***************************************************************************/
 
@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 ////////////////////////////////////////////////////////   code  for choosing a public key from a list for encryption
+#include <qlayout.h>
 #include <qpushbutton.h>
 #include <qptrlist.h>
 #include <qwhatsthis.h>
@@ -23,11 +24,24 @@
 #include <qiconset.h>
 #include <qbuttongroup.h>
 #include <qcheckbox.h>
+#include <qhbuttongroup.h>
+#include <qtoolbutton.h>
+
+#include <kdeversion.h>
 #include <klistview.h>
 #include <kprocess.h>
 #include <kprocio.h>
-#include <qhbuttongroup.h>
 #include <klocale.h>
+#include <kaccel.h>
+#if KDE_IS_VERSION( 3, 2, 90 )
+#include <klistviewsearchline.h>
+#endif
+#include <kactivelabel.h>
+#include <kaction.h>
+#include <kdebug.h>
+#include <kiconloader.h>
+#include <klineedit.h>
+
 
 #include "popuppublic.h"
 #include "kgpgsettings.h"
@@ -72,14 +86,14 @@ QString UpdateViewItem2 :: key(int c,bool ) const
 
 ///////////////  main view
 
-popupPublic::popupPublic(QWidget *parent, const char *name,QString sfile,bool filemode): 
+popupPublic::popupPublic(QWidget *parent, const char *name,QString sfile,bool filemode,KShortcut goDefaultKey):
 KDialogBase( Plain, i18n("Select Public Key"), Details | Ok | Cancel, Ok, parent, name,true)
 {
 
 	QWidget *page = plainPage();
 	QVBoxLayout *vbox=new QVBoxLayout(page,0,spacingHint());
 	vbox->setAutoAdd(true);
-	
+
 	setButtonText(KDialogBase::Details,i18n("Options"));
 
         if (KGpgSettings::allowCustomEncryptionOptions())
@@ -90,15 +104,32 @@ KDialogBase( Plain, i18n("Select Public Key"), Details | Ok | Cancel, Ok, parent
         keyPair=loader->loadIcon("kgpg_key2",KIcon::Small,20);
         keySingle=loader->loadIcon("kgpg_key1",KIcon::Small,20);
 	keyGroup=loader->loadIcon("kgpg_key3",KIcon::Small,20);
-	
+
         if (filemode) setCaption(i18n("Select Public Key for %1").arg(sfile));
-
-        fmode=filemode;
-
+        fmode=filemode;	
+	
+	QHButtonGroup *hBar=new QHButtonGroup(page);
+	//hBar->setFrameStyle(QFrame::NoFrame);
+	hBar->setMargin(0);
+	
+#if KDE_IS_VERSION( 3, 2, 90 )
+	QToolButton *clearSearch = new QToolButton(hBar);
+	clearSearch->setTextLabel(i18n("Clear Search"), true);
+	clearSearch->setIconSet(SmallIconSet(QApplication::reverseLayout() ? "clear_left"
+                                            : "locationbar_erase"));
+	(void) new QLabel(i18n("Search: "),hBar);
+	KListViewSearchLine* listViewSearch = new KListViewSearchLine(hBar);
+	connect(clearSearch, SIGNAL(pressed()), listViewSearch, SLOT(clear()));
+#endif
+	
         keysList = new KListView( page );
 	 keysList->addColumn(i18n("Name"));
 	 keysList->addColumn(i18n("Email"));
 	 keysList->addColumn(i18n("ID"));
+	 
+#if KDE_IS_VERSION( 3, 2, 90 )
+	 listViewSearch->setListView(keysList);
+#endif
 
         keysList->setRootIsDecorated(false);
         page->setMinimumSize(540,200);
@@ -112,7 +143,11 @@ KDialogBase( Plain, i18n("Select Public Key"), Details | Ok | Cancel, Ok, parent
 	keysList->setColumnWidth(1,210);
 
         boutonboxoptions=new QButtonGroup(5,Qt::Vertical ,page,0);
-
+	
+	KActionCollection *actcol=new KActionCollection(this);
+	(void) new KAction(i18n("&Go to Default Key"),goDefaultKey, this, SLOT(slotGotoDefaultKey()),actcol,"go_default_key");
+	
+	
         CBarmor=new QCheckBox(i18n("ASCII armored encryption"),boutonboxoptions);
         CBuntrusted=new QCheckBox(i18n("Allow encryption with untrusted keys"),boutonboxoptions);
         CBhideid=new QCheckBox(i18n("Hide user id"),boutonboxoptions);
@@ -131,14 +166,23 @@ KDialogBase( Plain, i18n("Select Public Key"), Details | Ok | Cancel, Ok, parent
                                   "box enables you to use any key, even if it has not be signed."));
 
         if (filemode) {
-                CBshred=new QCheckBox(i18n("Shred source file"),boutonboxoptions);
+		QWidget *parentBox=new QWidget(boutonboxoptions);
+		QHBoxLayout *shredBox=new QHBoxLayout(parentBox,0);
+		//shredBox->setFrameStyle(QFrame::NoFrame);
+		//shredBox->setMargin(0);
+	       CBshred=new QCheckBox(i18n("Shred source file"),parentBox);
                 QWhatsThis::add
                         (CBshred,i18n("<b>Shred source file</b>: permanently remove source file. No recovery will be possible"));
+			
+		QString shredWhatsThis = i18n( "<qt><b>Shred source file:</b><br /><p>Checking this option will shred (overwrite several times before erasing) the files you have encrypted. This way, it is almost impossible that the source file is recovered.</p><p><b>But you must be aware that this is not secure</b> on all file systems, and that parts of the file may have been saved in a temporary file or in the spooler of your printer if you previously opened it in an editor or tried to print it. Only works on files (not on folders).</p></qt>");
+		  KActiveLabel *warn= new KActiveLabel( i18n("<a href=\"whatsthis:%1\">Read this before using shredding</a>").arg(shredWhatsThis),parentBox );
+		  shredBox->addWidget(CBshred);
+		  shredBox->addWidget(warn);
         }
-	
+
 	        CBsymmetric=new QCheckBox(i18n("Symmetrical encryption"),boutonboxoptions);
                 QWhatsThis::add
-                        (CBsymmetric,i18n("<b>Symmetrical encryption</b>: encryption doesn't use keys. You just need to give a password "
+                        (CBsymmetric,i18n("<b>Symmetrical encryption</b>: encryption does not use keys. You just need to give a password "
                                           "to encrypt/decrypt the file"));
                 QObject::connect(CBsymmetric,SIGNAL(toggled(bool)),this,SLOT(isSymetric(bool)));
 
@@ -146,7 +190,7 @@ KDialogBase( Plain, i18n("Select Public Key"), Details | Ok | Cancel, Ok, parent
 	CBuntrusted->setChecked( KGpgSettings::allowUntrustedKeys() );
 	CBhideid->setChecked( KGpgSettings::hideUserID() );
 	if (filemode) CBshred->setChecked( KGpgSettings::shredSource() );
-        
+
         if (KGpgSettings::allowCustomEncryptionOptions()) {
                 QHButtonGroup *bGroup = new QHButtonGroup(page);
                 //bGroup->setFrameStyle(QFrame::NoFrame);
@@ -160,18 +204,21 @@ KDialogBase( Plain, i18n("Select Public Key"), Details | Ok | Cancel, Ok, parent
         QObject::connect(keysList,SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),this,SLOT(slotOk()));
 //	QObject::connect(this,SIGNAL(okClicked()),this,SLOT(crypte()));
         QObject::connect(CBuntrusted,SIGNAL(toggled(bool)),this,SLOT(refresh(bool)));
-	
+
         char line[200]="\0";
         FILE *fp2;
         seclist=QString::null;
 
-        fp2 = popen("gpg --no-secmem-warning --no-tty --list-secret-keys ", "r");
+        fp2 = popen("gpg --no-secmem-warning --no-tty --with-colon --list-secret-keys ", "r");
         while ( fgets( line, sizeof(line), fp2))
-                seclist+=line;
+        {
+	QString readLine=line;
+	if (readLine.startsWith("sec")) seclist+=", 0x"+readLine.section(":",4,4).right(8);
+	}
         pclose(fp2);
 
         trusted=CBuntrusted->isChecked();
-	
+
         refreshkeys();
 	setMinimumSize(550,200);
 	updateGeometry();
@@ -182,9 +229,10 @@ KDialogBase( Plain, i18n("Select Public Key"), Details | Ok | Cancel, Ok, parent
 popupPublic::~popupPublic()
 {}
 
+
 void popupPublic::slotAccept()
 {
-accept(); 
+accept();
 }
 
 void popupPublic::enable()
@@ -197,6 +245,7 @@ void popupPublic::enable()
                 current = current->nextSibling();
                 current->setVisible(true);
         }
+	keysList->ensureItemVisible(keysList->currentItem());
 }
 
 void popupPublic::sort()
@@ -225,7 +274,7 @@ void popupPublic::sort()
 		}
         }
 
-        if (reselect) {
+	if (reselect || !keysList->currentItem()->isVisible()) {
                 QListViewItem *firstvisible;
                 firstvisible=keysList->firstChild();
                 while (firstvisible->isVisible()!=true) {
@@ -234,7 +283,7 @@ void popupPublic::sort()
                                 return;
                 }
                 keysList->setSelected(firstvisible,true);
-                keysList->setCurrentItem(firstvisible);
+		keysList->setCurrentItem(firstvisible);
 		keysList->ensureItemVisible(firstvisible);
         }
 }
@@ -252,6 +301,15 @@ void popupPublic::customOpts(const QString &str)
         customOptions=str;
 }
 
+void popupPublic::slotGotoDefaultKey()
+{
+    QListViewItem *myDefaulKey = keysList->findItem(KGpgSettings::defaultKey(),2);
+    keysList->clearSelection();
+    keysList->setCurrentItem(myDefaulKey);
+    keysList->setSelected(myDefaulKey,true);
+    keysList->ensureItemVisible(myDefaulKey);
+}
+
 void popupPublic::refresh(bool state)
 {
         if (state)
@@ -285,23 +343,18 @@ void popupPublic::refreshkeys()
 
 void popupPublic::slotpreselect()
 {
-QListViewItem *it;
+QListViewItem *it=NULL;
+if (!keysList->firstChild()) return;
         if (fmode) it=keysList->findItem(KGpgSettings::defaultKey(),2);
-        else {
-                it=keysList->firstChild();
-                if (it==NULL)
-                        return;
-                while (!it->isVisible()) {
-                        it=it->nextSibling();
-                        if (it==NULL)
-                                return;
-                }
-        }
+if (!trusted)
+              sort();
+if (fmode) 
+{
+  	keysList->clearSelection();
 	keysList->setSelected(it,true);
 	keysList->setCurrentItem(it);
 	keysList->ensureItemVisible(it);
-        if (!trusted)
-              sort();
+}	
 emit keyListFilled();
 }
 
@@ -338,7 +391,7 @@ void popupPublic::slotprocread(KProcIO *p)
                         case 'd':
                                 dead=true;
                                 break;
-                        case 'r':
+                       case 'r':
                                 dead=true;
                                 break;
                         case 'e':
@@ -367,11 +420,11 @@ void popupPublic::slotprocread(KProcIO *p)
                 keymail=tst.section('<',-1,-1);
                 keymail.truncate(keymail.length()-1);
                 keyname=tst.section('<',0,0);
-                if (keyname.find("(")!=-1)
-                        keyname=keyname.section('(',0,0);
+                //if (keyname.find("(")!=-1)
+                 //       keyname=keyname.section('(',0,0);
         } else {
                 keymail=QString::null;
-                keyname=tst.section('(',0,0);
+                keyname=tst;//.section('(',0,0);
         }
 
 	keyname=KgpgInterface::checkForUtf8(keyname);
@@ -395,19 +448,20 @@ void popupPublic::slotprocread(KProcIO *p)
 void popupPublic::slotOk()
 {
         //////   emit selected data
-kdDebug()<<"Ok pressed"<<endl;
+kdDebug(2100)<<"Ok pressed"<<endl;
         QStringList selectedKeys;
 	QString userid;
         QPtrList<QListViewItem> list=keysList->selectedItems();
 
         for ( uint i = 0; i < list.count(); ++i )
-                if ( list.at(i) ) {
-			if (!list.at(i)->text(2).isEmpty()) selectedKeys<<list.at(i)->text(2);
+	  if ( list.at(i) && list.at(i)->isVisible()) {
+	  		if (!list.at(i)->text(2).isEmpty()) selectedKeys<<list.at(i)->text(2);
 			else selectedKeys<<list.at(i)->text(0);
                 }
         if (selectedKeys.isEmpty() && !CBsymmetric->isChecked())
                 return;
-kdDebug()<<"Selected Key:"<<selectedKeys<<endl;
+	if (CBsymmetric->isChecked()) selectedKeys=NULL;
+kdDebug(2100)<<"Selected Key:"<<selectedKeys<<endl;
         QStringList returnOptions;
         if (CBuntrusted->isChecked())
                 returnOptions<<"--always-trust";
