@@ -37,10 +37,6 @@
 #include "hexclipboard.h"
 #include "hexbuffer.h"
 
-#include <X11/Xlib.h> // For XQueryPointer()
-
-
-
 class CScrollBar : public QScrollBar
 {
   Q_OBJECT
@@ -168,6 +164,7 @@ class CHexViewWidget : public QFrame
     inline uint offset( void );
     inline uint bookmarkCount( void );
     inline bool modified( void );
+    inline void setModified( bool modified );
     inline const QDateTime &diskModifyTime( void );
     inline bool losslessEncoding( CConversion::EMode mode );
     inline const SEncodeState &encoding( void );
@@ -266,7 +263,7 @@ class CHexViewWidget : public QFrame
 
     int  bookmarkMenu( const QString &title );
 
-    inline bool shiftButtonState( void );
+    static inline bool shiftButtonState( void );
 
     inline void setupCursorTimer( void );
     inline int  startX( void );
@@ -312,14 +309,8 @@ class CHexViewWidget : public QFrame
 
 inline bool CHexViewWidget::shiftButtonState( void )
 {
-  Window root = RootWindow( x11Display(), x11Screen() );
-  uint mask;
-  Window w;
-  int i;
-  
-  XQueryPointer( x11Display(), root, &w, &w, &i, &i, &i, &i, &mask );
-  return( mask & ShiftMask ? true : false );
-} 
+  return kapp->keyboardModifiers() & KApplication::ShiftModifier;
+}
 
 
 
@@ -535,6 +526,12 @@ inline bool CHexViewWidget::modified( void )
   return( mHexBuffer->modified() );
 }
 
+inline void CHexViewWidget::setModified( bool modified )
+{
+  mHexBuffer->setModified( modified );
+  emit fileState( mHexBuffer->fileState() );
+}
+
 inline const QDateTime &CHexViewWidget::diskModifyTime( void )
 {
   return( mHexBuffer->diskModifyTime() );
