@@ -15,13 +15,14 @@
  ***************************************************************************/
 
 
-#ifndef KHEXEDIT_H
-#define KHEXEDIT_H
+#ifndef KHE_KHEXEDIT_H
+#define KHE_KHEXEDIT_H
 
 // qt specific
 #include <qclipboard.h>
 // lib specific
 // #include "khe.h"
+#include "khexedit_export.h"
 #include "kcolumnsview.h"
 
 class QTimer;
@@ -43,20 +44,42 @@ class KBufferCursor;
 class KBufferLayout;
 class KBufferRanges;
 
+class KController;
+class KTabController;
+class KNavigator;
+class KValueEditor;
+class KCharEditor;
+
 class KBufferDrag;
 
 class KCursor;
+class KCharCodec;
 
 class KHexEditPrivate;
 
 
 /** the main widget
+  * 
+  * The functions split up in helper functions and those that are complete.
+  * 
+  * Complete functions can be called from the outside and leave the widget in 
+  * a consistent state. They care for exceptions so one can safely call them in all 
+  * situations (like empty buffer, cursor behind end etc.)
+  *
+  * Helper functions do only partial tasks and need to be completed. They often do not 
+  * check for exceptions so one has to care for this.
   *
   *@author Friedrich W. H. Kossebau
   */
 
-class KHexEdit : public KColumnsView
+class KHEXEDIT_EXPORT KHexEdit : public KColumnsView
 {
+  friend class KTabController;
+  friend class KNavigator;
+  friend class KEditor;
+  friend class KValueEditor;
+  friend class KCharEditor;
+
   Q_OBJECT
   Q_ENUMS( KResizeStyle KCoding )
   Q_PROPERTY( bool OverwriteMode READ isOverwriteMode WRITE setOverwriteMode )
@@ -85,14 +108,12 @@ class KHexEdit : public KColumnsView
   Q_PROPERTY( QChar SubstituteChar READ substituteChar WRITE setSubstituteChar )
 
   public:
-    enum KMoveAction { MoveBackward, MoveWordBackward, MoveForward, MoveWordForward,
-                       MoveUp, MovePgUp, MoveDown, MovePgDown,
-                       MoveLineStart, MoveHome, MoveLineEnd, MoveEnd };
-    enum KKeyboardAction { ActionDelete, ActionWordDelete, ActionBackspace, ActionWordBackspace };
-
     enum KResizeStyle { NoResize=0, LockGrouping=1, FullSizeUsage=2, MaxResizeStyleId=0xFF };
     enum KCoding { HexadecimalCoding=0, DecimalCoding=1, OctalCoding=2, BinaryCoding=3, MaxCodingId=0xFFFF };
-    enum KEncoding { LocalEncoding=0, ISO8859_1Encoding=1, MaxEncodingId=0xFFFF };
+    enum KEncoding { LocalEncoding=0, ISO8859_1Encoding=1, EBCDIC1047Encoding=2,
+                     StartOfOwnEncoding=0x8000, MaxEncodingId=0xFFFF };
+
+    enum KBufferColumnId { ValueColumnId=1, CharColumnId=2 };
 
 
   public:
@@ -115,6 +136,11 @@ class KHexEdit : public KColumnsView
   public: // value access
     /** returns true if there is a selected range in the array */
     bool hasSelectedData() const;
+    /** returns the index of the cursor position */
+    int cursorPosition() const;
+    /***/
+    bool isCursorBehind() const;
+    KBufferColumnId cursorColumn() const;
 
     bool isOverwriteMode() const;
     bool isOverwriteOnly() const;
@@ -127,53 +153,67 @@ class KHexEdit : public KColumnsView
     int noOfBytesPerLine() const;
     int startOffset() const;
     int firstLineOffset() const;
+
+    bool offsetColumnVisible() const;
+    int visibleBufferColumns() const;
+
   // value column
     KCoding coding() const;
     int/*KPixelX*/ byteSpacingWidth() const;
     int noOfGroupedBytes() const;
     int/*KPixelX*/ groupSpacingWidth() const;
     int/*KPixelX*/ binaryGapWidth() const;
+
   // char column
-    /** returns true if "unprintable" chars (>32) are displayed in the char column
-      * with their corresponding character, default is false
+    /** reports if "unprintable" chars (value<32) are displayed in the char column
+      * with their original character. Default is false
+      * @return @c true if original chars are displayed, otherwise @c false 
       */
     bool showUnprintable() const;
-    /** returns the actually used substitute character for "unprintable" chars, default is '.' */
+    /** gives the used substitute character for "unprintable" chars, default is '.'
+      * @return substitute character 
+      */
     QChar substituteChar() const;
-    /** */
+    /** returns the actually used undefined character for "undefined" chars, default is '?' */
+    QChar undefinedChar() const;
+    /**
+      * @return encoding used in the char column
+      */
     KEncoding encoding() const;
-
+    /**
+     * @return name of the encoding used in the char column
+     */
+    const QString &encodingName() const;
 
   public: // logic value service
-    /** returns the number of bytes per line that fit into a widget with the given size
+    /** calculates the number of bytes per line that fit into a widget with the given size
       * tests whether a vertical scroll bar is needed at all or not due to the given width
       * takes the frame width into account
-      *@param TestSize Size the widget might have
+      * @param TestSize Size the widget might have
+      * @return number of bytes per line that fit into a widget with the given size
       */
     int fittingBytesPerLine( const QSize &TestSize ) const;
-    /** returns the index of the byte that is displayed around the point (in viewport coordinate system)
+    /** detects the index of the byte at the given point
+      * @param Point in viewport coordinate system
+      * @return index of the byte that covers the point
       */
     int indexByPoint(const QPoint &Point ) const;
 
   public:
-    /** returns a deep copy of the selected data */
+    /** 
+      * @return deep copy of the selected data 
+      */
     QByteArray selectedData() const;
 
-  public:
-    const KOffsetColumn& offsetColumn() const;
-    const KValueColumn& valueColumn()    const;
-    const KCharColumn& charColumn()   const;
-    const KBufferColumn& activeColumn() const;
-    const KBufferColumn& inactiveColumn() const;
-
-
   public: // modification access
-    /** moves the cursor according to the action, handles all drawing */
-    void moveCursor( KMoveAction Action );
-    /** puts the cursor to the position of index, handles all drawing */
-    void setCursorPosition( int Index );
+    /** puts the cursor to the position of index, handles all drawing 
+      * @param Index 
+      */
+    void setCursorPosition( int Index, bool Behind=false );
     /** puts the cursor in the column at the pos of Point (in absolute coord), does not handle the drawing */
     void placeCursor( const QPoint &Point );
+    /***/
+    void setCursorColumn( KBufferColumnId );
 //    void repaintByte( int row, int column, bool Erase = true );
 //    void updateByte( int row, int column );
 //    void ensureByteVisible( int row, int column );
@@ -182,8 +222,10 @@ class KHexEdit : public KColumnsView
     /** */
     void setDataBuffer( KDataBuffer *B );
 
-//    /** switches the Offset column on/off */
-//    void toggleOffsetColumn( bool Visible );
+    /** switches the Offset column on/off */
+    void toggleOffsetColumn( bool Visible );
+    /** */
+    void showBufferColumns( int Columns );
     /** scrolls the view as much as needed to have the cursor fully visible */
     void ensureCursorVisible();
 
@@ -252,19 +294,24 @@ class KHexEdit : public KColumnsView
       * returns true if there was a change
       */
     void setSubstituteChar( QChar SC );
+    /** sets the undefined character for "undefined" chars
+     * returns true if there was a change
+     */
+    void setUndefinedChar( QChar UC );
     /** sets the encoding of the char column. Default is KHE::LocalEncoding.
       * If the encoding is not available the format will not be changed. */
     void setEncoding( KEncoding C );
+    /** sets the encoding of the char column. Default is KHE::LocalEncoding.
+      * If the encoding is not available the format will not be changed.
+      * @param Encoding name of the encoding
+      */
+    void setEncoding( const QString& Encoding );
 
   // interaction
     /** de-/selects all data */
     void selectAll( bool select );
     /** selects word at index, returns true if there is one */
     bool selectWord( /*unsigned*/ int Index /*, Chartype*/ );
-    /**  */
-    void moveCursor( KMoveAction Action, bool Select );
-    /** executes keyboard Action \a Action. This is normally called by a key event handler. */
-    void doKeyboardAction( KKeyboardAction Action );
     /** removes the selected data, takes care of the cursor */
     virtual void removeSelectedData();
     /** inserts */
@@ -293,17 +340,6 @@ class KHexEdit : public KColumnsView
     /** undoes pauseCursor */
     virtual void unpauseCursor();
 
-  // byte editing
-    /** steps inside editing the byte in the value column */
-    bool goInsideByte();
-    /** */
-    void goOutsideByte( bool MoveToNext = false );
-    /** increases the byte in the buffer */
-    bool incByte();
-    /** increases the byte in the buffer */
-    bool decByte();
-
-
 
   signals:
     /** Index of the byte that was clicked */
@@ -320,8 +356,6 @@ class KHexEdit : public KColumnsView
     void copyAvailable( bool Really );
     /** there has been a change to the buffer */
     void bufferChanged();
-    /** the input was not even partially inserted */
-    void inputFailed();
 
 
   protected: // QWidget API
@@ -344,14 +378,23 @@ class KHexEdit : public KColumnsView
   protected: // KColumnsView API
     virtual void setNoOfLines( int NewNoOfLines );
 
+
+  protected: // element accessor functions
+    KValueColumn& valueColumn();
+    KCharColumn& charColumn();
+    KBufferColumn& activeColumn();
+    KBufferColumn& inactiveColumn();
+    const KValueColumn& valueColumn()    const;
+    const KCharColumn& charColumn()   const;
+    const KBufferColumn& activeColumn() const;
+    const KBufferColumn& inactiveColumn() const;
+
   protected: // atomic ui operations
     /** handles screen update in case of a change to any of the width sizes
       */
     void updateViewByWidth();
     /** repaints all the parts that are signed as changed */
     void repaintChanged();
-    bool handleByteEditKey( QKeyEvent *KeyEvent );
-    bool handleLetter( QKeyEvent *KeyEvent );
 
   protected: // drawing related operations
     /** recreates the cursor pixmaps and paints active and inactive cursors if doable */
@@ -361,18 +404,11 @@ class KHexEdit : public KColumnsView
     /** draws the blinking cursor or removes it */
     void paintActiveCursor( bool CursorOn );
     void paintInactiveCursor( bool CursorOn );
-    void paintEditedByte( bool Edited );
     void paintLine( KBufferColumn *C, int Line, KSection Positions );
 
   protected: // partial operations
-    KOffsetColumn& offsetColumn();
-    KValueColumn& valueColumn();
-    KCharColumn& charColumn();
-    KBufferColumn& activeColumn();
-    KBufferColumn& inactiveColumn();
-
     void handleMouseMove( const QPoint& Point );
-    KBufferDrag *dragObject( bool F = false, QWidget *Parent = 0 ) const;
+    KBufferDrag *dragObject( QWidget *Parent = 0 ) const;
     void pasteFromSource( QMimeSource *Source );
     /** removes the section from the databuffer and updates all affected values */
     void removeData( KSection Indizes );
@@ -380,8 +416,6 @@ class KHexEdit : public KColumnsView
       * @return true if there was a change within the visible range
       */
     bool hasChanged( const KCoordRange &VisibleRange, KCoordRange *ChangedRange ) const;
-    /** copies the actual edit value to the databuffer and updates the coding string */
-    void syncEditedByte();
     void handleInternalDrag( QDropEvent *e );
 
   protected:
@@ -395,7 +429,7 @@ class KHexEdit : public KColumnsView
     void updateLength();
     /** calls updateContent for the Column */
     void updateColumn( KColumn &Column );
-
+    void emitSelectionSignals();
 
   protected slots:
     /** gets called by the cursor blink timer */
@@ -421,12 +455,12 @@ class KHexEdit : public KColumnsView
     KBufferCursor *BufferCursor;
     /** */
     KBufferRanges *BufferRanges;
-    // TODO: Timer for syncing hexediting with charColumn... no needed?
+
 
   protected:
     KOffsetColumn *OffsetColumn;
     KBorderColumn *FirstBorderColumn;
-    KValueColumn    *ValueColumn;
+    KValueColumn  *ValueColumn;
     KBorderColumn *SecondBorderColumn;
     KCharColumn   *CharColumn;
 
@@ -435,6 +469,17 @@ class KHexEdit : public KColumnsView
     /** points to the column without keyboard focus (if there is) */
     KBufferColumn *InactiveColumn;
 
+    /** the actual input controller */
+    KController *Controller;
+    /** */
+    KTabController *TabController;
+    /** */
+    KNavigator *Navigator;
+    /** */
+    KValueEditor *ValueEditor;
+    /** */
+    KCharEditor *CharEditor;
+
   protected:
     /** Timer that controls the blinking of the cursor */
     QTimer *CursorBlinkTimer;
@@ -448,33 +493,32 @@ class KHexEdit : public KColumnsView
 
     /** object to store the blinking cursor pixmaps */
     KCursor *CursorPixmaps;
-    /** buffer with the  */
-    char *ByteBuffer;
-    /** stores the number of actual digits */
-    int LengthOfByteBuffer;
     /** */
-    unsigned char EditValue;
-    /** stores the old byte value */
-    unsigned char OldValue;
+    KCharCodec *Codec;
 
   protected:
     /** point at which the current double click happended (used by TrippleClick) */
     QPoint DoubleClickPoint;
-    QPoint DragStartPoint;
+    /** line in which the current double click happended (used by TrippleClick) */
     int DoubleClickLine;
+    /** point at which the current dragging started */
+    QPoint DragStartPoint;
+    /** */
     QClipboard::Mode ClipboardMode;
+    /** font size as set by user (used for zooming) */
     int DefaultFontSize;
 
   protected: // parameters
     /** style of resizing */
     KResizeStyle ResizeStyle;
-    /** flag if tab key should be ignored */
-    bool TabChangesFocus:1;
+    /** */
+    KEncoding Encoding;
+
     /** flag whether the widget is set to readonly. Cannot override the databuffer's setting, of course. */
     bool ReadOnly:1;
-    /** */
+    /** flag if only overwrite is allowed */
     bool OverWriteOnly:1;
-    /** */
+    /** flag if overwrite mode is active */
     bool OverWrite:1;
     /** flag if a mouse button is pressed */
     bool MousePressed:1;
@@ -490,10 +534,6 @@ class KHexEdit : public KColumnsView
     bool BlinkCursorVisible:1;
     /** flag whether the font is changed due to a zooming */
     bool InZooming:1;
-    /** flag whether we are in byte digits editing mode */
-    bool InEditMode:1;
-    /** flag whether byte edit mode was reached by inserting */
-    bool EditModeByInsert:1;
 
   private:
     /** the binary compatibility saving helper */
@@ -505,13 +545,11 @@ class KHexEdit : public KColumnsView
 };
 
 
-inline const KOffsetColumn& KHexEdit::offsetColumn()   const { return *OffsetColumn; }
 inline const KValueColumn& KHexEdit::valueColumn()     const { return *ValueColumn; }
 inline const KCharColumn& KHexEdit::charColumn()       const { return *CharColumn; }
 inline const KBufferColumn& KHexEdit::activeColumn()   const { return *ActiveColumn; }
 inline const KBufferColumn& KHexEdit::inactiveColumn() const { return *InactiveColumn; }
 
-inline KOffsetColumn& KHexEdit::offsetColumn()   { return *OffsetColumn; }
 inline KValueColumn& KHexEdit::valueColumn()     { return *ValueColumn; }
 inline KCharColumn& KHexEdit::charColumn()       { return *CharColumn; }
 inline KBufferColumn& KHexEdit::activeColumn()   { return *ActiveColumn; }
