@@ -15,7 +15,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
 
@@ -87,20 +87,16 @@ void CStatusBarProgress::setBarPixmap( const QPixmap &pixmap )
   {
     return;
   }
-  if( mBarPixmap != 0 )
-  {
-    delete mBarPixmap; mBarPixmap = 0;
-  }
+
+  delete mBarPixmap;
   mBarPixmap = new QPixmap( pixmap );
 }
 
 void CStatusBarProgress::setBarColor( const QColor &color )
 {
   mBarColor = color;
-  if( mBarPixmap != 0 )
-  {
-    delete mBarPixmap; mBarPixmap = 0;
-  }
+  delete mBarPixmap;
+  mBarPixmap = 0;
 }
 
 void CStatusBarProgress::setBarStyle( BarStyle style )
