@@ -50,10 +50,6 @@
 
 #define KJOTSVERSION "0.6"
 
-//
-// KMyListView
-//
-
 extern KIconLoader* global_pix_loader;
 
 //----------------------------------------------------------------------
@@ -219,7 +215,7 @@ KJotsMain::KJotsMain(const char* name)
     connect(subjectList, SIGNAL(collapsed(QListViewItem*)),
             this, SLOT(jumpToEntry(QListViewItem*)));
     connect(subjectList, SIGNAL(contextMenu(KListView*,QListViewItem*,const QPoint&)),
-            this, SLOT(showListviewContextenu(KListView*,QListViewItem*,const QPoint&)));
+            this, SLOT(showListviewContextMenu(KListView*,QListViewItem*,const QPoint&)));
     connect(subjectList, SIGNAL(itemRenamed(QListViewItem*,const QString&,int)),
             this, SLOT(slotItemRenamed(QListViewItem*,const QString&,int)));
     connect(roTextView, SIGNAL(linkClicked(const QString&)),
@@ -240,7 +236,7 @@ void KJotsMain::loadBooks()
     QStringList files = dir.entryList(QDir::Files|QDir::Readable);
     QStringList openBooks = KJotsSettings::openBooks();
     QString currentBookName = KJotsSettings::currentBook();
-    int currentPageNo = KJotsSettings::currentSubject();
+    int currentPageNo = KJotsSettings::currentPage();
 
     for (QStringList::Iterator it = files.begin(); it != files.end(); it++)
     {
@@ -254,6 +250,7 @@ void KJotsMain::loadBooks()
         if (openBooks.find(decodedFilename) != openBooks.end())
         {
             book->openBook();
+            book->setOpen(true);
         }
 
         if (decodedFilename == currentBookName)
@@ -272,6 +269,8 @@ void KJotsMain::loadBooks()
             }
             else
             {
+                book->setOpen(true); //again, shouldn't be necessary but who knows?
+
                 QListViewItem* page = book->firstChild();
                 for (int i = 0; i < currentPageNo && page; ++i)
                 {
@@ -319,10 +318,11 @@ bool KJotsMain::createFolder()
 void KJotsMain::slotRenameEntry()
 {
     KJotsEntryBase* entry = dynamic_cast<KJotsEntryBase*>(subjectList->currentItem());
-    
+
     if (entry)
     {
         entry->rename();
+        jumpToEntry(entry, true); //reflect the changes on screen
     }
 }
 
@@ -367,14 +367,14 @@ void KJotsMain::newEntry()
 
     if (b)
     {
-        KJotsSubject* s = b->addSubject();
+        KJotsPage* s = b->addPage();
         subjectList->setSelected(s, true);
     }
 }
 
 void KJotsMain::deleteEntry()
 {
-    KJotsSubject* cur = currentSubject();
+    KJotsPage* cur = currentPage();
 
     if (!cur ||
         KMessageBox::warningContinueCancel(topLevelWidget(),
@@ -386,19 +386,19 @@ void KJotsMain::deleteEntry()
     }
 
     KJotsBook* bk = dynamic_cast<KJotsBook*>(cur->KListViewItem::parent());
-    KJotsSubject* nxt = dynamic_cast<KJotsSubject*>(cur->nextSibling());
+    KJotsPage* nxt = dynamic_cast<KJotsPage*>(cur->nextSibling());
 
+    me_text->setEntry(0);
     delete cur;
     currentEntry = 0;
 
     if (!nxt)
-        nxt = dynamic_cast<KJotsSubject*>(bk->firstChild());
+        nxt = dynamic_cast<KJotsPage*>(bk->firstChild());
 
     if (nxt)
         subjectList->setSelected(nxt, true);
     else
     {
-        me_text->clear();
         setCaption(kapp->makeStdCaption(QString::null));
     }
     updateMenu();
@@ -446,21 +446,21 @@ void KJotsMain::updateConfiguration()
         m_autosaveTimer->stop();
 }
 
-void KJotsMain::autoSave(void)
+// the "isDirty()" check only works for edits. Use "force" for things like renames
+// and reorders, or any other time that you want to be really, really sure.
+void KJotsMain::autoSave(bool force)
 {
-    KJotsSubject* cur = currentSubject();
-
-    if (cur)
-        syncEntryWithText(cur);
-
     QListViewItem* b = subjectList->firstChild();
     while (b)
     {
         KJotsBook *book = dynamic_cast<KJotsBook*>(b);
 
-        if (book && book->isDirty())
+        if (book)
         {
-            book->closeBook(true);
+            if ( book->isDirty() || force )
+            {
+                book->closeBook(true);
+            }
         }
 
         b = b->nextSibling();
@@ -520,7 +520,7 @@ void KJotsMain::writePageToHTML()
 
 void KJotsMain::savePageToFile(bool plainText)
 {
-    KJotsSubject* e = currentSubject();
+    KJotsPage* e = currentPage();
 
     if (!e)
         return;
@@ -552,7 +552,7 @@ void KJotsMain::savePageToFile(bool plainText)
 void KJotsMain::copySelection()
 {
     //TODO: Strip HTML tags
-    KJotsSubject* cur = currentSubject();
+    KJotsPage* cur = currentPage();
 
     if (cur && me_text->hasSelectedText())
         cur->setSubject(me_text->selectedText());
@@ -579,33 +579,6 @@ void KJotsMain::insertDate()
   me_text->insert(KGlobal::locale()->formatDateTime(QDateTime::currentDateTime(), true) + " ");
 }
 
-void KJotsMain::syncTextWithEntry(KJotsSubject* entry)
-{
-    if (!entry)
-        return;
-
-    me_text->setText(entry->body());
-    me_text->removeSelection();
-    me_text->repaint();
-    me_text->setEnabled(true);
-    me_text->setFocus();
-}
-
-void KJotsMain::syncEntryWithText(KJotsSubject* entry)
-{
-    if (!entry || !me_text->edited())
-        return;
-
-    KJotsBook* b = dynamic_cast<KJotsBook*>(entry->KListViewItem::parent());
-
-    if (b)
-    {
-        b->setDirty(true);
-    }
-
-    entry->setBody(me_text->text());
-}
-
 void KJotsMain::updateMenu()
 {
     KJotsEntryBase* cur = dynamic_cast<KJotsEntryBase*>(subjectList->currentItem());
@@ -659,7 +632,7 @@ void KJotsMain::slotFindSuccessful()
     actionCollection()->action(KStdAction::stdName(KStdAction::FindNext))->setEnabled(true);
 }
 
-void KJotsMain::showListviewContextenu(KListView*, QListViewItem* i, const QPoint& p)
+void KJotsMain::showListviewContextMenu(KListView*, QListViewItem* i, const QPoint& p)
 {
     KActionMenu* am = new KActionMenu(this);
 
@@ -679,7 +652,7 @@ void KJotsMain::showListviewContextenu(KListView*, QListViewItem* i, const QPoin
     }
     else
     {
-        //clicked on subject
+        //clicked on page
         am->insert(actionCollection()->action(KStdAction::stdName(KStdAction::New)));
         am->insert(actionCollection()->action("rename_entry"));
         am->insert(actionCollection()->action("save_page_to_ascii"));
@@ -729,25 +702,8 @@ void KJotsMain::bookLinkClicked(const QString& link)
 
 bool KJotsMain::queryClose()
 {
-    KJotsSubject* cur = currentSubject();
-    if (cur)
-        syncEntryWithText(cur);
-
+    autoSave(true);
     saveProperties();
-
-    QListViewItem* b = subjectList->firstChild();
-
-    while (b)
-    {
-        KJotsBook *book = dynamic_cast<KJotsBook*>(b);
-        if (book)
-        {
-            book->closeBook();
-        }
-
-        b = b->nextSibling();
-    }
-
     return true;
 }
 
@@ -756,12 +712,12 @@ void KJotsMain::saveProperties()
     KJotsSettings::setSplitterSizes(splitter->sizes());
 
     KJotsBook* selBook = currentBook();
-    KJotsSubject* selSubj = currentSubject();
+    KJotsPage* selSubj = currentPage();
     int pageNo = -1;
 
     if (selBook && (!selSubj || static_cast<KJotsEntryBase*>(selBook) == selSubj))
     {
-        selSubj = dynamic_cast<KJotsSubject*>(selBook->firstChild());
+        selSubj = dynamic_cast<KJotsPage*>(selBook->firstChild());
     }
     else if (selSubj)
     {
@@ -780,7 +736,7 @@ void KJotsMain::saveProperties()
     }
 
     KJotsSettings::setCurrentBook( selBook ? selBook->subject() : QString::null);
-    KJotsSettings::setCurrentSubject( pageNo );
+    KJotsSettings::setCurrentPage( pageNo );
 
     QStringList list;
 
@@ -809,17 +765,6 @@ void KJotsMain::slotExpandBook(QListViewItem* item)
     void(dynamic_cast<KJotsBook*>(item)->openBook());
 }
 
-void KJotsMain::slotCollapseBook(QListViewItem* item)
-{
-    if (currentEntry)
-        syncEntryWithText(dynamic_cast<KJotsSubject*>(currentEntry));
-
-    static_cast<KJotsBook*>(item)->closeBook();
-    me_text->clear();
-    setCaption(kapp->makeStdCaption(QString::null));
-    currentEntry = 0;
-}
-
 QString KJotsMain::currentTitle()
 {
     QListViewItem* entry = subjectList->currentItem();
@@ -835,10 +780,10 @@ QString KJotsMain::currentTitle()
     }
     else
     {
-        KJotsSubject* subject = static_cast<KJotsSubject*>(entry);
+        KJotsPage* page = static_cast<KJotsPage*>(entry);
         // TODO: this will have to be fixed if/when we allow arbitrary depth pages
-        return static_cast<KJotsEntryBase*>(subject->KListViewItem::parent())->subject() +
-               ": " + subject->subject();
+        return static_cast<KJotsEntryBase*>(page->KListViewItem::parent())->subject() +
+               ": " + page->subject();
     }
 }
 
@@ -857,10 +802,10 @@ QString KJotsMain::currentBookmarkURL()
     }
     else
     {
-        KJotsSubject* subject = static_cast<KJotsSubject*>(entry);
+        KJotsPage* page = static_cast<KJotsPage*>(entry);
         // TODO: this will have to be fixed if/when we allow arbitrary depth pages
-        return dynamic_cast<KJotsEntryBase*>(subject->KListViewItem::parent())->subject() +
-               "/" + QString::number(subject->id());
+        return dynamic_cast<KJotsEntryBase*>(page->KListViewItem::parent())->subject() +
+               "/" + QString::number(page->id());
     }
 }
 
@@ -910,9 +855,9 @@ void KJotsMain::jumpToBookmark(const QString& page)
 
                 while (item)
                 {
-                    KJotsSubject* subject = dynamic_cast<KJotsSubject*>(item);
+                    KJotsPage* page = dynamic_cast<KJotsPage*>(item);
 
-                    if (subject && subject->id() == pageID)
+                    if (page && page->id() == pageID)
                     {
                         book->setOpen(true);
                         subjectList->ensureItemVisible(item);
@@ -989,7 +934,7 @@ void KJotsMain::prevBook()
 
 void KJotsMain::nextPage()
 {
-    QListViewItem* page = currentSubject();
+    QListViewItem* page = currentPage();
 
     if (!page)
     {
@@ -1035,7 +980,7 @@ void KJotsMain::nextPage()
 
 void KJotsMain::prevPage()
 {
-    QListViewItem* page = currentSubject();
+    QListViewItem* page = currentPage();
 
     if (!page)
     {
@@ -1108,38 +1053,39 @@ void KJotsMain::prevPage()
     jumpToEntry(item);
 }
 
-void KJotsMain::jumpToEntry(QListViewItem* entry)
+void KJotsMain::jumpToEntry(QListViewItem* entry, bool force)
 {
-    if (currentEntry == entry)
+    //This won't lose data or anything; but it does reset the cursor postion and waste cycles.
+    if (currentEntry == entry && !force)
         return;
 
-    if (currentEntry)
-        syncEntryWithText(dynamic_cast<KJotsSubject*>(currentEntry));
-
     if (entry == 0)
     {
-        me_text->clear();
+        me_text->setEntry(0);
         currentEntry = 0;
     }
     else if (dynamic_cast<KJotsBook*>(entry))
     {
+        me_text->setEntry(0);
         KJotsBook* book = static_cast<KJotsBook*>(entry);
 
+        book->openBook(); //making sure. doesn't hurt if book is already open
+
         QString TOC;
         QString pageText;
         QListViewItem* child = entry->firstChild();
         int i = 1;
         while (child)
         {
-            KJotsSubject* subject = dynamic_cast<KJotsSubject*>(child);
-            if (subject)
+            KJotsPage* page = dynamic_cast<KJotsPage*>(child);
+            if (page)
             {
-                TOC += QString("<li><a href=\"p%1\">").arg(i) + subject->subject() + "</a></li>";
-                QString text = subject->subject();
+                TOC += QString("<li><a href=\"p%1\">").arg(i) + page->subject() + "</a></li>";
+                QString text = page->subject();
                 text.replace("<", "&lt;");
                 text.replace(">", "&gt;");
                 pageText += QString("<h3><a name=\"p%1\" href=\"%2\">%3</a></h3>").arg(i).arg(i).arg(text);
-                text = subject->body();
+                text = page->body();
                 text.replace("<", "&lt;");
                 text.replace(">", "&gt;");
                 text.replace("\n", "<br>");
@@ -1162,8 +1108,7 @@ void KJotsMain::jumpToEntry(QListViewItem* entry)
     else
     {
         textStack->raiseWidget(me_text);
-        syncTextWithEntry(dynamic_cast<KJotsSubject*>(entry));
-
+        me_text->setEntry(dynamic_cast<KJotsPage*>(entry));
         currentEntry = static_cast<KJotsEntryBase*>(entry);
     }
 
@@ -1188,7 +1133,7 @@ void KJotsMain::updateCaption()
     {
         setCaption(kapp->makeStdCaption(static_cast<KJotsBook*>(e)->subject()));
     }
-    else if (dynamic_cast<KJotsSubject*>(e))
+    else if (dynamic_cast<KJotsPage*>(e))
     {
         QString caption = static_cast<KJotsEntryBase*>(e->parent())->subject() +
                           " / " +
@@ -1206,6 +1151,7 @@ void KJotsMain::slotItemRenamed(QListViewItem* item, const QString& str, int  /*
     {
         entry->setSubject(str);
         updateCaption();
+        jumpToEntry(entry, true); //reflect the changes on screen
     }
 }
 
@@ -1213,6 +1159,7 @@ void KJotsMain::slotItemMoved(QListViewItem *item, QListViewItem * afterFirst, Q
 {
     KJotsEntryBase *p_item = dynamic_cast<KJotsEntryBase*>(item);
     KJotsEntryBase *p_item_parent = dynamic_cast<KJotsEntryBase*>(item->parent());
+
     if (p_item_parent)
     {
         if (dynamic_cast<KJotsBook*>(p_item) && dynamic_cast<KJotsBook*>(p_item_parent))
@@ -1234,14 +1181,14 @@ void KJotsMain::slotItemMoved(QListViewItem *item, QListViewItem * afterFirst, Q
     }
     else if (!dynamic_cast<KJotsBook*>(p_item))
     {
-        KJotsSubject *p_aux = dynamic_cast<KJotsSubject*>(item);
+        KJotsPage *p_aux = dynamic_cast<KJotsPage*>(item);
 
         if (!p_aux)
         {
             return;
         }
 
-        // we don't accept subjects in the root
+        // we don't accept pages in the root
         // create a new book
         if (KMessageBox::questionYesNo(this,
                                        i18n("All pages must be inside a book. "
@@ -1252,15 +1199,21 @@ void KJotsMain::slotItemMoved(QListViewItem *item, QListViewItem * afterFirst, Q
             KMessageBox::No ||
             !createFolder())
         {
-            subjectList->moveItem(p_aux, currentBook(), afterFirst);
+            //Careful! afterFirst only works here if this page was after another page.
+            if ( dynamic_cast<KJotsPage*>(afterFirst) )
+                subjectList->moveItem(p_aux, currentBook(), afterFirst);
+            else
+                subjectList->moveItem(p_aux, currentBook(), 0);
             return;
         }
 
         delete currentBook()->firstChild();
         currentBook()->insertItem(p_aux);
-        me_text->setText(p_aux->body());
+        me_text->setEntry(p_aux);
         currentEntry = p_item;
     }
+
+    autoSave(true); //flush changes to disk
 }
 
 KJotsBook* KJotsMain::currentBook()
@@ -1279,9 +1232,9 @@ KJotsBook* KJotsMain::currentBook()
     return 0;
 }
 
-KJotsSubject* KJotsMain::currentSubject()
+KJotsPage* KJotsMain::currentPage()
 {
-    return dynamic_cast<KJotsSubject*>(subjectList->currentItem());
+    return dynamic_cast<KJotsPage*>(subjectList->currentItem());
 }
 
 void addBookmark()
