@@ -43,7 +43,7 @@ class KEdFind;
 class KEdReplace;
 class QTimer;
 
-class KJotsSubject;
+class KJotsPage;
 class KJotsBook;
 class KJotsEntryBase;
 class KJotsEdit;
@@ -85,8 +85,7 @@ class KJotsMain : public KMainWindow
         void slotFindSuccessful();
 
         void slotExpandBook(QListViewItem* item);
-        void slotCollapseBook(QListViewItem* item);
-        void jumpToEntry(QListViewItem* entry);
+        void jumpToEntry(QListViewItem* entry, bool=false);
         void slotItemRenamed(QListViewItem*,const QString&,int);
         void slotItemMoved(QListViewItem*,QListViewItem*,QListViewItem*);
         void writeBook();
@@ -104,9 +103,9 @@ class KJotsMain : public KMainWindow
         QListViewItem* findPrevBookItem();
 
         // handling page changes in the listview
-        void showListviewContextenu(KListView* l, QListViewItem* i, const QPoint& p);
+        void showListviewContextMenu(KListView* l, QListViewItem* i, const QPoint& p);
         void bookLinkClicked(const QString&);
-        void autoSave();
+        void autoSave(bool=false);
 
         // bookmarks
         void jumpToBookmark(const QString& page);
@@ -114,12 +113,10 @@ class KJotsMain : public KMainWindow
     protected:
         void saveProperties();
         bool queryClose();
-        void syncTextWithEntry(KJotsSubject* entry);
-        void syncEntryWithText(KJotsSubject* entry);
         void updateMenu();
         void loadBooks();
         KJotsBook* currentBook();
-        KJotsSubject* currentSubject();
+        KJotsPage* currentPage();
 
         QHBoxLayout   *bg_top_layout;
         QButtonGroup  *bg_top;
@@ -130,8 +127,6 @@ class KJotsMain : public KMainWindow
         QSplitter *splitter;
         QWidgetStack *textStack;
         QFont m_font;
-        bool    wantAutoSave;
-        int     autoSaveInterval;
         QTimer*  m_autosaveTimer;
 };
 
