@@ -33,7 +33,9 @@
 #include <kstandarddirs.h>
 
 #include <kio/job.h>
+#include <assert.h>
 
+#include "kjotsedit.h"
 #include "KJotsMain.h"
 #include "kjotsentry.h"
 
@@ -109,8 +111,6 @@ KJotsBook::~KJotsBook()
 {
     if (m_deleteFlag)
         annihilateBook();
-    else
-        closeBook();
 }
 
 bool KJotsBook::isBookFile(const QString& filename)
@@ -147,11 +147,6 @@ bool KJotsBook::openBook()
 
     listView()->setUpdatesEnabled(false);
 
-    if (!isOpen())
-    {
-        setOpen(true);
-    }
-
     QDir dir = QDir(locateLocal("appdata",""));
     QString file_name = dir.absPath();
     file_name += '/';
@@ -161,7 +156,7 @@ bool KJotsBook::openBook()
 
     if ( !folder.exists() )
     {
-        addSubject();
+        addPage();
         listView()->setUpdatesEnabled(true);
         m_open = true;
         return true;
@@ -169,7 +164,7 @@ bool KJotsBook::openBook()
     else if ( !folder.open(IO_ReadWrite) )
     {
         // TODO: should check for IO_READ access and open read only if so
-        addSubject();
+        addPage();
         listView()->setUpdatesEnabled(true);
         m_open = true;
         return false;
@@ -181,13 +176,13 @@ bool KJotsBook::openBook()
 
     if (buf.left(9) != "\\NewEntry")
     {
-        addSubject();
+        addPage();
         listView()->setUpdatesEnabled(true);
         m_open = true;
         return false;
     }
 
-    KJotsSubject *entry = 0;
+    KJotsPage *entry = 0;
     QString body;
 
     bool quit=false;
@@ -221,7 +216,7 @@ bool KJotsBook::openBook()
             {
                 pageID = nextID();
             }
-            entry = addSubject(title, entry, pageID);
+            entry = addPage(title, entry, pageID);
         }
 
         int pos = 0;
@@ -276,7 +271,7 @@ void KJotsBook::closeBook(bool saveOnly)
         return;
     }
 
-    KJotsSubject* entry = dynamic_cast<KJotsSubject*>(firstChild());
+    KJotsPage* entry = dynamic_cast<KJotsPage*>(firstChild());
     QTextStream st((QIODevice *) &folder);
     st.setEncoding( QTextStream::Locale );
 
@@ -293,12 +288,12 @@ void KJotsBook::closeBook(bool saveOnly)
 
         if (!saveOnly)
         {
-            KJotsSubject* newEntry = dynamic_cast<KJotsSubject*>(entry->nextSibling());
+            KJotsPage* newEntry = dynamic_cast<KJotsPage*>(entry->nextSibling());
             delete entry;
             entry = newEntry;
         }
         else
-            entry = dynamic_cast<KJotsSubject*>(entry->nextSibling());
+            entry = dynamic_cast<KJotsPage*>(entry->nextSibling());
     }
 
     folder.close();
@@ -307,6 +302,8 @@ void KJotsBook::closeBook(bool saveOnly)
         listView()->setUpdatesEnabled(true);
         m_open = false;
     }
+
+    if ( m_dirty ) m_dirty = false;
 }
 
 void KJotsBook::annihilateBook()
@@ -334,6 +331,9 @@ void KJotsBook::rename()
 
 void KJotsBook::setSubject(const QString& newSubject)
 {
+    //Sanity check. Did they just press enter?
+    if ( newSubject == m_beforeRename ) return;
+
     QDir dir = QDir(locateLocal("appdata",""));
     QString fileName = dir.absPath();
     fileName += '/' + QFile::encodeName(newSubject);
@@ -416,10 +416,10 @@ void KJotsBook::saveDataReq(KIO::Job* /* job */, QByteArray& data)
         int i = 1;
         while (child)
         {
-            KJotsSubject* subject = dynamic_cast<KJotsSubject*>(child);
-            if (subject)
+            KJotsPage* page = dynamic_cast<KJotsPage*>(child);
+            if (page)
             {
-                QString text = prepForHTML(subject->subject());
+                QString text = prepForHTML(page->subject());
                 TOC += "<li><a href=\"#p" + QString::number(i) + "\">" + text + "</a></li>";
                 ++i;
             }
@@ -430,10 +430,10 @@ void KJotsBook::saveDataReq(KIO::Job* /* job */, QByteArray& data)
         stream << "<h3>" + i18n("Table of Contents") + "</h3><ul>" + TOC + "</ul><hr>";
     }
 
-    KJotsSubject* entry = 0;
+    KJotsPage* entry = 0;
     while (m_saveInProgress)
     {
-        entry = dynamic_cast<KJotsSubject*>(m_saveInProgress);
+        entry = dynamic_cast<KJotsPage*>(m_saveInProgress);
 
         if (entry)
         {
@@ -452,7 +452,8 @@ void KJotsBook::saveDataReq(KIO::Job* /* job */, QByteArray& data)
         m_saveInProgress = m_saveInProgress->nextSibling();
         ++pageNo;
     }
-    else // if (!m_saveInProgress) // we are truly finished
+
+    if (!m_saveInProgress) // we are truly finished
     {
         stream << htmlFooter();
         pageNo = 1;
@@ -467,7 +468,7 @@ void KJotsBook::slotSaveResult(KIO::Job *)
     /* if (job->error() != 0) {} */
 }
 
-KJotsSubject* KJotsBook::addSubject(QString subject, QListViewItem* after, int id)
+KJotsPage* KJotsBook::addPage(QString subject, QListViewItem* after, int id)
 {
     if (id < 0)
     {
@@ -485,7 +486,7 @@ KJotsSubject* KJotsBook::addSubject(QString subject, QListViewItem* after, int i
         }
     }
 
-    return new KJotsSubject(this, subject, id, after);
+    return new KJotsPage(this, subject, id, after);
 }
 
 void KJotsBook::print(QFont& defaultFont)
@@ -510,7 +511,7 @@ void KJotsBook::print(QFont& defaultFont)
 
     for (QListViewItem* page = firstChild(); page; page = page->nextSibling())
     {
-        KJotsSubject* subject = dynamic_cast<KJotsSubject*>(page);
+        KJotsPage* subject = dynamic_cast<KJotsPage*>(page);
 
         if (!subject)
         {
@@ -555,30 +556,64 @@ QString KJotsBook::defaultSubject()
     return i18n("Untitled Book");
 }
 
+bool KJotsBook::isDirty()
+{
+    //has an edit already happened?
+    if ( m_dirty ) return true;
+
+    //is an edit currently happening?
+    if ( m_active )
+    {
+        KJotsPage* page = dynamic_cast<KJotsPage*>(firstChild());
+        while (page)
+        {
+            if ( page->isDirty() )
+            {
+                return true;
+            } else {
+                page = dynamic_cast<KJotsPage*>(page->nextSibling());
+            }
+        }
+    }
+
+    return false;
+}
+
 //
-// KJotsSubject
+// KJotsPage
 //
 
-KJotsSubject::KJotsSubject(KJotsBook* parent, QString subj, int id, QListViewItem* after)
+KJotsPage::KJotsPage(KJotsBook* parent, QString subj, int id, QListViewItem* after)
     : KJotsEntryBase(parent,after),
       m_id(id),
-      m_saveInProgress(false)
+      m_saveInProgress(false),
+      m_editor(0)
 {
     setSubject(subj);
     setPixmap(0, kapp->iconLoader()->loadIcon(QString("edit"), KIcon::Small));
 }
 
-QString KJotsSubject::body()
+QString KJotsPage::body()
 {
+    //if we're being edited we want the current text, not whatever we saved before.
+    if ( m_editor && m_editor->edited() )
+    {
+        m_text = m_editor->text();
+        m_editor->setEdited(false);
+        KJotsBook* book = dynamic_cast<KJotsBook*>(KListViewItem::parent());
+        if ( book ) book->setDirty();
+    }
+
     return m_text;
 }
 
-void KJotsSubject::setBody(const QString& text)
+void KJotsPage::setBody(const QString& text)
 {
+    assert ( !m_editor ); //m_editor should *never* be set.
     m_text = text;
 }
 
-void KJotsSubject::rename()
+void KJotsPage::rename()
 {
     bool ok;
 
@@ -597,7 +632,7 @@ void KJotsSubject::rename()
     }
 }
 
-void KJotsSubject::write(QTextStream &stream, bool plainText)
+void KJotsPage::write(QTextStream &stream, bool plainText)
 {
     if (plainText)
     {
@@ -637,7 +672,7 @@ void KJotsSubject::write(QTextStream &stream, bool plainText)
 }
 
 // FIXME: break up into chunks in case of REAAAAALLY long pages?
-void KJotsSubject::saveToFile(KURL url, bool plainText)
+void KJotsPage::saveToFile(KURL url, bool plainText)
 {
     if (url.isEmpty() || m_saveInProgress)
         return;
@@ -654,7 +689,7 @@ void KJotsSubject::saveToFile(KURL url, bool plainText)
     m_saveInProgress = true;
 }
 
-void KJotsSubject::saveDataReq(KIO::Job* /* job */, QByteArray& data)
+void KJotsPage::saveDataReq(KIO::Job* /* job */, QByteArray& data)
 {
     if (!m_saveInProgress)
     {
@@ -667,13 +702,13 @@ void KJotsSubject::saveDataReq(KIO::Job* /* job */, QByteArray& data)
     m_saveInProgress = false;
 }
 
-void KJotsSubject::slotSaveResult(KIO::Job *)
+void KJotsPage::slotSaveResult(KIO::Job *)
 {
     m_saveInProgress = false;
     /* if (job->error() != 0) {} */
 }
 
-void KJotsSubject::print(QFont& defaultFont)
+void KJotsPage::print(QFont& defaultFont)
 {
     KJotsEntryBase* book = dynamic_cast<KJotsEntryBase*>(KListViewItem::parent());
 
@@ -698,17 +733,20 @@ void KJotsSubject::print(QFont& defaultFont)
     }
 }
 
-int KJotsSubject::print(KPrinter& printer, QPainter& painter, int y)
+int KJotsPage::print(KPrinter& printer, QPainter& painter, int y)
 {
     QPaintDeviceMetrics metrics( &printer );
     int maxWidth = metrics.width();
     int maxHeight = metrics.height();
-    QStringList paragraphs = QStringList::split("\n", body());
+    QStringList paragraphs = QStringList::split(QChar('\n'), body(), true);
 
     for (QStringList::iterator para = paragraphs.begin();
          para != paragraphs.end();
          ++para)
     {
+        //Watch for blank lines inserted as spacers.
+        if ( (*para).isNull() ) *para = " ";
+
         QRect r = painter.boundingRect(0, y,
                                        maxWidth, maxHeight,
                                        QPainter::ExpandTabs | QPainter::WordBreak,
@@ -729,11 +767,51 @@ int KJotsSubject::print(KPrinter& printer, QPainter& painter, int y)
     return y;
 }
 
-QString KJotsSubject::defaultSubject()
+QString KJotsPage::defaultSubject()
 {
     return i18n("Page %1").arg(m_id);
 }
 
+void KJotsPage::setEditor( KJotsEdit *editor )
+{
+    KJotsBook* book = dynamic_cast<KJotsBook*>(KListViewItem::parent());
+
+    //out with the old...
+    if ( m_editor )
+    {
+        if ( m_editor->edited() )
+        {
+            m_text = m_editor->text();
+            if (book) book->setDirty();
+        }
+    }
+
+    if (book) book->setActive(false);
+    m_editor = editor;
+
+    //and in with the new
+    if ( m_editor )
+    {
+        if ( book ) book->setActive(true);
+        m_editor->setEdited(false);
+    }
+
+    return;
+}
+
+bool KJotsPage::isDirty()
+{
+    if ( m_editor )
+    {
+        if ( m_editor->edited() )
+        {
+            return true;
+        }
+    }
+
+    return false;
+}
+
 /* ex: set tabstop=4 softtabstop=4 shiftwidth=4 expandtab: */
 
 #include "kjotsentry.moc"
