@@ -31,8 +31,9 @@
 //
 
 class KURL;
-class KJotsSubject;
+class KJotsPage;
 class KProgressDialog;
+class KJotsEdit;
 
 namespace KIO
 {
@@ -52,7 +53,7 @@ class KJotsEntryBase : public QObject, public KListViewItem
         void setText(int,const QString&);
         virtual void saveToFile(KURL, bool plainText) = 0;
         virtual void print(QFont& defaultFont) = 0;
-        virtual QString defaultSubject() = 0;
+        virtual QString defaultSubject() = 0; //!< "subject" is the caption name
         virtual void rename() = 0;
 };
 
@@ -75,10 +76,12 @@ class KJotsBook : public KJotsEntryBase
         void rename();
         void setDeleteFlag() { m_deleteFlag = true; }
         void saveToFile(KURL, bool plainText);
-        KJotsSubject* addSubject(QString subject = QString::null, QListViewItem* after = 0, int id = -1);
+        KJotsPage* addPage(QString subject = QString::null, QListViewItem* after = 0, int id = -1);
         void print(QFont& defaultFont);
-        bool isDirty() { return m_dirty; }
-        void setDirty(bool d) { m_dirty = d; }
+        bool isDirty();
+        void setDirty() { m_dirty = true; } //!< Noone outside the class can turn dirty off.
+        bool isActive();
+        void setActive(bool active) { m_active = active; }
         int nextID() { return ++m_pageID; }
         QString defaultSubject();
 
@@ -87,7 +90,8 @@ class KJotsBook : public KJotsEntryBase
         void slotSaveResult(KIO::Job*);
 
     private:
-        bool m_dirty;
+        bool m_dirty; //!< Set when a child page has been changed.
+        bool m_active; //!< Set when a child page is being edited.
         bool m_open;
         bool m_deleteFlag;
         QString m_beforeRename;
@@ -98,13 +102,13 @@ class KJotsBook : public KJotsEntryBase
 };
 
 //
-// class KJotsSubject
+// class KJotsPage
 //
-class KJotsSubject : public KJotsEntryBase
+class KJotsPage : public KJotsEntryBase
 {
     Q_OBJECT
     public:
-        KJotsSubject(KJotsBook* parent, QString subj, int id, QListViewItem* after = 0);
+        KJotsPage(KJotsBook* parent, QString subj, int id, QListViewItem* after = 0);
 
     public:
         QString body();
@@ -117,6 +121,9 @@ class KJotsSubject : public KJotsEntryBase
         int id() { return m_id; }
         void rename();
 
+        void setEditor(KJotsEdit*);
+        bool isDirty();
+
     protected slots:
         void saveDataReq(KIO::Job* job, QByteArray& data);
         void slotSaveResult(KIO::Job*);
@@ -126,6 +133,7 @@ class KJotsSubject : public KJotsEntryBase
         int     m_id;
         bool    m_saveInProgress;
         bool    m_saveToPlainText;
+        KJotsEdit *m_editor; //!< ptr to editor if this is the active subject
 };
 
 #endif // __KJOTSENTRY_H
