@@ -269,11 +269,12 @@ ButtonsConfig::ButtonsConfig (QWidget * parent, const char *name)
 
       hlay->addStretch(1);
 
-      QLabel* explain = new QLabel(i18n("This panel enables actions that are triggered when the lid closure switch\n"
-			    	        "or power switch on your laptop is pressed. Some laptops may already\n"
-					"automatically do things like this, if you can't disable them in your BIOS\n"
-					"you probably shouldn't enable anything in this panel"), this);
-      top_layout->addWidget(explain, 0, Qt::AlignLeft);
+      QLabel* explain = new QLabel(i18n("This panel enables actions that are triggered when the lid closure switch "
+			    	        "or power switch on your laptop is pressed. Some laptops may already "
+					"automatically do things like this, if you cannot disable them in your BIOS "
+					"you probably should not enable anything in this panel."), this);
+      explain->setAlignment( Qt::WordBreak );
+      top_layout->addWidget(explain);
 
       top_layout->addStretch(1);
 
