@@ -29,6 +29,8 @@
 #include <kpushbutton.h>
 #include <kstdguiitem.h>
 
+#include <kpushbutton.h>
+#include <kstdguiitem.h>
 #include "kpcmcia.h"
 
 #include "kpcmciainfo.h"
@@ -74,7 +76,7 @@ KPCMCIAInfo::KPCMCIAInfo(KPCMCIA *pcmcia, QWidget *parent, const char *name)
   connect(_closeButton, SIGNAL(pressed()), this, SLOT(slotClose()));
   _mainGrid->setRowStretch(7, 0);
 
-  this->show();
+  show();
 }
 
 
