@@ -31,6 +31,7 @@
 #include <fcntl.h>
 
 #include "main.h"
+#include "version.h"
 #include "warning.h"
 #include "power.h"
 #include "battery.h"
@@ -47,49 +48,49 @@ extern void wake_laptop_daemon();
 extern "C"
 {
 
-  KCModule *create_pcmcia(QWidget *parent, const char *)
+  KDE_EXPORT KCModule *create_pcmcia(QWidget *parent, const char *)
   {
     return new PcmciaConfig(parent, "kcmlaptop");
   }
 
-  KCModule *create_bwarning(QWidget *parent, const char *)
+  KDE_EXPORT KCModule *create_bwarning(QWidget *parent, const char *)
   {
     return new WarningConfig(0, parent, "kcmlaptop");
   }
-  KCModule *create_cwarning(QWidget *parent, const char *)
+  KDE_EXPORT KCModule *create_cwarning(QWidget *parent, const char *)
   {
     return new WarningConfig(1, parent, "kcmlaptop");
   }
-  KCModule *create_battery(QWidget *parent, const char *)
+  KDE_EXPORT KCModule *create_battery(QWidget *parent, const char *)
   {
     return new BatteryConfig(parent, "kcmlaptop");
   }
-  KCModule *create_power(QWidget *parent, const char *)
+  KDE_EXPORT KCModule *create_power(QWidget *parent, const char *)
   {
     return new PowerConfig(parent, "kcmlaptop");
   }
-  KCModule *create_acpi(QWidget *parent, const char *)
+  KDE_EXPORT KCModule *create_acpi(QWidget *parent, const char *)
   {
     return new AcpiConfig(parent, "kcmlaptop");
   }
-  KCModule *create_apm(QWidget *parent, const char *)
+  KDE_EXPORT KCModule *create_apm(QWidget *parent, const char *)
   {
     return new ApmConfig(parent, "kcmlaptop");
   }
-  KCModule *create_Profile(QWidget *parent, const char *)
+  KDE_EXPORT KCModule *create_Profile(QWidget *parent, const char *)
   {
     return new ProfileConfig(parent, "kcmlaptop");
   }
-  KCModule *create_sony(QWidget *parent, const char *)
+  KDE_EXPORT KCModule *create_sony(QWidget *parent, const char *)
   {
     return new SonyConfig(parent, "kcmlaptop");
   }
-  KCModule *create_buttons(QWidget *parent, const char *)
+  KDE_EXPORT KCModule *create_buttons(QWidget *parent, const char *)
   {
     return new ButtonsConfig(parent, "kcmlaptop");
   }
 
-  void init_battery()
+  KDE_EXPORT void init_battery()
   {
     KConfig config("kcmlaptoprc", true /*readonly*/, false /*no globals*/);
     config.setGroup("BatteryDefault");
@@ -110,13 +111,12 @@ extern "C"
      wake_laptop_daemon();
   }
 
-  KCModule *create_laptop(QWidget *parent, const char *)
+  KDE_EXPORT KCModule *create_laptop(QWidget *parent, const char *)
   {
-    KGlobal::locale()->insertCatalogue( "klaptopdaemon" );
 	return new LaptopModule(parent, "kcmlaptop");
   }
 
-  void init_laptop()
+  KDE_EXPORT void init_laptop()
   {
 	init_battery();
   }
@@ -222,7 +222,14 @@ LaptopModule::LaptopModule(QWidget *parent, const char *)
   } else {
         sony = 0;
   }
-
+  
+  KAboutData* about = 
+  new KAboutData("kcmlaptop", I18N_NOOP("Laptop Battery Configuration"), LAPTOP_VERSION,
+       I18N_NOOP("Battery Control Panel Module"),
+      KAboutData::License_GPL,
+       I18N_NOOP("(c) 1999 Paul Campbell"), 0, 0);
+  //about->addAuthor("NAME", 0, "e-mail addy");
+  setAboutData( about );
 }
 
 void LaptopModule::load()
