@@ -18,7 +18,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 
@@ -35,6 +35,11 @@
 class WarningConfig;
 class BatteryConfig;
 class PowerConfig;
+class AcpiConfig;
+class ApmConfig;
+class SonyConfig;
+class ProfileConfig;
+class ButtonsConfig;
 
 class LaptopModule : public KCModule
 {
@@ -64,6 +69,11 @@ private:
   WarningConfig 	*critical;
   BatteryConfig   	*battery;
   PowerConfig  		*power;
+  AcpiConfig  		*acpi;
+  ApmConfig  		*apm;
+  ProfileConfig		*profile;
+  SonyConfig  		*sony;
+  ButtonsConfig		*buttons;
 };
 
 
