@@ -13,10 +13,3 @@ void KCMKVaioGeneral::slotChanged()
     emit(changed());
 }
 
-void KCMKVaioGeneral::slotBrightnessChanged( int value )
-{
-   int percent = (int)(100.0 * value / slBrightness->maxValue() +0.5);
-
-    tlCurrentBrightness->setText(QString( "%1%" ).arg( percent ));
-    slotChanged();
-}
