@@ -35,13 +35,11 @@ class KVaioModule : public KCModule
 public:
     KVaioModule(QWidget *parent, const char *name, const QStringList &);
 
-    QString quickHelp() const;
     void  save();
     void  load();
     void defaults();
 
 protected slots:
-    void moduleChanged();
     void timeout();
     void vaioEvent (int);
 private:
