@@ -43,7 +43,7 @@
 using namespace KMilo;
 
 extern "C" {
-   KDEDModule *create_kmilod(const QCString &name) {
+   KDE_EXPORT KDEDModule *create_kmilod(const QCString &name) {
 	   return new KMiloD(name);
    }
 }
