@@ -15,10 +15,10 @@
  *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  *  Boston, MA 02111-1307, USA.
  **/
-#ifndef __dcbutton
-#define __dcbutton
+#ifndef dcbutton
+#define dcbutton
+
 #include <qtoolbutton.h>
-#include <qpixmap.h>
 class QMouseEvent;
 
 /**
@@ -39,4 +39,4 @@ signals:
   void doubleClicked();
 };
 
-#endif // __dcbutton
+#endif // dcbutton
