@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #include "generalprefs.h"
@@ -61,11 +61,11 @@ KSim::GeneralPrefs::GeneralPrefs(QWidget *parent, const char *name)
   m_sizeHSpin->setValue(40);
   m_sizeHSpin->setMinValue(40);
   m_sizeHSpin->setMaxValue(200);
-  m_sizeHSpin->setSizePolicy(QSizePolicy(QSizePolicy::Preferred, 
+  m_sizeHSpin->setSizePolicy(QSizePolicy(QSizePolicy::Preferred,
      QSizePolicy::Fixed));
   sizeBoxLayout->addWidget(m_sizeHSpin, 0, 1);
 
-  QSpacerItem *sizeHSpacer = new QSpacerItem(20, 20, 
+  QSpacerItem *sizeHSpacer = new QSpacerItem(20, 20,
      QSizePolicy::Expanding, QSizePolicy::Minimum);
   sizeBoxLayout->addItem(sizeHSpacer, 0, 2);
 
@@ -77,7 +77,7 @@ KSim::GeneralPrefs::GeneralPrefs(QWidget *parent, const char *name)
   m_sizeWSpin->setValue(58);
   m_sizeWSpin->setMinValue(58);
   m_sizeWSpin->setMaxValue(200);
-  m_sizeWSpin->setSizePolicy(QSizePolicy(QSizePolicy::Preferred, 
+  m_sizeWSpin->setSizePolicy(QSizePolicy(QSizePolicy::Preferred,
      QSizePolicy::Fixed));
   sizeBoxLayout->addWidget(m_sizeWSpin, 1, 1);
 
@@ -85,33 +85,21 @@ KSim::GeneralPrefs::GeneralPrefs(QWidget *parent, const char *name)
   sizeBoxLayout->addItem(sizeWSpacer, 1, 2);
 
   m_mainLayout->addWidget(m_sizeBox, 0, 0);
-  QSpacerItem *boxSpacer = new QSpacerItem(20, 20, 
+  QSpacerItem *boxSpacer = new QSpacerItem(20, 20,
      QSizePolicy::Expanding, QSizePolicy::Minimum);
   m_mainLayout->addItem(boxSpacer, 0, 1);
 
-  m_showDock = new QCheckBox(this);
-  m_showDock->setText(i18n("Show systray icon"));
-  m_mainLayout->addWidget(m_showDock, 1, 0);
-
-  m_savePos = new QCheckBox(this);
-  m_savePos->setText(i18n("Save position"));
-  m_mainLayout->addWidget(m_savePos, 2, 0);
-
-  m_stayOnTop = new QCheckBox(this);
-  m_stayOnTop->setText(i18n("Always on top"));
-  m_mainLayout->addWidget(m_stayOnTop, 3, 0);
-
   m_displayFqdn = new QCheckBox(this);
   m_displayFqdn->setText(i18n("Display fully qualified domain name"));
-  m_mainLayout->addMultiCellWidget(m_displayFqdn, 4, 4, 0, 1);
+  m_mainLayout->addMultiCellWidget(m_displayFqdn, 1, 1, 0, 1);
 
   m_recolourThemes = new QCheckBox(this);
-  m_recolourThemes->setText(i18n("Recolour themes to the current colour scheme"));
-  m_mainLayout->addMultiCellWidget(m_recolourThemes, 5, 5, 0, 1);
+  m_recolourThemes->setText(i18n("Recolor themes to the current color scheme"));
+  m_mainLayout->addMultiCellWidget(m_recolourThemes, 2, 2, 0, 1);
 
   QSpacerItem *spacer = new QSpacerItem(20, 20,
      QSizePolicy::Minimum, QSizePolicy::Expanding);
-  m_mainLayout->addItem(spacer, 6, 0);
+  m_mainLayout->addItem(spacer, 3, 0);
 }
 
 KSim::GeneralPrefs::~GeneralPrefs()
@@ -120,9 +108,6 @@ KSim::GeneralPrefs::~GeneralPrefs()
 
 void KSim::GeneralPrefs::saveConfig(KSim::Config *config)
 {
-  config->setShowDock(m_showDock->isChecked());
-  config->setSavePos(m_savePos->isChecked());
-  config->setStayOnTop(m_stayOnTop->isChecked());
   config->setGraphSize(QSize(m_sizeWSpin->value(), m_sizeHSpin->value()));
   config->setDisplayFqdn(m_displayFqdn->isChecked());
   config->setReColourThemes(m_recolourThemes->isChecked());
@@ -133,9 +118,6 @@ void KSim::GeneralPrefs::readConfig(KSim::Config *config)
   QSize size = config->graphSize();
   m_sizeHSpin->setValue(size.height());
   m_sizeWSpin->setValue(size.width());
-  m_showDock->setChecked(config->showDock());
-  m_savePos->setChecked(config->savePos());
-  m_stayOnTop->setChecked(config->stayOnTop());
   m_displayFqdn->setChecked(config->displayFqdn());
   m_recolourThemes->setChecked(config->reColourThemes());
 }
@@ -146,38 +128,14 @@ KSim::ClockPrefs::ClockPrefs(QWidget *parent, const char *name)
   m_mainLayout = new QVBoxLayout(this);
   m_mainLayout->setSpacing(6);
 
-  m_timeBox = new QGroupBox(this);
-  m_timeBox->setTitle(i18n("Time"));
-  m_timeBox->setColumnLayout(0, Qt::Vertical);
-  m_timeLayout = new QVBoxLayout(m_timeBox->layout());
-
-  m_timeCheck = new QCheckBox(m_timeBox);
-  m_timeLayout->addWidget(m_timeCheck);
-  m_timeCheck->setText(i18n("Show time"));
+  m_timeCheck = new QCheckBox(i18n("Show time"),this);
+  m_mainLayout->addWidget(m_timeCheck);
   m_timeCheck->setChecked(true);
 
-  m_24hourCheck = new QCheckBox(m_timeBox);
-  m_timeLayout->addWidget(m_24hourCheck);
-  m_24hourCheck->setText(i18n("Display 24 hour instead of 12 hour"));
-
-  connect(m_timeCheck, SIGNAL(toggled(bool)),
-     m_24hourCheck, SLOT(setEnabled(bool)));
-
-  m_mainLayout->addWidget(m_timeBox);
-
-  m_dateBox = new QGroupBox(this);
-  m_dateBox->setTitle(i18n("Date"));
-  m_dateBox->setColumnLayout(0, Qt::Vertical);
-
-  m_dateLayout = new QVBoxLayout(m_dateBox->layout());
-
-  m_dateCheck = new QCheckBox(m_dateBox);
-  m_dateLayout->addWidget(m_dateCheck);
-  m_dateCheck->setText(i18n("Show date"));
+  m_dateCheck = new QCheckBox(i18n("Show date"),this);
+  m_mainLayout->addWidget(m_dateCheck);
   m_dateCheck->setChecked(true);
 
-  m_mainLayout->addWidget(m_dateBox);
-
   QSpacerItem *spacer = new QSpacerItem(20, 20,
      QSizePolicy::Minimum, QSizePolicy::Expanding);
   m_mainLayout->addItem(spacer);
@@ -190,14 +148,12 @@ KSim::ClockPrefs::~ClockPrefs()
 void KSim::ClockPrefs::saveConfig(KSim::Config *config)
 {
   config->setShowTime(m_timeCheck->isChecked());
-  config->setShow24hour(m_24hourCheck->isChecked());
   config->setShowDate(m_dateCheck->isChecked());
 }
 
 void KSim::ClockPrefs::readConfig(KSim::Config *config)
 {
   m_timeCheck->setChecked(config->showTime());
-  m_24hourCheck->setChecked(config->show24hour());
   m_dateCheck->setChecked(config->showDate());
 }
 
@@ -206,7 +162,7 @@ KSim::UptimePrefs::UptimePrefs(QWidget *parent, const char *name)
 {
   m_addIcon = SmallIconSet("filenew");
   m_removeIcon = SmallIconSet("editdelete");
-  
+
   m_mainLayout = new QVBoxLayout(this);
   m_mainLayout->setSpacing(6);
 
@@ -318,7 +274,7 @@ void KSim::UptimePrefs::uptimeContextMenu(QPopupMenu *menu)
   menu->insertSeparator();
   menu->insertItem(m_addIcon, i18n("Insert Item"),
      this, SLOT(insertUptimeItem()));
-  menu->insertItem(m_removeIcon, i18n("Remove Item"), 
+  menu->insertItem(m_removeIcon, i18n("Remove Item"),
      this, SLOT(removeUptimeItem()));
 }
 
@@ -349,11 +305,11 @@ KSim::MemoryPrefs::MemoryPrefs(QWidget *parent, const char *name)
 
   m_memCombo = new KComboBox(true, this);
   m_memCombo->setDuplicatesEnabled(false);
-  m_memCombo->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, 
+  m_memCombo->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,
      QSizePolicy::Fixed));
   m_memCombo->insertItem(i18n("%tM - %fM free"));
   m_memCombo->insertItem(i18n("%tM - %uM used"));
-  connect(m_memCombo, 
+  connect(m_memCombo,
      SIGNAL(aboutToShowContextMenu(QPopupMenu *)),
      SLOT(memoryContextMenu(QPopupMenu *)));
 
@@ -402,6 +358,10 @@ KSim::MemoryPrefs::MemoryPrefs(QWidget *parent, const char *name)
   m_mtLabel->setText(i18n("%t - Total memory"));
   m_boxLayout->addWidget(m_mtLabel);
 
+  m_mfLabel = new QLabel(m_memBox);
+  m_mfLabel->setText(i18n("%F - Total free memory including cached and buffered"));
+  m_boxLayout->addWidget(m_mfLabel);
+
   m_mfLabel = new QLabel(m_memBox);
   m_mfLabel->setText(i18n("%f - Total free memory"));
   m_boxLayout->addWidget(m_mfLabel);
@@ -413,7 +373,7 @@ KSim::MemoryPrefs::MemoryPrefs(QWidget *parent, const char *name)
   m_mcLabel = new QLabel(m_memBox);
   m_mcLabel->setText(i18n("%c - Total cached memory"));
   m_boxLayout->addWidget(m_mcLabel);
- 
+
   m_mbLabel = new QLabel(m_memBox);
   m_mbLabel->setText(i18n("%b - Total buffered memory"));
   m_boxLayout->addWidget(m_mbLabel);
@@ -460,9 +420,9 @@ void KSim::MemoryPrefs::readConfig(KSim::Config *config)
 void KSim::MemoryPrefs::memoryContextMenu(QPopupMenu *menu)
 {
   menu->insertSeparator();
-  menu->insertItem(m_addIcon, i18n("Insert item"),
+  menu->insertItem(m_addIcon, i18n("Insert Item"),
      this, SLOT(insertMemoryItem()));
-  menu->insertItem(m_removeIcon, i18n("Remove item"),
+  menu->insertItem(m_removeIcon, i18n("Remove Item"),
      this, SLOT(removeMemoryItem()));
 }
 
@@ -592,8 +552,8 @@ void KSim::SwapPrefs::readConfig(KSim::Config *config)
 void KSim::SwapPrefs::swapContextMenu(QPopupMenu *menu)
 {
   menu->insertSeparator();
-  menu->insertItem(m_addIcon, i18n("Insert item"), this, SLOT(insertSwapItem()));
-  menu->insertItem(m_removeIcon, i18n("Remove item"), this, SLOT(removeSwapItem()));
+  menu->insertItem(m_addIcon, i18n("Insert Item"), this, SLOT(insertSwapItem()));
+  menu->insertItem(m_removeIcon, i18n("Remove Item"), this, SLOT(removeSwapItem()));
 }
 
 void KSim::SwapPrefs::insertSwapItem()
