@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #ifndef KSIMFRAME_H
@@ -26,7 +26,7 @@
 
 namespace KSim
 {
-  class MainWindow;
+  class PanelExtension;
 
   /**
    * @internal
@@ -35,8 +35,7 @@ namespace KSim
   {
     Q_OBJECT
     public:
-      Frame(KSim::MainWindow *topLevel, int type,
-         QWidget *parent, const char *name=0);
+      Frame(int type, QWidget *parent, const char *name = 0);
       ~Frame();
 
       const QPixmap *const background() const { return &m_background; }
@@ -45,12 +44,6 @@ namespace KSim
     protected:
       virtual void paintEvent(QPaintEvent *);
       virtual void resizeEvent(QResizeEvent *);
-      virtual void mousePressEvent(QMouseEvent *e);
-      virtual void mouseReleaseEvent(QMouseEvent *e);
-      virtual void mouseMoveEvent(QMouseEvent *e);
-      virtual void enterEvent(QEvent *);
-      virtual void leaveEvent(QEvent *);
-      virtual bool eventFilter(QObject *, QEvent *);
 
     private:
       // helper functions to make
@@ -65,8 +58,6 @@ namespace KSim
       QPoint m_origPos;
       QImage m_image;
       QPixmap m_background;
-      bool m_resizing;
-      KSim::MainWindow *m_topLevel;
   };
 }
 #endif
