@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #ifndef KSIM__LABEL_H
@@ -23,6 +23,8 @@
 #include <qwidget.h>
 #include "common.h"
 
+#include <kdemacros.h>
+
 namespace KSim
 {
   /**
@@ -32,7 +34,7 @@ namespace KSim
    * @short Label widget
    * @author Robbie Ward <linuxphreak@gmx.co.uk>
    */
-  class Label : public QWidget, public KSim::Base
+  class KDE_EXPORT Label : public QWidget, public KSim::Base
   {
     Q_OBJECT
     public:
@@ -136,19 +138,19 @@ namespace KSim
        */
       bool showShadow() const;
       /**
-       * Set the text colour
+       * Set the text color
        */
-      void setTextColour(const QColor &colour);
+      void setTextColour(const QColor &color);
       /**
-       * @return the text colour
+       * @return the text color
        */
       const QColor &textColour() const;
       /**
-       * Set the shadow colour
+       * Set the shadow color
        */
-      void setShadowColour(const QColor &colour);
+      void setShadowColour(const QColor &color);
       /**
-       * @return the shadow colour
+       * @return the shadow color
        */
       const QColor &shadowColour() const;
       /**
@@ -167,7 +169,7 @@ namespace KSim
        * draw the text onto the label
        */
       void drawText(QPainter *painter, const QRect &rect,
-          const QColor &colour, const QString &text);
+          const QColor &color, const QString &text);
       /**
        * draw the pixmap onto the label
        */
