@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #ifndef PLUGINLOADER_H
@@ -23,9 +23,11 @@
 #include "pluginglobal.h"
 #include <qobject.h>
 
+#include <kdemacros.h>
+
 namespace KSim
 {
-  class PluginInfo
+  class KDE_EXPORT PluginInfo
   {
     friend class PluginLoader;
     public:
@@ -59,7 +61,7 @@ namespace KSim
    * Provides a loader for the plugins
    * @author Robbie Ward <linuxphreak@gmx.co.uk>
    */
-  class PluginLoader : public QObject
+  class KDE_EXPORT PluginLoader : public QObject
   {
     Q_OBJECT
     friend class MainView;
@@ -81,11 +83,11 @@ namespace KSim
        * you can then use @ref pluginList() to access the plugin, view,
        * config page and plugin information
        * @param file is the desktop file of the lib
-       * @return true if the plugin is succesfully loaded
+       * @return true if the plugin is successfully loaded
        */
       bool loadPlugin(const KDesktopFile &file);
       /**
-       * unloads a loaded plugin and removes plugin entrys from pluginList()
+       * unloads a loaded plugin and removes plugin entries from pluginList()
        */
       bool unloadPlugin(const QCString &name);
       /**
