@@ -26,6 +26,8 @@
 #include <qfont.h>
 #include <qvaluelist.h>
 
+#include <kdemacros.h>
+
 class QStringList;
 template<class> class QValueVector;
 class KConfig;
@@ -42,7 +44,7 @@ namespace KSim
    * @author Robbie Ward <linuxphreak@gmx.co.uk>
    * @short Provides a loader for the themes
    */
-  class Theme
+  class KDE_EXPORT Theme
   {
     friend class ThemeLoader;
     public:
@@ -395,7 +397,7 @@ namespace KSim
    * @author Robbie Ward <linuxphreak@gmx.co.uk>
    * @short Provides a loader for the themes
    */
-  class ThemeLoader
+  class KDE_EXPORT ThemeLoader
   {
     public:
       /**
