@@ -237,12 +237,13 @@ void CpuView::updateCpu(CpuData &cpu, int cpuNumber)
 
 #ifdef Q_OS_FREEBSD
 #warning "add support for SMP on FreeBSD"
+  Q_UNUSED(cpuNumber);
   static int name2oid[2] = { 0, 3 };
   static int oidCpuTime[CTL_MAXNAME + 2];
   static size_t oidCpuTimeLen = sizeof(oidCpuTime);
   long cpuTime[CPUSTATES];
   size_t cpuTimeLen = sizeof(cpuTime);
-  static char *name = "kern.cp_time";
+  static char name[] = "kern.cp_time";
   static int initialized = 0;
 
   if (!initialized) {
