@@ -34,7 +34,7 @@
 #include <klocale.h>
 #include <kapplication.h>
 #include <klistview.h>
-#include <klineeditdlg.h>
+#include <kinputdialog.h>
 #include <kconfig.h>
 
 #include <chart.h>
@@ -108,12 +108,15 @@ DiskView::DiskView(KSim::PluginObject *parent, const char *name)
 #endif
 
   config()->setGroup("DiskPlugin");
-  m_list = config()->readListEntry("Disks");
+  m_list = config()->readListEntry("Disks", QStringList() << "complete");
   m_useSeperatly = config()->readBoolEntry("UseSeperatly", true);
 
   m_firstTime = 1;
   m_addAll = false;
   m_layout = new QVBoxLayout(this);
+  QSpacerItem *item = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Expanding);
+  m_layout->addItem(item);
+
   init();
 
   m_timer = new QTimer(this);
@@ -135,7 +138,7 @@ DiskView::~DiskView()
 void DiskView::reparseConfig()
 {
   config()->setGroup("DiskPlugin");
-  QStringList list = config()->readListEntry("Disks");
+  QStringList list = config()->readListEntry("Disks", QStringList() << "complete");
   m_useSeperatly = config()->readBoolEntry("UseSeperatly", true);
 
   if (list != m_list) {
@@ -156,43 +159,48 @@ void DiskView::reparseConfig()
   }
 }
 
+DiskView::DiskData DiskView::findDiskData(const DiskList& diskList, QString diskName)
+{
+  if (diskName == "complete")
+     diskName = i18n("All Disks");
+
+  DiskView::DiskList::ConstIterator disk;
+  for (disk = diskList.begin(); disk != diskList.end(); ++disk)
+     if ((*disk).name == diskName)
+        return *disk;
+
+  // Not found
+  DiskView::DiskData dummy;
+  dummy.name = "["+diskName+"]";
+  return dummy;  
+}
+
 // Kind of messy code, dont ya think?
 void DiskView::updateDisplay()
 {
   DiskList diskList;
-  DiskList newList;
-  DiskData all;
+
   updateData(diskList);
 
-  int i = 0;
-  DiskList::ConstIterator disk;
-  for (disk = diskList.begin(); disk != diskList.end(); ++disk) {
-    if (m_addAll)
-      all += (*disk);
+  if (m_addAll)
+  {
+    DiskData all;
+    all.name = i18n("All Disks");
 
-    QStringList::ConstIterator string;
-    for (string = m_list.begin(); string != m_list.end(); ++string) {
-      if ((*disk).name == (*string))
-        newList.append((*disk));
+    for (DiskList::ConstIterator disk = diskList.begin(); 
+         disk != diskList.end(); ++disk)
+    {
+      all += (*disk);
     }
 
-    ++i;
+    diskList.prepend(all);
   }
 
-  if (m_addAll) {
-    all.name = i18n("All Disks");
-    newList.prepend(all);
-  }
-
-  diskList.clear();
   // merge all the disks into one
-  i = 0;
-  DiskData diskData;
   QPtrListIterator<DiskPair> it(m_diskList);
-  for (; it.current(); ++it) {
+  for (int i = 0; it.current(); ++it, ++i) {
+    DiskData diskData = findDiskData(diskList, m_list[i]);
     m_data[i].second = m_data[i].first;
-    diskData = newList[i];
-
     m_data[i].first = diskData;
     diskData -= m_data[i].second;
     unsigned long diff = diskData.readBlocks + diskData.writeBlocks;
@@ -214,7 +222,6 @@ void DiskView::updateDisplay()
     it.current()->second->setMaxValue(it.current()->first->maxValue());
     it.current()->second->setText(diskData.name);
     it.current()->second->setValue(diff);
-    ++i;
   }
 
   m_firstTime = 0;
@@ -419,6 +426,10 @@ QString DiskView::diskName( int major, int minor ) const
 
   returnValue.at(2) = returnValue.at(2).latin1() + minor;
   return returnValue;
+#else
+  Q_UNUSED(major);
+  Q_UNUSED(minor);
+  return 0;
 #endif
 }
 
@@ -426,7 +437,7 @@ DiskView::DiskPair *DiskView::addDisk()
 {
   KSim::Chart *chart = new KSim::Chart(false, 0, this);
   chart->show();
-  m_layout->addWidget(chart, 0, AlignHCenter);
+  m_layout->addWidget(chart);
 
   KSim::Progress *progress = new KSim::Progress(0, KSim::Types::None,
      KSim::Progress::Panel, this);
@@ -533,8 +544,11 @@ void DiskConfig::saveConfig()
 void DiskConfig::addItem()
 {
   bool ok = false;
-  QString text = KLineEditDlg::getText(i18n("Add Disk Device"), i18n("Disk name:"),
+  QString text = KInputDialog::getText(i18n("Add Disk Device"), i18n("Disk name:"),
      QString::null, &ok, this);
+  
+  if (text.startsWith("/dev/"))
+    text = text.mid(5);
 
   if (ok)
     new QListViewItem(m_listview, text);
