@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #include "ksimsensors.h"
@@ -72,8 +72,7 @@ void PluginModule::showAbout()
 }
 
 SensorsView::SensorsView(KSim::PluginObject *parent, const char *name)
-   : KSim::PluginView(parent, name),
-   DCOPObject("sensors")
+   : DCOPObject("sensors"), KSim::PluginView(parent, name)
 {
   config()->setGroup("Sensors");
   (new QVBoxLayout(this))->setAutoAdd(true);
