@@ -26,7 +26,7 @@
 #include <kio/netaccess.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kwallet.h>
 
 #include <qdragobject.h>
@@ -386,12 +386,12 @@ void KWalletIconView::slotDropped(QDropEvent *e, const QValueList<QIconDragItem>
 	}
 
 	KURL u(ul.first());
-	if (u.filename().isEmpty()) {
+	if (u.fileName().isEmpty()) {
 		e->ignore();
 		return;
 	}
 
-	QString dest = KGlobal::dirs()->saveLocation("kwallet") + u.filename();
+	QString dest = KGlobal::dirs()->saveLocation("kwallet") + u.fileName();
 	if (QFile::exists(dest)) {
 		KMessageBox::sorry(viewport(), i18n("That wallet file already exists.  You cannot overwrite wallets."));
 		e->ignore();
@@ -399,7 +399,7 @@ void KWalletIconView::slotDropped(QDropEvent *e, const QValueList<QIconDragItem>
 	}
 
 	// FIXME: verify that it is a real wallet file first
-	KIO::NetAccess::file_copy(u, dest);
+	KIO::NetAccess::file_copy(u, KURL::fromPathOrURL(dest));
 	e->accept();
 }
 
