@@ -18,6 +18,7 @@
 */
 
 
+#include "kbetterthankdialogbase.h"
 #include "kwalleteditor.h"
 #include "kwmapeditor.h"
 #include "allyourbase.h"
@@ -29,24 +30,29 @@
 #include <kdebug.h>
 #include <kfiledialog.h>
 #include <kiconview.h>
-#include <kio/netaccess.h>
 #include <kinputdialog.h>
+#include <kio/netaccess.h>
+#include <klistviewsearchline.h>
 #include <klocale.h>
 #include <kmdcodec.h>
 #include <kmessagebox.h>
 #include <kpopupmenu.h>
 #include <ksqueezedtextlabel.h>
+#include <kstandarddirs.h>
 #include <kstdaction.h>
+#include <kstringhandler.h>
 #include <ktempfile.h>
 
 #include <qcheckbox.h>
 #include <qcombobox.h>
+#include <qclipboard.h>
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qlineedit.h>
 #include <qlistview.h>
 #include <qptrstack.h>
 #include <qpushbutton.h>
+#include <qstylesheet.h>
 #include <qtextedit.h>
 #include <qwidgetstack.h>
 
@@ -54,7 +60,9 @@
 
 KWalletEditor::KWalletEditor(const QString& wallet, bool isPath, QWidget *parent, const char *name)
 : KMainWindow(parent, name), _walletName(wallet), _nonLocal(isPath) {
+	_newWallet = false;
 	_ww = new WalletWidget(this, "Wallet Widget");
+	_copyPassAction = KStdAction::copy(this, SLOT(copyPassword()), actionCollection());
 	QVBoxLayout *box = new QVBoxLayout(_ww->_folderDetails);
 	_details = new QLabel(_ww->_folderDetails, "Folder Details");
         _details->setBackgroundMode(PaletteBase);
@@ -64,6 +72,7 @@ KWalletEditor::KWalletEditor(const QString& wallet, bool isPath, QWidget *parent
 
 	box = new QVBoxLayout(_ww->_entryListFrame);
 	_entryList = new KWalletEntryList(_ww->_entryListFrame, "Wallet Entry List");
+	box->addWidget(new KListViewSearchLine(_ww->_entryListFrame, _entryList));
 	box->addWidget(_entryList);
 
 	_entryList->setEnabled(false);
@@ -188,12 +197,21 @@ void KWalletEditor::createActions() {
 			SLOT(changePassword()), actionCollection(),
 			"change_password");
 
+	_mergeAction = new KAction(i18n("&Merge Wallet..."), 0, 0, this,
+			SLOT(importWallet()), actionCollection(),
+			"merge");
+
+	_importAction = new KAction(i18n("&Import XML..."), 0, 0, this,
+			SLOT(importXML()), actionCollection(),
+			"import");
+
 	_exportAction = new KAction(i18n("&Export..."), 0, 0, this,
 			SLOT(exportXML()), actionCollection(),
 			"export");
 
-	KStdAction::close(this, SLOT(close()), actionCollection());
-         KStdAction::keyBindings(guiFactory(), SLOT(configureShortcuts()),
+	KStdAction::saveAs(this, SLOT(saveAs()), actionCollection());
+	KStdAction::quit(this, SLOT(close()), actionCollection());
+	KStdAction::keyBindings(guiFactory(), SLOT(configureShortcuts()),
 actionCollection());
 	emit enableFolderActions(_w != 0L);
 	emit enableContextFolderActions(false);
@@ -240,7 +258,7 @@ void KWalletEditor::deleteFolder() {
 			if (rc == KMessageBox::Continue) {
 				bool rc = _w->removeFolder(ivi->text());
 				if (!rc) {
-					KMessageBox::sorry(this, i18n("Error deleting folder.  Error code=%1").arg((int)rc));
+					KMessageBox::sorry(this, i18n("Error deleting folder."));
 					return;
 				}
 				updateFolderList();
@@ -404,10 +422,13 @@ void KWalletEditor::updateDetails() {
 			"</ul>"
 			"</qt>");
 
-	_details->setText(page
-                        .arg(i18n("Folder:"))
-			.arg(_folderView->currentItem()->text())
-			.arg(i18n("Contains one item.", "Contains %n items." ,_entries.count())));
+	if (_folderView->currentItem())
+		_details->setText(page
+                	        .arg(i18n("Folder:"))
+				.arg(_folderView->currentItem()->text())
+				.arg(i18n("Contains one item.", "Contains %n items." ,_entries.count())));
+	else
+		_details->setText(QString::null);
 }
 
 
@@ -503,11 +524,18 @@ void KWalletEditor::listContextMenuRequested(QListViewItem *item, const QPoint&
 	}
 
 	KPopupMenu *m = new KPopupMenu(this);
-	m->insertTitle(item->text(0));
+	QString title = item->text(0);
+	// I think 200 pixels is wide enough for a title
+	title = KStringHandler::cPixelSqueeze(title, m->fontMetrics(), 200);
+	m->insertTitle(title);
 	if (item->parent()) {
 		m->insertItem(i18n("&New..." ), this, SLOT(newEntry()), Key_Insert);
 		m->insertItem(i18n( "&Rename" ), this, SLOT(renameEntry()), Key_F2);
 		m->insertItem(i18n( "&Delete" ), this, SLOT(deleteEntry()), Key_Delete);
+		if (item->parent() == _passItems) {
+			m->insertSeparator();
+			_copyPassAction->plug(m);
+		}
 		m->popup(pos);
 	} else {
 		m->insertItem(i18n( "&New..." ), this, SLOT(newEntry()), Key_Insert);
@@ -516,6 +544,17 @@ void KWalletEditor::listContextMenuRequested(QListViewItem *item, const QPoint&
 }
 
 
+void KWalletEditor::copyPassword() {
+	QListViewItem *item = _entryList->selectedItem();
+	if (_w && item) {
+		QString pass;
+		if (_w->readPassword(item->text(0), pass) == 0) {
+			QApplication::clipboard()->setText(pass);
+		}
+	}
+}
+
+
 void KWalletEditor::newEntry() {
 	QListViewItem *item = _entryList->selectedItem();
 	QString n;
@@ -565,7 +604,7 @@ void KWalletEditor::newEntry() {
 
 
 void KWalletEditor::renameEntry() {
-QListViewItem *item = _entryList->selectedItem();
+	QListViewItem *item = _entryList->selectedItem();
 	if (_w && item) {
 		item->startRename(0);
 	}
@@ -603,7 +642,7 @@ void KWalletEditor::listItemRenamed(QListViewItem* item, int, const QString& t)
 
 
 void KWalletEditor::deleteEntry() {
-QListViewItem *item = _entryList->selectedItem();
+	QListViewItem *item = _entryList->selectedItem();
 	if (_w && item) {
 		int rc = KMessageBox::warningContinueCancel(this, i18n("Are you sure you wish to delete the item '%1'?").arg(item->text(0)),"",KStdGuiItem::del());
 		if (rc == KMessageBox::Continue) {
@@ -616,7 +655,7 @@ QListViewItem *item = _entryList->selectedItem();
 
 
 void KWalletEditor::updateEntries(const QString& folder) {
-QIconViewItem *ivi = _folderView->currentItem();
+	QIconViewItem *ivi = _folderView->currentItem();
 
 	if (ivi && ivi->text() == folder) {
 		_entries = _w->entryList();
@@ -635,7 +674,10 @@ void KWalletEditor::walletOpened(bool success) {
 	if (success) {
 		updateFolderList();
 	} else {
-		KMessageBox::sorry(this, i18n("Unable to open the requested wallet."));
+		if (!_newWallet) {
+			KMessageBox::sorry(this, i18n("Unable to open the requested wallet."));
+		}
+		close();
 	}
 }
 
@@ -659,11 +701,249 @@ void KWalletEditor::showHideMapEditorValue(bool show) {
 }
 
 
+enum MergePlan { Prompt = 0, Always = 1, Never = 2, Yes = 3, No = 4 };
+
+void KWalletEditor::importWallet() {
+	KURL url = KFileDialog::getOpenURL(QString::null, "*.kwl", this);
+	if (url.isEmpty()) {
+		return;
+	}
+
+	QString tmpFile;
+	if (!KIO::NetAccess::download(url, tmpFile, this)) {
+		KMessageBox::sorry(this, i18n("Unable to access wallet '<b>%1</b>'.").arg(url.prettyURL()));
+		return;
+	}
+
+	KWallet::Wallet *w = KWallet::Wallet::openWallet(tmpFile, winId(), KWallet::Wallet::Path);
+	if (w && w->isOpen()) {
+		MergePlan mp = Prompt;
+		QStringList fl = w->folderList();
+		for (QStringList::ConstIterator f = fl.constBegin(); f != fl.constEnd(); ++f) {
+			if (!w->setFolder(*f)) {
+				continue;
+			}
+
+			if (!_w->hasFolder(*f)) {
+				_w->createFolder(*f);
+			}
+
+			_w->setFolder(*f);
+			
+			QMap<QString, QMap<QString, QString> > map;
+			int rc;
+			rc = w->readMapList("*", map);
+			if (rc == 0) {
+				QMap<QString, QMap<QString, QString> >::ConstIterator me;
+				for (me = map.constBegin(); me != map.constEnd(); ++me) {
+					bool hasEntry = _w->hasEntry(me.key());
+					if (hasEntry && mp == Prompt) {
+						KBetterThanKDialogBase *bd;
+						bd = new KBetterThanKDialogBase(this);
+						bd->setLabel(i18n("Folder '<b>%1</b>' already contains an entry '<b>%2</b>'.  Do you wish to replace it?").arg(QStyleSheet::escape(*f)).arg(QStyleSheet::escape(me.key())));
+						mp = (MergePlan)bd->exec();
+						delete bd;
+						bool ok = false;
+						if (mp == Always || mp == Yes) {
+							ok = true;
+						}
+						if (mp == Yes || mp == No) {
+						       	// reset mp
+							mp = Prompt;
+						}
+						if (!ok) {
+							continue;
+						}
+					} else if (hasEntry && mp == Never) {
+						continue;
+					}
+					_w->writeMap(me.key(), me.data());
+				}
+			}
+
+			QMap<QString, QString> pwd;
+			rc = w->readPasswordList("*", pwd);
+			if (rc == 0) {
+				QMap<QString, QString>::ConstIterator pe;
+				for (pe = pwd.constBegin(); pe != pwd.constEnd(); ++pe) {
+					bool hasEntry = _w->hasEntry(pe.key());
+					if (hasEntry && mp == Prompt) {
+						KBetterThanKDialogBase *bd;
+						bd = new KBetterThanKDialogBase(this);
+						bd->setLabel(i18n("Folder '<b>%1</b>' already contains an entry '<b>%2</b>'.  Do you wish to replace it?").arg(QStyleSheet::escape(*f)).arg(QStyleSheet::escape(pe.key())));
+						mp = (MergePlan)bd->exec();
+						delete bd;
+						bool ok = false;
+						if (mp == Always || mp == Yes) {
+							ok = true;
+						}
+						if (mp == Yes || mp == No) {
+						       	// reset mp
+							mp = Prompt;
+						}
+						if (!ok) {
+							continue;
+						}
+					} else if (hasEntry && mp == Never) {
+						continue;
+					}
+					_w->writePassword(pe.key(), pe.data());
+				}
+			}
+
+			QMap<QString, QByteArray> ent;
+			rc = w->readEntryList("*", ent);
+			if (rc == 0) {
+				QMap<QString, QByteArray>::ConstIterator ee;
+				for (ee = ent.constBegin(); ee != ent.constEnd(); ++ee) {
+					bool hasEntry = _w->hasEntry(ee.key());
+					if (hasEntry && mp == Prompt) {
+						KBetterThanKDialogBase *bd;
+						bd = new KBetterThanKDialogBase(this);
+						bd->setLabel(i18n("Folder '<b>%1</b>' already contains an entry '<b>%2</b>'.  Do you wish to replace it?").arg(QStyleSheet::escape(*f)).arg(QStyleSheet::escape(ee.key())));
+						mp = (MergePlan)bd->exec();
+						delete bd;
+						bool ok = false;
+						if (mp == Always || mp == Yes) {
+							ok = true;
+						}
+						if (mp == Yes || mp == No) {
+						       	// reset mp
+							mp = Prompt;
+						}
+						if (!ok) {
+							continue;
+						}
+					} else if (hasEntry && mp == Never) {
+						continue;
+					}
+					_w->writeEntry(ee.key(), ee.data());
+				}
+			}
+		}
+	}
+
+	delete w;
+
+	KIO::NetAccess::removeTempFile(tmpFile);
+	updateDetails();
+	updateEntries();
+	restoreEntry();
+}
+
+
+void KWalletEditor::importXML() {
+	KURL url = KFileDialog::getOpenURL(QString::null, "*.xml", this);
+	if (url.isEmpty()) {
+		return;
+	}
+
+	QString tmpFile;
+	if (!KIO::NetAccess::download(url, tmpFile, this)) {
+		KMessageBox::sorry(this, i18n("Unable to access XML file '<b>%1</b>'.").arg(url.prettyURL()));
+		return;
+	}
+
+	QFile qf(tmpFile);
+	if (!qf.open(IO_ReadOnly)) {
+		KMessageBox::sorry(this, i18n("Error opening XML file '<b>%1</b>' for input.").arg(url.prettyURL()));
+		KIO::NetAccess::removeTempFile(tmpFile);
+		return;
+	}
+
+	QDomDocument doc(tmpFile);
+	if (!doc.setContent(&qf)) {
+		KMessageBox::sorry(this, i18n("Error reading XML file '<b>%1</b>' for input.").arg(url.prettyURL()));
+		KIO::NetAccess::removeTempFile(tmpFile);
+		return;
+	}
+
+	QDomElement top = doc.documentElement();
+	if (top.tagName().lower() != "wallet") {
+		KMessageBox::sorry(this, i18n("Error: XML file does not contain a wallet."));
+		KIO::NetAccess::removeTempFile(tmpFile);
+		return;
+	}
+
+	QDomNode n = top.firstChild();
+	MergePlan mp = Prompt;
+	while (!n.isNull()) {
+		QDomElement e = n.toElement();
+		if (e.tagName().lower() != "folder") {
+			n = n.nextSibling();
+			continue;
+		}
+
+		QString fname = e.attribute("name");
+		if (fname.isEmpty()) {
+			n = n.nextSibling();
+			continue;
+		}
+		if (!_w->hasFolder(fname)) {
+			_w->createFolder(fname);
+		}
+		_w->setFolder(fname);
+		QDomNode enode = e.firstChild();
+		while (!enode.isNull()) {
+			e = enode.toElement();
+			QString type = e.tagName().lower();
+			QString ename = e.attribute("name");
+			bool hasEntry = _w->hasEntry(ename);
+			if (hasEntry && mp == Prompt) {
+				KBetterThanKDialogBase *bd;
+				bd = new KBetterThanKDialogBase(this);
+				bd->setLabel(i18n("Folder '<b>%1</b>' already contains an entry '<b>%2</b>'.  Do you wish to replace it?").arg(QStyleSheet::escape(fname)).arg(QStyleSheet::escape(ename)));
+				mp = (MergePlan)bd->exec();
+				delete bd;
+				bool ok = false;
+				if (mp == Always || mp == Yes) {
+					ok = true;
+				}
+				if (mp == Yes || mp == No) { // reset mp
+					mp = Prompt;
+				}
+				if (!ok) {
+					enode = enode.nextSibling();
+					continue;
+				}
+			} else if (hasEntry && mp == Never) {
+				enode = enode.nextSibling();
+				continue;
+			}
+
+			if (type == "password") {
+				_w->writePassword(ename, e.text());
+			} else if (type == "stream") {
+				_w->writeEntry(ename, KCodecs::base64Decode(e.text().latin1()));
+			} else if (type == "map") {
+				QMap<QString,QString> map;
+				QDomNode mapNode = e.firstChild();
+				while (!mapNode.isNull()) {
+					QDomElement mape = mapNode.toElement();
+					if (mape.tagName().lower() == "mapentry") {
+						map[mape.attribute("name")] = mape.text();
+					}
+					mapNode = mapNode.nextSibling();
+				}
+				_w->writeMap(ename, map);
+			}
+			enode = enode.nextSibling();
+		}
+		n = n.nextSibling();
+	}
+
+	KIO::NetAccess::removeTempFile(tmpFile);
+	updateDetails();
+	updateEntries();
+	restoreEntry();
+}
+
+
 void KWalletEditor::exportXML() {
-KTempFile tf;
-tf.setAutoDelete(true);
-QTextStream& ts(*tf.textStream());
-QStringList fl = _w->folderList();
+	KTempFile tf;
+	tf.setAutoDelete(true);
+	QTextStream& ts(*tf.textStream());
+	QStringList fl = _w->folderList();
 
 	ts << "<wallet name=\"" << _walletName << "\">" << endl;
 	for (QStringList::Iterator i = fl.begin(); i != fl.end(); ++i) {
@@ -719,7 +999,26 @@ QStringList fl = _w->folderList();
 	KURL url = KFileDialog::getSaveURL(QString::null, "*.xml", this);
 
 	if (!url.isEmpty()) {
-		KIO::NetAccess::upload(tf.name(), url, this);
+		KIO::NetAccess::file_copy(tf.name(), url, 0600, false, false, this);
+	}
+}
+
+
+void KWalletEditor::setNewWallet(bool x) {
+	_newWallet = x;
+}
+
+
+void KWalletEditor::saveAs() {
+	KURL url = KFileDialog::getSaveURL(QString::null, "*.kwl", this);
+	if (!url.isEmpty()) {
+		// Sync() kwalletd
+		if (_nonLocal) {
+			KIO::NetAccess::file_copy(_walletName, url, 0600, false, false, this);
+		} else {
+			QString path = KGlobal::dirs()->saveLocation("kwallet") + "/" + _walletName + ".kwl";
+			KIO::NetAccess::file_copy(path, url, 0600, false, false, this);
+		}
 	}
 }
 
