@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2003 George Staikos <staikos@kde.org>
+   Copyright (C) 2003,2004 George Staikos <staikos@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -23,8 +23,8 @@
 #include "kwalleteditor.h"
 #include "allyourbase.h"
 
-#include <dcopref.h>
 #include <dcopclient.h>
+#include <dcopref.h>
 #include <kaction.h>
 #include <kapplication.h>
 #include <kconfig.h>
@@ -34,6 +34,7 @@
 #include <kinputdialog.h>
 #include <klocale.h>
 #include <kmessagebox.h>
+#include <kstandarddirs.h>
 #include <kstdaction.h>
 #include <ksystemtray.h>
 #include <kwallet.h>
@@ -46,26 +47,28 @@
 
 KWalletManager::KWalletManager(QWidget *parent, const char *name, WFlags f)
 : KMainWindow(parent, name, f), DCOPObject("KWalletManager") {
+	KGlobal::dirs()->addResourceType("kwallet", "share/apps/kwallet");
+	_kwalletdLaunch = false;
 	QAccel *accel = new QAccel(this, "kwalletmanager");
 
 	KApplication::dcopClient()->setQtBridgeEnabled(false);
 	_shuttingDown = false;
 	KConfig cfg("kwalletrc"); // not sure why this setting isn't in kwalletmanagerrc...
 	KConfigGroup walletConfigGroup(&cfg, "Wallet");
-	if ( walletConfigGroup.readBoolEntry( "Launch Manager", true ) ) {
-	_tray = new KSystemTray(this, "kwalletmanager tray");
-	_tray->setPixmap(loadSystemTrayIcon("wallet_closed"));
-	QToolTip::add(_tray, i18n("KDE Wallet: No wallets open."));
-	connect(_tray,SIGNAL(quitSelected()),SLOT(shuttingDown()));
-	QStringList wl = KWallet::Wallet::walletList();
-	for (QStringList::Iterator it = wl.begin(); it != wl.end(); ++it) {
-		if (KWallet::Wallet::isOpen(*it)) {
-			_tray->setPixmap(loadSystemTrayIcon("wallet_open"));
-			QToolTip::remove(_tray);
-			QToolTip::add(_tray, i18n("KDE Wallet: A wallet is open."));
-			break;
+	if (walletConfigGroup.readBoolEntry("Launch Manager", true)) {
+		_tray = new KSystemTray(this, "kwalletmanager tray");
+		_tray->setPixmap(loadSystemTrayIcon("wallet_closed"));
+		QToolTip::add(_tray, i18n("KDE Wallet: No wallets open."));
+		connect(_tray,SIGNAL(quitSelected()),SLOT(shuttingDown()));
+		QStringList wl = KWallet::Wallet::walletList();
+		for (QStringList::Iterator it = wl.begin(); it != wl.end(); ++it) {
+			if (KWallet::Wallet::isOpen(*it)) {
+				_tray->setPixmap(loadSystemTrayIcon("wallet_open"));
+				QToolTip::remove(_tray);
+				QToolTip::add(_tray, i18n("KDE Wallet: A wallet is open."));
+				break;
+			}
 		}
-	}
 	} else {
 		_tray = 0;
 	}
@@ -89,11 +92,11 @@ KWalletManager::KWalletManager(QWidget *parent, const char *name, WFlags f)
 		this,
 		SLOT(possiblyRescan(const QCString&)));
 
-        connectDCOPSignal(_dcopRef->app(), _dcopRef->obj(), "allWalletsClosed()", "allWalletsClosed()", false);
-        connectDCOPSignal(_dcopRef->app(), _dcopRef->obj(), "walletClosed(QString)", "updateWalletDisplay()", false);
-        connectDCOPSignal(_dcopRef->app(), _dcopRef->obj(), "walletOpened(QString)", "aWalletWasOpened()", false);
-        connectDCOPSignal(_dcopRef->app(), _dcopRef->obj(), "walletDeleted(QString)", "updateWalletDisplay()", false);
-        connectDCOPSignal(_dcopRef->app(), _dcopRef->obj(), "walletListDirty()", "updateWalletDisplay()", false);
+	connectDCOPSignal(_dcopRef->app(), _dcopRef->obj(), "allWalletsClosed()", "allWalletsClosed()", false);
+	connectDCOPSignal(_dcopRef->app(), _dcopRef->obj(), "walletClosed(QString)", "updateWalletDisplay()", false);
+	connectDCOPSignal(_dcopRef->app(), _dcopRef->obj(), "walletOpened(QString)", "aWalletWasOpened()", false);
+	connectDCOPSignal(_dcopRef->app(), _dcopRef->obj(), "walletDeleted(QString)", "updateWalletDisplay()", false);
+	connectDCOPSignal(_dcopRef->app(), _dcopRef->obj(), "walletListDirty()", "updateWalletDisplay()", false);
 
 	// FIXME: slight race - a wallet can open, then we get launched, but the
 	//        wallet closes before we are done opening.  We will then stay
@@ -105,29 +108,30 @@ KWalletManager::KWalletManager(QWidget *parent, const char *name, WFlags f)
 	KAction *act = new KAction(i18n("Configure &Wallet..."), "configure",
 			0, this, SLOT(setupWallet()), actionCollection(),
 			"wallet_settings");
-	if ( _tray )
-	act->plug(_tray->contextMenu());
+	if (_tray) {
+		act->plug(_tray->contextMenu());
+	}
 	act = new KAction(i18n("Close &All Wallets"), 0, 0, this,
 			SLOT(closeAllWallets()), actionCollection(),
 			"close_all_wallets");
-	if ( _tray )
-	act->plug(_tray->contextMenu());
+	if (_tray) {
+		act->plug(_tray->contextMenu());
+	}
 	KStdAction::quit(this, SLOT(shuttingDown()), actionCollection());
-          KStdAction::keyBindings(guiFactory(), SLOT(configureShortcuts()),
+	KStdAction::keyBindings(guiFactory(), SLOT(configureShortcuts()),
 actionCollection());
 
 	createGUI("kwalletmanager.rc");
-        accel->connectItem(accel->insertItem(Key_Return),
-                           this, SLOT(openWallet()));
-        accel->connectItem(accel->insertItem(Key_Delete),
-                           this, SLOT(deleteWallet()));
+	accel->connectItem(accel->insertItem(Key_Return), this, SLOT(openWallet()));
+	accel->connectItem(accel->insertItem(Key_Delete), this, SLOT(deleteWallet()));
 
-	if ( _tray )
-	_tray->show();
-	else
+	if (_tray) {
+		_tray->show();
+	} else {
 		show();
+	}
 
-	kapp->setName("kwallet");
+	kapp->setName("kwallet"); // hack to fix docs
 }
 
 
@@ -137,22 +141,30 @@ KWalletManager::~KWalletManager() {
 	_dcopRef = 0L;
 }
 
+
+void KWalletManager::kwalletdLaunch() {
+	_kwalletdLaunch = true;
+}
+
+
 bool KWalletManager::queryClose() {
 	if (!_shuttingDown && !kapp->sessionSaving()) {
-		if ( !_tray )
+		if (!_tray) {
 			kapp->quit();
-		else
-		hide();
+		} else {
+			hide();
+		}
 		return false;
 	}
 	return true;
 }
 
+
 void KWalletManager::aWalletWasOpened() {
-	if ( _tray ) {
-	_tray->setPixmap(loadSystemTrayIcon("wallet_open"));
-	QToolTip::remove(_tray);
-	QToolTip::add(_tray, i18n("KDE Wallet: A wallet is open."));
+	if (_tray) {
+		_tray->setPixmap(loadSystemTrayIcon("wallet_open"));
+		QToolTip::remove(_tray);
+		QToolTip::add(_tray, i18n("KDE Wallet: A wallet is open."));
 	}
 	updateWalletDisplay();
 }
@@ -192,21 +204,21 @@ void KWalletManager::contextMenu(QIconViewItem *item, const QPoint& pos) {
 		connect(popupMenu, SIGNAL(walletChangePassword(const QString&)), this, SLOT(changeWalletPassword(const QString&)));
 		connect(popupMenu, SIGNAL(walletCreated()), this, SLOT(createWallet()));
 		popupMenu->exec(pos);
-                delete popupMenu;
+		delete popupMenu;
 	}
 }
 
 
 void KWalletManager::deleteWallet(const QString& walletName) {
-    int rc = KMessageBox::warningContinueCancel(this, i18n("Are you sure you wish to delete the wallet '%1'?").arg(walletName),"",KStdGuiItem::del());
-    if (rc != KMessageBox::Continue) {
-        return;
-    }
-    rc = KWallet::Wallet::deleteWallet(walletName);
-    if (rc != 0) {
-        KMessageBox::sorry(this, i18n("Unable to delete the wallet. Error code was %1.").arg(rc));
-    }
-    updateWalletDisplay();
+	int rc = KMessageBox::warningContinueCancel(this, i18n("Are you sure you wish to delete the wallet '%1'?").arg(walletName),"",KStdGuiItem::del());
+	if (rc != KMessageBox::Continue) {
+		return;
+	}
+	rc = KWallet::Wallet::deleteWallet(walletName);
+	if (rc != 0) {
+		KMessageBox::sorry(this, i18n("Unable to delete the wallet. Error code was %1.").arg(rc));
+	}
+	updateWalletDisplay();
 }
 
 
@@ -244,21 +256,25 @@ void KWalletManager::openWalletFile(const QString& path) {
 }
 
 
-void KWalletManager::openWallet()
-{
+void KWalletManager::openWallet() {
 	QIconViewItem *item = _iconView->currentItem();
 	openWallet(item);
 }
 
-void KWalletManager::deleteWallet()
-{
+void KWalletManager::deleteWallet() {
 	QIconViewItem *item = _iconView->currentItem();
 	if (item) {
 		deleteWallet(item->text());
 	}
 }
 
+
 void KWalletManager::openWallet(const QString& walletName) {
+	openWallet(walletName, false);
+}
+
+
+void KWalletManager::openWallet(const QString& walletName, bool newWallet) {
 	// Don't allow a wallet to open in two windows
 	for (KMainWindow *w = _windows.first(); w; w = _windows.next()) {
 		KWalletEditor *e = static_cast<KWalletEditor*>(w);
@@ -269,12 +285,13 @@ void KWalletManager::openWallet(const QString& walletName) {
 	}
 
 	KWalletEditor *we = new KWalletEditor(walletName, false, this, "Wallet Editor");
+	we->setNewWallet(newWallet);
 	if (we->isOpen()) {
 		connect(we, SIGNAL(editorClosed(KMainWindow*)),
 			this, SLOT(editorClosed(KMainWindow*)));
 		we->show();
 		_windows.append(we);
-	} else {
+	} else if (!newWallet) {
 		KMessageBox::sorry(this, i18n("Error opening wallet %1.").arg(walletName));
 		delete we;
 	}
@@ -289,10 +306,10 @@ void KWalletManager::openWallet(QIconViewItem *item) {
 
 
 void KWalletManager::allWalletsClosed() {
-	if ( _tray ) {
-	_tray->setPixmap(loadSystemTrayIcon("wallet_closed"));
-	QToolTip::remove(_tray);
-	QToolTip::add(_tray, i18n("KDE Wallet: No wallets open."));
+	if (_tray) {
+		_tray->setPixmap(loadSystemTrayIcon("wallet_closed"));
+		QToolTip::remove(_tray);
+		QToolTip::add(_tray, i18n("KDE Wallet: No wallets open."));
 	}
 	possiblyQuit();
 }
@@ -303,7 +320,8 @@ void KWalletManager::possiblyQuit() {
 	cfg.setGroup("Wallet");
 	if (_windows.isEmpty() &&
 			!isVisible() &&
-			!cfg.readBoolEntry("Leave Manager Open", false)) {
+			!cfg.readBoolEntry("Leave Manager Open", false) &&
+			_kwalletdLaunch) {
 		kapp->quit();
 	}
 }
@@ -328,6 +346,11 @@ void KWalletManager::createWallet() {
 	QRegExp regexp("^[A-Za-z0-9]+[A-Za-z0-9_\\s\\-]*$");
 	QString txt = i18n("Please choose a name for the new wallet:");
 
+	if (!KWallet::Wallet::isEnabled()) {
+		// FIXME: KMessageBox::warningYesNo(this, i1_8n("KWallet is not enabled.  Do you want to enable it?"));
+		return;
+	}
+
 	do {
 		n = KInputDialog::getText(i18n("New Wallet"),
 				txt,
@@ -354,25 +377,28 @@ void KWalletManager::createWallet() {
 
 	// Small race here - the wallet could be created on us already.
 	if (!n.isEmpty()) {
-		openWallet(n);
+		openWallet(n, true);
 	}
 }
 
+
 void KWalletManager::shuttingDown() {
 	_shuttingDown = true;
 	kapp->quit();
 }
 
+
 void KWalletManager::setupWallet() {
 	KApplication::startServiceByDesktopName("kwallet_config");
 }
 
+
 void KWalletManager::closeAllWallets() {
 	_dcopRef->call("closeAllWallets");
 }
 
-QPixmap KWalletManager::loadSystemTrayIcon(const QString &icon)
-{
+
+QPixmap KWalletManager::loadSystemTrayIcon(const QString &icon) {
 #if KDE_IS_VERSION(3, 1, 90)
 	return KSystemTray::loadIcon(icon);
 #else
