@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2003 George Staikos <staikos@kde.org>
+   Copyright (C) 2003,2004 George Staikos <staikos@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -40,12 +40,15 @@ class KWalletManager : public KMainWindow, public DCOPObject {
 
                 QPixmap loadSystemTrayIcon(const QString &icon);
 
+		void kwalletdLaunch();
+
 	public slots:
 		void createWallet();
 		void deleteWallet(const QString& walletName);
 		void closeWallet(const QString& walletName);
 		void changeWalletPassword(const QString& walletName);
 		void openWallet(const QString& walletName);
+		void openWallet(const QString& walletName, bool newWallet);
 		void openWalletFile(const QString& path);
 		void openWallet(QIconViewItem *item);
 		void contextMenu(QIconViewItem *item, const QPoint& pos);
@@ -75,6 +78,7 @@ class KWalletManager : public KMainWindow, public DCOPObject {
 		KWalletIconView *_iconView;
 		DCOPRef *_dcopRef;
 		QPtrList<KMainWindow> _windows;
+		bool _kwalletdLaunch;
 };
 
 #endif
